@@ -54,8 +54,8 @@ int csp_thread_index_get(CSOUND *csound)
 }
 
 
-/* **** An implementation of Barriers for MAC that lacks them **** */
-#ifdef __MACH__
+/* **** An implementation of Barriers for MAC and Haku that lack them **** */
+#if defined(__MACH__) || defined(__HAIKU__)
 /*#define BARRIER_SERIAL_THREAD (-1)
 
 typedef struct {
@@ -140,14 +140,14 @@ void csp_barrier_alloc(CSOUND *csound, pthread_barrier_t **barrier,
                        int thread_count)
 {
     if (UNLIKELY(barrier == NULL))
-      csound->Die(csound, "Invalid NULL Parameter barrier");
+      csound->Die(csound, Str("Invalid NULL Parameter barrier"));
     if (UNLIKELY(thread_count < 1))
-      csound->Die(csound, "Invalid Parameter thread_count must be > 0");
+      csound->Die(csound, Str("Invalid Parameter thread_count must be > 0"));
 
     *barrier = (pthread_barrier_t *)csound->Malloc(csound,
                                                    sizeof(pthread_barrier_t));
     if (UNLIKELY(*barrier == NULL)) {
-        csound->Die(csound, "Failed to allocate barrier");
+        csound->Die(csound, "Str(Failed to allocate barrier");
     }
     pthread_barrier_init(*barrier, NULL, thread_count);
 }
@@ -155,7 +155,7 @@ void csp_barrier_alloc(CSOUND *csound, pthread_barrier_t **barrier,
 void csp_barrier_dealloc(CSOUND *csound, pthread_barrier_t **barrier)
 {
     if (UNLIKELY(barrier == NULL || *barrier == NULL))
-      csound->Die(csound, "Invalid NULL Parameter barrier");
+      csound->Die(csound, Str("Invalid NULL Parameter barrier"));
 
     pthread_barrier_destroy(*barrier);
 }
@@ -167,7 +167,7 @@ void csp_barrier_dealloc(CSOUND *csound, pthread_barrier_t **barrier)
 //void csp_semaphore_alloc(CSOUND *csound, sem_t **sem, int max_threads)
 //{
 //    if (UNLIKELY(sem == NULL))
-//      csound->Die(csound, "Invalid NULL Parameter sem");
+//      csound->Die(csound, "Str(Invalid) NULL Parameter sem");
 //    if (*sem != NULL) {
 //      int val;
 //      sem_getvalue(*sem, &val);
@@ -215,7 +215,7 @@ void csp_barrier_dealloc(CSOUND *csound, pthread_barrier_t **barrier)
 //{
 //    /* int val, res; */
 //    /* res = sem_getvalue(sem, &val); */
-//    /* csound->DebugMsg(csound, "before sem_grow: %d %i\t", 
+//    /* csound->DebugMsg(csound, "before sem_grow: %d %i\t",
 //               val, csp_thread_index_get(csound)); */
 //    sem_post(sem);
 //    /* res = sem_getvalue(sem, &val); */
@@ -249,7 +249,7 @@ void csp_barrier_dealloc(CSOUND *csound, pthread_barrier_t **barrier)
 //void csp_semaphore_release_print(CSOUND *csound, sem_t *sem)
 //{
 //    int val, res;
-//    if (UNLIKELY(sem == NULL)) 
+//    if (UNLIKELY(sem == NULL))
 //      csound->Die(csound, "Invalid NULL Parameter sem");
 //    res = sem_getvalue(sem, &val);
 //    csound->DebugMsg(csound, "sem_release_print: %d %p\n",
@@ -260,18 +260,16 @@ void csp_barrier_dealloc(CSOUND *csound, pthread_barrier_t **barrier)
 /***********************************************************************
  * set data structure
  */
-#pragma mark -
-#pragma mark Set
 
 /* static prototypes */
-static int set_element_delloc(CSOUND *csound, 
+static int set_element_delloc(CSOUND *csound,
                               struct set_element_t **set_element);
 static int set_element_alloc(CSOUND *csound,
-                             struct set_element_t **set_element, 
+                             struct set_element_t **set_element,
                              char *data);
-static int set_is_set(CSOUND *csound, struct set_t *set);
+static int set_is_set(struct set_t *set);
 #if 0
-static int 
+static int
   set_element_is_set_element(CSOUND *csound,
                              struct set_element_t *set_element);
 #endif
@@ -281,11 +279,11 @@ int csp_set_alloc(CSOUND *csound, struct set_t **set,
                   set_element_data_print *ele_print_func)
 {
     if (UNLIKELY(set == NULL))
-      csound->Die(csound, "Invalid NULL Parameter set");
+      csound->Die(csound, Str("Invalid NULL Parameter set"));
 
     *set = csound->Malloc(csound, sizeof(struct set_t));
     if (UNLIKELY(*set == NULL)) {
-      csound->Die(csound, "Failed to allocate set");
+      csound->Die(csound, Str("Failed to allocate set"));
     }
     memset(*set, 0, sizeof(struct set_t));
     strncpy((*set)->hdr, SET_HDR, HDR_LEN);
@@ -300,9 +298,9 @@ int csp_set_dealloc(CSOUND *csound, struct set_t **set)
 {
     struct set_element_t *ele;
     if (UNLIKELY(set == NULL || *set == NULL))
-      csound->Die(csound, "Invalid NULL Parameter set");
-    if (UNLIKELY(!set_is_set(csound, *set)))
-      csound->Die(csound, "Invalid Parameter set not a set");
+      csound->Die(csound, Str("Invalid NULL Parameter set"));
+    if (UNLIKELY(!set_is_set(*set)))
+      csound->Die(csound, Str("Invalid Parameter set not a set"));
 
     if ((*set)->cache != NULL) csound->Free(csound, (*set)->cache);
 
@@ -324,11 +322,11 @@ static int set_element_alloc(CSOUND *csound,
                              char *data)
 {
     if (UNLIKELY(set_element == NULL || data == NULL))
-      csound->Die(csound, "Invalid NULL Parameter data");
+      csound->Die(csound, Str("Invalid NULL Parameter data"));
 
     *set_element = csound->Malloc(csound, sizeof(struct set_element_t));
     if (UNLIKELY(*set_element == NULL)) {
-      csound->Die(csound, "Failed to allocate set element");
+      csound->Die(csound, Str("Failed to allocate set element"));
     }
     memset(*set_element, 0, sizeof(struct set_element_t));
     strncpy((*set_element)->hdr, SET_ELEMENT_HDR, HDR_LEN);
@@ -341,14 +339,14 @@ static int set_element_delloc(CSOUND *csound,
                               struct set_element_t **set_element)
 {
     if (UNLIKELY(set_element == NULL || *set_element == NULL))
-      csound->Die(csound, "Invalid NULL Parameter set_element");
+      csound->Die(csound, Str("Invalid NULL Parameter set_element"));
     csound->Free(csound, *set_element);
     *set_element = NULL;
 
     return CSOUND_SUCCESS;
 }
 
-static int set_is_set(CSOUND *csound, struct set_t *set)
+static int set_is_set(struct set_t *set)
 {
     char buf[4];
     if (set == NULL) return 0;
@@ -358,7 +356,7 @@ static int set_is_set(CSOUND *csound, struct set_t *set)
 }
 
 #if 0
-static int 
+static int
   set_element_is_set_element(CSOUND *csound,
                              struct set_element_t *set_element)
 {
@@ -410,7 +408,7 @@ static int set_update_cache(CSOUND *csound, struct set_t *set)
     if (set->count > 0) {
       struct set_element_t *ele;
       int ctr = 0;
-      set->cache = 
+      set->cache =
         csound->Malloc(csound,
                        sizeof(struct set_element_t *) * set->count);
       ele = set->head;
@@ -427,28 +425,18 @@ static int set_update_cache(CSOUND *csound, struct set_t *set)
  * if out_set_element is not NULL and the element corresponding to
  * data is not found it will not be changed
  */
-static int set_element_get(CSOUND *csound, struct set_t *set,
+static int set_element_get(struct set_t *set,
                            char *data,
                            struct set_element_t **out_set_element)
 {
-#ifdef SET_DEBUG
-    if (UNLIKELY(set == NULL))
-      csound->Die(csound, "Invalid NULL Parameter set");
-    if (UNLIKELY(data == NULL))
-      csound->Die(csound, "Invalid NULL Parameter data");
-    if (UNLIKELY(out_set_element == NULL))
-      csound->Die(csound, "Invalid NULL Parameter out_set_element");
-#endif
-    {
-      struct set_element_t *ele = set->head;
-      struct set_element_t data_ele = { SET_ELEMENT_HDR, data, 0 };
-      while (ele != NULL) {
-        if (set->ele_eq_func(ele, &data_ele)) {
-          *out_set_element = ele;
-          break;
-        }
-        ele = ele->next;
+    struct set_element_t *ele = set->head;
+    struct set_element_t data_ele = { SET_ELEMENT_HDR, data, 0 };
+    while (ele != NULL) {
+      if (set->ele_eq_func(ele, &data_ele)) {
+        *out_set_element = ele;
+        break;
       }
+      ele = ele->next;
     }
     return CSOUND_SUCCESS;
 }
@@ -458,9 +446,9 @@ int csp_set_add(CSOUND *csound, struct set_t *set, void *data)
     struct set_element_t *ele = NULL;
 #ifdef SET_DEBUG
     if (UNLIKELY(set == NULL))
-      csound->Die(csound, "Invalid NULL Parameter set");
+      csound->Die(csound, Str("Invalid NULL Parameter set"));
     if (UNLIKELY(data == NULL))
-      csound->Die(csound, "Invalid NULL Parameter data");
+      csound->Die(csound, Str("Invalid NULL Parameter data"));
 #endif
 
     if (csp_set_exists(csound, set, data)) {
@@ -487,9 +475,9 @@ int csp_set_remove(CSOUND *csound, struct set_t *set, void *data)
 {
 #ifdef SET_DEBUG
     if (UNLIKELY(set == NULL))
-      csound->Die(csound, "Invalid NULL Parameter set");
+      csound->Die(csound, Str("Invalid NULL Parameter set"));
     if (UNLIKELY(data == NULL))
-      csound->Die(csound, "Invalid NULL Parameter data");
+      csound->Die(csound, Str("Invalid NULL Parameter data"));
 #endif
     {
       struct set_element_t *ele = set->head, *prev = NULL;
@@ -524,11 +512,11 @@ int csp_set_exists(CSOUND *csound, struct set_t *set, void *data)
     struct set_element_t *ele = NULL;
 #ifdef SET_DEBUG
     if (UNLIKELY(set == NULL))
-      csound->Die(csound, "Invalid NULL Parameter set");
+      csound->Die(csound, Str("Invalid NULL Parameter set"));
     if (UNLIKELY(data == NULL))
-      csound->Die(csound, "Invalid NULL Parameter data");
+      csound->Die(csound, Str("Invalid NULL Parameter data"));
 #endif
-    set_element_get(csound, set, data, &ele);
+    set_element_get(set, data, &ele);
 
     return (ele == NULL ? 0 : 1);
 }
@@ -538,9 +526,9 @@ int csp_set_print(CSOUND *csound, struct set_t *set)
     struct set_element_t *ele;
 #ifdef SET_DEBUG
     if (UNLIKELY(set == NULL))
-      csound->Die(csound, "Invalid NULL Parameter set");
-    if (UNLIKELY(!set_is_set(csound, set)))
-      csound->Die(csound, "Invalid Parameter set not a set");
+      csound->Die(csound, Str("Invalid NULL Parameter set"));
+    if (UNLIKELY(!set_is_set(set)))
+      csound->Die(csound, Str("Invalid Parameter set not a set"));
 #endif
 
     ele = set->head;
@@ -559,33 +547,14 @@ int csp_set_print(CSOUND *csound, struct set_t *set)
     return CSOUND_SUCCESS;
 }
 
-int inline csp_set_count(CSOUND *csound, struct set_t *set)
+inline int csp_set_count(struct set_t *set)
 {
-#ifdef SET_DEBUG
-    if (UNLIKELY(set == NULL))
-      csound->Die(csound, "Invalid NULL Parameter set");
-    if (UNLIKELY(!set_is_set(csound, set)))
-      csound->Die(csound, "Invalid Parameter set not a set");
-#endif
-
     return set->count;
 }
 
 /* 0 indexed */
-int inline csp_set_get_num(CSOUND *csound,
-                           struct set_t *set, int num, void **data)
+inline int csp_set_get_num(struct set_t *set, int num, void **data)
 {
-#ifdef SET_DEBUG
-    if (UNLIKELY(set == NULL))
-      csound->Die(csound, "Invalid NULL Parameter set");
-    if (UNLIKELY(!set_is_set(csound, set)))
-      csound->Die(csound, "Invalid Parameter set not a set");
-    if (UNLIKELY(um >= set->count))
-      csound->Die(csound, "Invalid Parameter num is out of bounds");
-    if (UNLIKELY(data == NULL))
-      csound->Die(csound, "Invalid NULL Parameter data");
-#endif
-
     *data = set->cache[num]->data;
     /*
     if (set->cache != NULL) {
@@ -614,29 +583,29 @@ int csp_set_union(CSOUND *csound, struct set_t *first,
     int second_len;
 #ifdef SET_DEBUG
     if (UNLIKELY(first == NULL))
-      csound->Die(csound, "Invalid NULL Parameter first");
-    if (UNLIKELY(!set_is_set(csound, first)))
-      csound->Die(csound, "Invalid Parameter set not a first");
+      csound->Die(csound, Str("Invalid NULL Parameter first"));
+    if (UNLIKELY(!set_is_set(first)))
+      csound->Die(csound, Str("Invalid Parameter set not a first"));
     if (UNLIKELY(second == NULL))
- csound->Die(csound, "Invalid NULL Parameter second");
-    if (UNLIKELY(!set_is_set(csound, second)))
-      csound->Die(csound, "Invalid Parameter set not a second");
+      csound->Die(csound, Str("Invalid NULL Parameter second"));
+    if (UNLIKELY(!set_is_set(second)))
+      csound->Die(csound, Str("Invalid Parameter set not a second"));
     if (UNLIKELY(result == NULL))
- csound->Die(csound, "Invalid NULL Parameter result");
+      csound->Die(csound, Str("Invalid NULL Parameter result"));
     if (UNLIKELY(first->ele_eq_func != second->ele_eq_func))
       csound->Die(csound,
-                  "Invalid sets for comparison (different equality)");
+                  Str("Invalid sets for comparison (different equality)"));
 #endif
 
     csp_set_alloc(csound, result,
                   first->ele_eq_func, first->ele_print_func);
 
-    first_len = csp_set_count(csound, first);
-    second_len = csp_set_count(csound, second);
+    first_len = csp_set_count(first);
+    second_len = csp_set_count(second);
 
     while (ctr < first_len) {
       void *data = NULL;
-      csp_set_get_num(csound, first, ctr, &data);
+      csp_set_get_num(first, ctr, &data);
       csp_set_add(csound, *result, data);
       ctr++;
     }
@@ -644,7 +613,7 @@ int csp_set_union(CSOUND *csound, struct set_t *first,
     ctr = 0;
     while (ctr < second_len) {
       void *data = NULL;
-      csp_set_get_num(csound, second, ctr, &data);
+      csp_set_get_num(second, ctr, &data);
       csp_set_add(csound, *result, data);
       ctr++;
     }
@@ -659,28 +628,28 @@ int csp_set_intersection(CSOUND *csound, struct set_t *first,
     int first_len;
 #ifdef SET_DEBUG
     if (UNLIKELY(first == NULL))
-      csound->Die(csound, "Invalid NULL Parameter first");
-    if (UNLIKELY(!set_is_set(csound, first)))
-      csound->Die(csound, "Invalid Parameter set not a first");
+      csound->Die(csound, Str("Invalid NULL Parameter first"));
+    if (UNLIKELY(!set_is_set(first)))
+      csound->Die(csound, Str("Invalid Parameter set not a first"));
     if (UNLIKELY(second == NULL))
-      csound->Die(csound, "Invalid NULL Parameter second");
-    if (UNLIKELY(!set_is_set(csound, second)))
-      csound->Die(csound, "Invalid Parameter set not a second");
+      csound->Die(csound, Str("Invalid NULL Parameter second"));
+    if (UNLIKELY(!set_is_set(second)))
+      csound->Die(csound, Str("Invalid Parameter set not a second"));
     if (UNLIKELY(result == NULL))
-      csound->Die(csound, "Invalid NULL Parameter result");
+      csound->Die(csound, Str("Invalid NULL Parameter result"));
     if (UNLIKELY(first->ele_eq_func != second->ele_eq_func))
       csound->Die(csound,
-                  "Invalid sets for comparison (different equality)");
+                  Str("Invalid sets for comparison (different equality)"));
 #endif
 
     csp_set_alloc(csound, result,
                   first->ele_eq_func, first->ele_print_func);
 
-    first_len = csp_set_count(csound, first);
+    first_len = csp_set_count(first);
 
     while (ctr < first_len) {
       void *data = NULL;
-      csp_set_get_num(csound, first, ctr, &data);
+      csp_set_get_num(first, ctr, &data);
       if (csp_set_exists(csound, second, data)) {
         csp_set_add(csound, *result, data);
       }
