@@ -26,7 +26,6 @@
 
 #include "csoundCore.h"
 #include "csound_orc.h"
-#include "tok.h"
 #include "cs_par_base.h"
 #include "cs_par_orc_semantics.h"
 #include "cs_par_dispatch.h"
@@ -42,7 +41,7 @@ extern ORCTOKEN *lookup_token(CSOUND *csound, char *);
 /***********************************************************************
  * static function prototypes
  */
-static uint32_t inline hash( uint32_t a );
+inline static uint32_t hash( uint32_t a );
 static uint32_t hash_chain(INSDS *chain, uint32_t hash_size);
 static uint32_t hash_string(char *str, uint32_t hash_size);
 
@@ -53,7 +52,7 @@ static uint32_t hash_string(char *str, uint32_t hash_size);
 /* Robert Jenkins' 32 bit integer hash function from
  * http://www.concentric.net/~Ttwang/tech/inthash.htm
  */
-static uint32_t inline hash( uint32_t a )
+inline static uint32_t hash( uint32_t a )
 {
     a = (a+0x7ed55d16) + (a<<12);
     a = (a^0xc761c23c) ^ (a>>19);
@@ -91,8 +90,6 @@ static uint32_t hash_string(char *str, uint32_t hash_size)
 /***********************************************************************
  * Global Var Lock Inserts
  */
-#pragma mark -
-#pragma mark Global Var Lock Inserts
 
 /* global variables lock support */
 struct global_var_lock_t {
@@ -108,7 +105,7 @@ struct global_var_lock_t {
 //static struct global_var_lock_t **global_var_lock_cache;
 
 
-void inline csp_locks_lock(CSOUND * csound, int global_index)
+inline void csp_locks_lock(CSOUND * csound, int global_index)
 {
     if (UNLIKELY(global_index >= csound->global_var_lock_count)) {
       csound->Die(csound,
@@ -121,7 +118,7 @@ void inline csp_locks_lock(CSOUND * csound, int global_index)
     TAKE_LOCK(&(csound->global_var_lock_cache[global_index]->lock));
 }
 
-void inline csp_locks_unlock(CSOUND * csound, int global_index)
+inline void csp_locks_unlock(CSOUND * csound, int global_index)
 {
     if (UNLIKELY(global_index >= csound->global_var_lock_count)) {
       csound->Die(csound,
@@ -154,7 +151,7 @@ static struct global_var_lock_t *global_var_lock_alloc(CSOUND *csound,
     return ret;
 }
 
-static struct global_var_lock_t 
+static struct global_var_lock_t
   *global_var_lock_find(CSOUND *csound, char *name)
 {
     if (UNLIKELY(name == NULL))
@@ -201,7 +198,7 @@ static struct global_var_lock_t
 TREE *csp_locks_insert(CSOUND *csound, TREE *root)
 {
     csound->Message(csound,
-                    "Inserting Parallelism Constructs into AST\n");
+                    Str("Inserting Parallelism Constructs into AST\n"));
 
     TREE *anchor = NULL;
 
@@ -213,8 +210,9 @@ TREE *csp_locks_insert(CSOUND *csound, TREE *root)
       switch(current->type) {
       case INSTR_TOKEN:
         if (current->left->type == T_INSTLIST) {
-          instr = csp_orc_sa_instr_get_by_name(csound,
-                                               current->left->left->value->lexeme);
+          instr =
+            csp_orc_sa_instr_get_by_name(csound,
+                                         current->left->left->value->lexeme);
         }
         else {
           instr = csp_orc_sa_instr_get_by_name(csound,
@@ -244,7 +242,7 @@ TREE *csp_locks_insert(CSOUND *csound, TREE *root)
            * that is same global read and written in this operation */
           if (left->count == 1 && right->count == 1 && new->count == 1) {
             char *global_var = NULL;
-            csp_set_get_num(csound, new, 0, (void **)&global_var);
+            csp_set_get_num(new, 0, (void **)&global_var);
 
             struct global_var_lock_t *gvar =
               global_var_lock_find(csound, global_var);
@@ -300,7 +298,7 @@ TREE *csp_locks_insert(CSOUND *csound, TREE *root)
     }
 
     csound->Message(csound,
-                    "[End Inserting Parallelism Constructs into AST]\n");
+                    Str("[End Inserting Parallelism Constructs into AST]\n"));
 
     return anchor;
 }
@@ -328,7 +326,7 @@ void csp_locks_cache_build(CSOUND *csound)
     /* csound->Message(csound, "Global Locks Cache\n");
        ctr = 0;
        while (ctr < csound->global_var_lock_count) {
-       csound->Message(csound, "[%i] %s\n", 
+       csound->Message(csound, "[%i] %s\n",
                        csound->global_var_lock_cache[ctr]->index,
        csound->global_var_lock_cache[ctr]->name);
        ctr++;
@@ -353,10 +351,8 @@ int globalunlock(CSOUND *csound, GLOBAL_LOCK_UNLOCK *p)
 /***********************************************************************
  * weighting
  */
-#pragma mark -
-#pragma mark Instr weightings
 
-/* static struct instr_weight_info_t 
+/* static struct instr_weight_info_t
    *instr_weight_info_alloc(CSOUND *csound)
    {
    struct instr_weight_info_t *ret =
@@ -374,15 +370,15 @@ int globalunlock(CSOUND *csound, GLOBAL_LOCK_UNLOCK *p)
 static void csp_weights_calculate_instr(CSOUND *csound, TREE *root,
                                         INSTR_SEMANTICS *instr)
 {
-    csound->Message(csound, "Calculating Instrument weight from AST\n");
+    csound->Message(csound, Str("Calculating Instrument weight from AST\n"));
 
     TREE *current = root;
     INSTR_SEMANTICS *nested_instr = NULL;
 
-    while(current != NULL) {
+    while (current != NULL) {
       switch(current->type) {
       case INSTR_TOKEN:
-        nested_instr = 
+        nested_instr =
           csp_orc_sa_instr_get_by_name(csound,
                                        current->left->value->lexeme);
         /* if (nested_instr->weight == NULL) {
@@ -410,8 +406,8 @@ static void csp_weights_calculate_instr(CSOUND *csound, TREE *root,
 
       default:
         csound->Message(csound,
-                        "WARNING: Unexpected node type in weight "
-                        "calculation walk %i\n", current->type);
+                        Str("WARNING: Unexpected node type in weight "
+                            "calculation walk %i\n"), current->type);
         instr->weight += WEIGHT_UNKNOWN_NODE;
         break;
       }
@@ -420,17 +416,17 @@ static void csp_weights_calculate_instr(CSOUND *csound, TREE *root,
     }
 
     csound->Message(csound,
-                    "[End Calculating Instrument weight from AST]\n");
+                    Str("[End Calculating Instrument weight from AST]\n"));
 }
 
 void csp_weights_calculate(CSOUND *csound, TREE *root)
 {
-    csound->Message(csound, "Calculating Instrument weights from AST\n");
+    csound->Message(csound, Str("Calculating Instrument weights from AST\n"));
 
     TREE *current = root;
     INSTR_SEMANTICS *instr = NULL;
 
-    while(current != NULL) {
+    while (current != NULL) {
       switch(current->type) {
       case INSTR_TOKEN:
         if (current->left->type == T_INSTLIST) {
@@ -468,14 +464,14 @@ void csp_weights_calculate(CSOUND *csound, TREE *root)
     }
 
     csound->Message(csound,
-                    "[End Calculating Instrument weights from AST]\n");
+                    Str("[End Calculating Instrument weights from AST]\n"));
 }
 
 static void csp_orc_sa_opcode_dump_instr(CSOUND *csound, TREE *root)
 {
     TREE *current = root;
 
-    while(current != NULL) {
+    while (current != NULL) {
       switch(current->type) {
       case INSTR_TOKEN:
         break;
@@ -489,8 +485,8 @@ static void csp_orc_sa_opcode_dump_instr(CSOUND *csound, TREE *root)
         break;
 
       default:
-        csound->Message(csound, "WARNING: Unexpected node type in weight "
-                        "calculation walk %i\n", current->type);
+        csound->Message(csound, Str("WARNING: Unexpected node type in weight "
+                                    "calculation walk %i\n"), current->type);
         break;
       }
 
@@ -504,8 +500,8 @@ void csp_orc_sa_opcode_dump(CSOUND *csound, TREE *root)
 
     TREE *current = root;
 
-    while(current != NULL) {
-      switch(current->type) {
+    while (current != NULL) {
+      switch (current->type) {
       case INSTR_TOKEN:
         csp_orc_sa_opcode_dump_instr(csound, current->right);
         break;
@@ -524,8 +520,6 @@ void csp_orc_sa_opcode_dump(CSOUND *csound, TREE *root)
 /***********************************************************************
  * weights structure
  */
-#pragma mark -
-#pragma mark weights structure
 
 struct opcode_weight_cache_entry_t {
   uint32_t                            hash_val;
@@ -547,7 +541,7 @@ struct opcode_weight_cache_entry_t {
 static void opcode_weight_entry_add(CSOUND *csound,
                                     char *name, uint32_t weight);
 
-static int 
+static int
   opcode_weight_entry_alloc(CSOUND *csound,
                             struct opcode_weight_cache_entry_t **entry,
                             char *name, uint32_t weight, uint32_t hash_val)
@@ -575,7 +569,7 @@ static int
 }
 
 #if 0
-static int 
+static int
   opcode_weight_entry_dealloc(CSOUND *csound,
                               struct opcode_weight_cache_entry_t **entry)
 {
@@ -613,7 +607,7 @@ uint32_t csp_opcode_weight_fetch(CSOUND *csound, char *name)
       }
       /* no weight for this opcode use default */
       csound->Message(csound,
-                      "WARNING: no weight found for opcode: %s\n", name);
+                      Str("WARNING: no weight found for opcode: %s\n"), name);
       return WEIGHT_OPCODE_NODE;
     }
 }
@@ -692,7 +686,7 @@ void csp_weights_dump(CSOUND *csound)
 {
     if (UNLIKELY(csound->opcode_weight_have_cache == 0)) {
           csound->Message(csound,
-                          Str("No Weights to Dump (Using Defaults)\n"));
+                          "No Weights to Dump (Using Defaults)\n");
       return;
     }
     else {
@@ -915,8 +909,6 @@ void csp_weights_load(CSOUND *csound)
 /***********************************************************************
  * weighting decision
  */
-#pragma mark -
-#pragma mark dag weighting decision
 
 /* static struct instr_weight_info_t *weight_info; */
 
@@ -996,8 +988,6 @@ int inline csp_parallel_compute_should(CSOUND *csound, DAG *dag)
 /***********************************************************************
  * dag2 data structure
  */
-#pragma mark -
-#pragma mark Dag2
 
 /* prototypes for dag2 */
 static void dag_node_2_alloc(CSOUND *csound, DAG_NODE **dag_node,
@@ -1014,13 +1004,13 @@ static void dag_node_2_dealloc(CSOUND *csound, DAG_NODE **dag_node);
 /* build the edges (fill out the table) */
 /* static void csp_dag_build_edges(CSOUND *csound, DAG *dag); */
 /* find the roots in the DAG and setup the root countdowns */
-static void csp_dag_build_roots(CSOUND *csound, DAG *dag);
+static void csp_dag_build_roots(DAG *dag);
 /* perpare DAG after building */
-/* static void csp_dag_prepare_use_first(CSOUND *csound, DAG *dag); */
+/* static void csp_dag_prepare_use_first(DAG *dag); */
 /* perpare DAG after getting out of the cache */
-static void csp_dag_prepare_use(CSOUND *csound, DAG *dag);
+static void csp_dag_prepare_use(DAG *dag);
 /* follow insds chain in nodes to update insds pointers */
-static inline void csp_dag_prepare_use_insds(CSOUND *csound, DAG *dag,
+static inline void csp_dag_prepare_use_insds(DAG *dag,
                                              INSDS *chain);
 
 #define DAG_NO_LINK     0
@@ -1155,7 +1145,7 @@ void csp_dag_add(CSOUND *csound, DAG *dag,
     dag_node_2_alloc(csound, &dag_node, instr, insds);
 
     TRACE_1("dag->count = %d\n", dag->count);
-    //    dag->all = 
+    //    dag->all =
     //     (DAG_NODE **)csound->Malloc(csound,
     //                                 sizeof(DAG_NODE *) * (dag->count + 1));
     /* Can not this be done with memcpy or Realloc */
@@ -1265,7 +1255,8 @@ inline static DAG *csp_dag_build_initial(CSOUND *csound, INSDS *chain)
         csp_orc_sa_instr_get_by_num(csound, chain->insno);
       if (current_instr == NULL) {
         current_instr =
-          csp_orc_sa_instr_get_by_name(csound, csound->instrtxtp[chain->insno]->insname);
+          csp_orc_sa_instr_get_by_name(csound,
+                                       csound->instrtxtp[chain->insno]->insname);
         if (current_instr == NULL)
           csound->Die(csound,
                       Str("Failed to find semantic information"
@@ -1300,12 +1291,12 @@ inline static void csp_dag_build_edges(CSOUND *csound, DAG *dag)
         csp_set_intersection(csound, dag->all[dag_root_ctr]->instr->write,
                              dag->all[dag_curr_ctr]->instr->read,
                              &write_intersection);
-        if (csp_set_count(csound, write_intersection) != 0) {
+        if (csp_set_count(write_intersection) != 0) {
           depends |= DAG_STRONG_LINK;
         }
         csp_set_dealloc(csound, &write_intersection);
 
-        /* csound->Message(csound, 
+        /* csound->Message(csound,
                            "write_intersection depends: %i\n", depends);
            csp_set_print(csound, dag->all[dag_root_ctr]->instr->write);
            csp_set_print(csound, dag->all[dag_curr_ctr]->instr->read); */
@@ -1314,7 +1305,7 @@ inline static void csp_dag_build_edges(CSOUND *csound, DAG *dag)
         csp_set_intersection(csound, dag->all[dag_root_ctr]->instr->read,
                              dag->all[dag_curr_ctr]->instr->write,
                              &read_intersection);
-        if (csp_set_count(csound, read_intersection) != 0) {
+        if (csp_set_count(read_intersection) != 0) {
           depends |= DAG_STRONG_LINK;
         }
         csp_set_dealloc(csound, &read_intersection);
@@ -1328,7 +1319,7 @@ inline static void csp_dag_build_edges(CSOUND *csound, DAG *dag)
         csp_set_intersection(csound, dag->all[dag_root_ctr]->instr->write,
                              dag->all[dag_curr_ctr]->instr->write,
                              &double_write_intersection);
-        if (csp_set_count(csound, double_write_intersection) != 0) {
+        if (csp_set_count(double_write_intersection) != 0) {
           depends |= DAG_STRONG_LINK;
         }
         csp_set_dealloc(csound, &double_write_intersection);
@@ -1343,23 +1334,23 @@ inline static void csp_dag_build_edges(CSOUND *csound, DAG *dag)
                              dag->all[dag_root_ctr]->instr->read_write,
                              dag->all[dag_curr_ctr]->instr->write,
                              &readwrite_write_intersection);
-        if (csp_set_count(csound, readwrite_write_intersection) != 0) {
+        if (csp_set_count(readwrite_write_intersection) != 0) {
           depends |= DAG_STRONG_LINK;
         }
         csp_set_dealloc(csound, &readwrite_write_intersection);
 
-        /* csound->Message(csound, 
+        /* csound->Message(csound,
                            "readwrite_write_intersection depends: %i\n",
                            depends);
            csp_set_print(csound, dag->all[dag_root_ctr]->instr->read_write);
            csp_set_print(csound, dag->all[dag_curr_ctr]->instr->write); */
 
         struct set_t *readwrite_read_intersection = NULL;
-        csp_set_intersection(csound, 
+        csp_set_intersection(csound,
                              dag->all[dag_root_ctr]->instr->read_write,
                              dag->all[dag_curr_ctr]->instr->read,
                              &readwrite_read_intersection);
-        if (csp_set_count(csound, readwrite_read_intersection) != 0) {
+        if (csp_set_count(readwrite_read_intersection) != 0) {
           depends |= DAG_STRONG_LINK;
         }
         csp_set_dealloc(csound, &readwrite_read_intersection);
@@ -1367,7 +1358,7 @@ inline static void csp_dag_build_edges(CSOUND *csound, DAG *dag)
         /* csound->Message(csound,
                            "readwrite_read_intersection depends: %i\n",
                            depends);
-           csp_set_print(csound, 
+           csp_set_print(csound,
                          dag->all[dag_root_ctr]->instr->read_write);
            csp_set_print(csound, dag->all[dag_curr_ctr]->instr->write); */
 
@@ -1375,23 +1366,23 @@ inline static void csp_dag_build_edges(CSOUND *csound, DAG *dag)
         csp_set_intersection(csound, dag->all[dag_root_ctr]->instr->read,
                              dag->all[dag_curr_ctr]->instr->read_write,
                              &read_readwrite_intersection);
-        if (csp_set_count(csound, read_readwrite_intersection) != 0) {
+        if (csp_set_count(read_readwrite_intersection) != 0) {
           depends |= DAG_STRONG_LINK;
         }
         csp_set_dealloc(csound, &read_readwrite_intersection);
 
-        /* csound->Message(csound, 
+        /* csound->Message(csound,
                            "read_readwrite_intersection depends: %i\n",
                            depends);
            csp_set_print(csound, dag->all[dag_root_ctr]->instr->read);
-           csp_set_print(csound, 
+           csp_set_print(csound,
                          dag->all[dag_curr_ctr]->instr->read_write); */
 
         struct set_t *write_readwrite_intersection = NULL;
         csp_set_intersection(csound, dag->all[dag_root_ctr]->instr->write,
                              dag->all[dag_curr_ctr]->instr->read_write,
                              &write_readwrite_intersection);
-        if (csp_set_count(csound, write_readwrite_intersection) != 0) {
+        if (csp_set_count(write_readwrite_intersection) != 0) {
           depends |= DAG_STRONG_LINK;
         }
         csp_set_dealloc(csound, &write_readwrite_intersection);
@@ -1408,8 +1399,7 @@ inline static void csp_dag_build_edges(CSOUND *csound, DAG *dag)
                              dag->all[dag_root_ctr]->instr->read_write,
                              dag->all[dag_curr_ctr]->instr->read_write,
                              &readwrite_readwrite_intersection);
-        if (csp_set_count(csound,
-                          readwrite_readwrite_intersection) != 0) {
+        if (csp_set_count(readwrite_readwrite_intersection) != 0) {
           depends |= DAG_WEAK_LINK;
         }
         csp_set_dealloc(csound, &readwrite_readwrite_intersection);
@@ -1418,7 +1408,7 @@ inline static void csp_dag_build_edges(CSOUND *csound, DAG *dag)
                            "readwrite_readwrite_intersection depends: %i\n",
                            depends);
            csp_set_print(csound, dag->all[dag_root_ctr]->instr->read_write);
-           csp_set_print(csound, 
+           csp_set_print(csound,
                          dag->all[dag_curr_ctr]->instr->read_write); */
 
         if (depends & DAG_STRONG_LINK) {
@@ -1433,12 +1423,9 @@ inline static void csp_dag_build_edges(CSOUND *csound, DAG *dag)
     }
 }
 
-static void csp_dag_build_roots(CSOUND *csound, DAG *dag)
+static void csp_dag_build_roots(DAG *dag)
 {
     int col = 0;
-#ifdef CAUTIOUS
-    if (dag == NULL) csound->Die(csound, Str("Invalid NULL Parameter dag"));
-#endif
 
     while (col < dag->count) {
       int exists_in = 0;
@@ -1461,14 +1448,14 @@ static void csp_dag_build_roots(CSOUND *csound, DAG *dag)
     }
 }
 
-inline static void csp_dag_prepare_use_first(CSOUND *csound, DAG *dag)
+inline static void csp_dag_prepare_use_first(DAG *dag)
 {
 
     memcpy(dag->table[0], dag->table_ori[0],
            sizeof(uint8_t) * dag->count * dag->count);
 }
 
-static void csp_dag_prepare_use(CSOUND *csound, DAG *dag)
+static void csp_dag_prepare_use(DAG *dag)
 {
  #ifdef CAUTIOUS
     if (dag == NULL) csound->Die(csound, Str("Invalid NULL Parameter dag"));
@@ -1483,8 +1470,7 @@ static void csp_dag_prepare_use(CSOUND *csound, DAG *dag)
     dag->root_seen[dag->first_root] = 2;
 }
 
-static inline void csp_dag_prepare_use_insds(CSOUND *csound,
-                                             DAG *dag, INSDS *chain)
+static inline void csp_dag_prepare_use_insds(DAG *dag, INSDS *chain)
 {
     DAG_NODE *node;
 #ifdef CAUTIOUS
@@ -1502,10 +1488,25 @@ static inline void csp_dag_prepare_use_insds(CSOUND *csound,
     }
 }
 
-static void csp_dag_calculate_max_roots(CSOUND *csound, DAG *dag)
+inline int csp_dag_is_finished(DAG *dag)
 {
-    INSTR_SEMANTICS *instr = NULL;
-    INSDS *insds = NULL;
+#ifdef CAUTIOUS
+    if (dag == NULL)
+      csound->Die(csound, Str("Invalid NULL Parameter dag"));
+#endif
+    /* TAKE_LOCK(&(dag->spinlock));
+       int res = (dag->remaining <= 0);
+       RELS_LOCK(&(dag->spinlock));
+       return res;
+    */
+    TRACE_5("DAG is finished %d\n", dag->remaining <= 0);
+    return (dag->remaining <= 0);
+}
+
+static void csp_dag_calculate_max_roots(DAG *dag)
+{
+    //INSTR_SEMANTICS *instr = NULL;
+    //INSDS *insds = NULL;
     DAG_NODE *node;
     int update_hdl = -1;
 
@@ -1513,7 +1514,7 @@ static void csp_dag_calculate_max_roots(CSOUND *csound, DAG *dag)
     if (dag == NULL) csound->Die(csound, Str("Invalid NULL Parameter dag"));
 #endif
 
-    while (!csp_dag_is_finished(csound, dag)) {
+    while (!csp_dag_is_finished(dag)) {
       int ctr = 0, roots_avail = 0;
       while (ctr < dag->count) {
         if (dag->roots[ctr] != NULL) {
@@ -1524,12 +1525,10 @@ static void csp_dag_calculate_max_roots(CSOUND *csound, DAG *dag)
       if (roots_avail > dag->max_roots) {
         dag->max_roots = roots_avail;
       }
-      csp_dag_consume(csound, dag, &node, &update_hdl);
-      instr = node->instr;
-      insds = node->insds;
+      csp_dag_consume(dag, &node, &update_hdl);
 
-      if (insds != NULL) {
-        csp_dag_consume_update(csound, dag, update_hdl);
+      if (node->insds != NULL) {
+        csp_dag_consume_update(dag, update_hdl);
       }
     }
 }
@@ -1547,35 +1546,20 @@ void csp_dag_build(CSOUND *csound, DAG **dag, INSDS *chain)
     *dag = csp_dag_build_initial(csound, chain);
     csp_dag_build_prepare(csound, *dag);
     csp_dag_build_edges(csound, *dag);
-    csp_dag_build_roots(csound, *dag);
-    csp_dag_prepare_use_first(csound, *dag);
-    csp_dag_prepare_use(csound, *dag);
+    csp_dag_build_roots(*dag);
+    csp_dag_prepare_use_first(*dag);
+    csp_dag_prepare_use(*dag);
 
-    csp_dag_calculate_max_roots(csound, *dag);
-    csp_dag_prepare_use(csound, *dag);
+    csp_dag_calculate_max_roots(*dag);
+    csp_dag_prepare_use(*dag);
     TRACE_5("DAG BUILT\n");
 }
 
-int inline csp_dag_is_finished(CSOUND *csound, DAG *dag)
-{
-#ifdef CAUTIOUS
-    if (dag == NULL)
-      csound->Die(csound, Str("Invalid NULL Parameter dag"));
-#endif
-    /* TAKE_LOCK(&(dag->spinlock));
-       int res = (dag->remaining <= 0);
-       RELS_LOCK(&(dag->spinlock));
-       return res;
-    */
-    TRACE_5("DAG is finished %d\n", dag->remaining <= 0);
-    return (dag->remaining <= 0);
-}
-
 /*
  * consume an instr and update the first root cache
  */
 //static int waiting_for_ending=0;
-void csp_dag_consume(CSOUND *csound, DAG *dag,
+void csp_dag_consume(DAG *dag,
                      DAG_NODE **node, int *update_hdl)
 {
     DAG_NODE *dag_node = NULL;
@@ -1670,7 +1654,7 @@ void csp_dag_consume(CSOUND *csound, DAG *dag,
 /*
  * update the roots countdown and roots after consumeing a node
  */
-void csp_dag_consume_update(CSOUND *csound, DAG *dag, int update_hdl)
+void csp_dag_consume_update(DAG *dag, int update_hdl)
 {
     int col = 0;
     TRACE_5("DAG update\n");
@@ -1724,7 +1708,7 @@ void csp_dag_consume_update(CSOUND *csound, DAG *dag, int update_hdl)
             csp_thread_index_get(csound), dag->first_root, dag->consume_spinlock);
 }
 
-static char *csp_dag_string(CSOUND *csound, DAG *dag)
+static char *csp_dag_string(DAG *dag)
 {
 #define DAG_2_BUF 8196
     char buf[DAG_2_BUF];
@@ -1818,7 +1802,7 @@ static char *csp_dag_string(CSOUND *csound, DAG *dag)
 
 void csp_dag_print(CSOUND *csound, DAG *dag)
 {
-    char *str = csp_dag_string(csound, dag);
+    char *str = csp_dag_string(dag);
     if (str != NULL) {
       csound->Message(csound, "%s", str);
       free(str);
@@ -1860,11 +1844,9 @@ void csp_dag_print(CSOUND *csound, DAG *dag)
 #endif
 }
 
-/**********************************************************************************************
+/************************************************************************
  * dag2 optimization structure
  */
-#pragma mark -
-#pragma mark Dag2 optimization
 
 static uint64_t dag_opt_counter;
 
@@ -2103,7 +2085,8 @@ void csp_dag_optimization(CSOUND *csound, DAG *dag)
 #if TRACE > 1
         ctr = 0;
         while (ctr < dag->count) {
-          csound->Message(csound, "%i -> %i\n", ctr, map_old_to_new_locations[ctr]);
+          csound->Message(csound,
+                          "%i -> %i\n", ctr, map_old_to_new_locations[ctr]);
           ctr++;
         }
 #endif
@@ -2171,12 +2154,12 @@ void csp_dag_optimization(CSOUND *csound, DAG *dag)
     memset(dag->remaining_count_ori, 0, sizeof(int) * dag_table_original_size);
     dag->max_roots = 0;
 
-    csp_dag_build_roots(csound, dag);
-    /* csp_dag_prepare_use_first(csound, dag); */
-    csp_dag_prepare_use(csound, dag);
+    csp_dag_build_roots(dag);
+    /* csp_dag_prepare_use_first(dag); */
+    csp_dag_prepare_use(dag);
 
-    csp_dag_calculate_max_roots(csound, dag);
-    csp_dag_prepare_use(csound, dag);
+    csp_dag_calculate_max_roots(dag);
+    csp_dag_prepare_use(dag);
     //    csp_dag_print(csound, dag);
 
 
@@ -2186,11 +2169,9 @@ void csp_dag_optimization(CSOUND *csound, DAG *dag)
 #endif
 }
 
-/**********************************************************************************************
+/*********************************************************************
  * dag2 cache structure
  */
-#pragma mark -
-#pragma mark Dag2 Cache
 
 /* #ifdef LINEAR_CACHE */
 
@@ -2211,7 +2192,8 @@ void csp_dag_optimization(CSOUND *csound, DAG *dag)
 /* #define DAG_2_CACHE_SIZE     100 */
 /* #define DAG_2_DECAY_COMP     1 */
 /* #define DAG_2_MIN_USE_LIMIT  5000 */
-/* /\* aiming for 8 passes of the cache update before a new entry must exist solely on its usage *\/ */
+/* /\* aiming for 8 passes of the cache update before a new entry must */
+/*     exist solely on its usage *\/ */
 /* #define DAG_2_MIN_AGE_LIMIT  256 */
 /* #define DAG_2_AGE_START      131072 */
 
@@ -2220,8 +2202,9 @@ void csp_dag_optimization(CSOUND *csound, DAG *dag)
 /* static int csp_dag_cache_entry_alloc(CSOUND *csound, */
 /*                                      struct dag_cache_entry_t **entry, */
 /*                                      INSDS *chain); */
-/* static int csp_dag_cache_compare(CSOUND *csound */
-/*                                  , struct dag_cache_entry_t *entry, INSDS *chain); */
+/* static int csp_dag_cache_compare(CSOUND *csound, */
+/*                                  struct dag_cache_entry_t *entry, */
+/*                                  INSDS *chain); */
 /* static void csp_dag_cache_update(CSOUND *csound); */
 
 /* void csp_dag_cache_print(CSOUND *csound) */
@@ -2244,7 +2227,8 @@ void csp_dag_optimization(CSOUND *csound, DAG *dag)
 /* } */
 
 /* static int csp_dag_cache_entry_alloc(CSOUND *csound, */
-/*                                      struct dag_cache_entry_t **entry, INSDS *chain) */
+/*                                      struct dag_cache_entry_t **entry, */
+/*                                      INSDS *chain) */
 /* { */
 /*     int ctr = 0; */
 /*     INSDS *current_insds = chain; */
@@ -2262,11 +2246,12 @@ void csp_dag_optimization(CSOUND *csound, DAG *dag)
 /*     } */
 
 /*     *entry = csound->Malloc(csound, */
-/*                             sizeof(struct dag_cache_entry_t) + sizeof(int16) * ctr); */
+/*                             sizeof(struct dag_cache_entry_t) + */
+/*                             sizeof(int16) * ctr); */
 /*     if (UNLIKELY(*entry == NULL)) { */
 /*       csound->Die(csound, Str("Failed to allocate Dag2 cache")); */
 /*     } */
-/*     memset(*entry, 0, sizeof(struct dag_cache_entry_t) + sizeof(int16) * ctr); */
+/*     memset(*entry, 0, sizeof(struct dag_cache_entry_t)+sizeof(int16)*ctr); */
 /*     (*entry)->uses   = 1; */
 /*     (*entry)->age    = DAG_2_AGE_START; */
 /*     (*entry)->instrs = ctr; */
@@ -2330,14 +2315,15 @@ void csp_dag_optimization(CSOUND *csound, DAG *dag)
 /* } */
 
 /* static int csp_dag_cache_compare(CSOUND *csound, */
-/*                                  struct dag_cache_entry_t *entry, INSDS *chain) */
+/*                                  struct dag_cache_entry_t *entry, */
+/*                                  INSDS *chain) */
 /* { */
 /*     INSDS *current_insds = chain; */
 /*     int32_t ctr = 0; */
 
 /* #ifdef CAUTIOUS */
-/*     if (entry == NULL) csound->Die(csound, Str("Invalid NULL Parameter entry")); */
-/*     if (chain == NULL) csound->Die(csound, Str("Invalid NULL Parameter chain")); */
+/*   if (entry == NULL) csound->Die(csound, Str("Invalid NULL Parameter entry")); */
+/*   if (chain == NULL) csound->Die(csound, Str("Invalid NULL Parameter chain")); */
 /* #endif */
 
 /*     while (current_insds != NULL && ctr < entry->instrs) { */
@@ -2382,8 +2368,8 @@ void csp_dag_optimization(CSOUND *csound, DAG *dag)
 
 /*         curr->uses++; */
 
-/*         csp_dag_prepare_use_insds(csound, curr->dag, chain); */
-/*         csp_dag_prepare_use(csound, curr->dag); */
+/*         csp_dag_prepare_use_insds(curr->dag, chain); */
+/*         csp_dag_prepare_use(curr->dag); */
 /*         break; */
 /*       } */
 /*       curr = curr->next; */
@@ -2435,8 +2421,7 @@ static uint32_t update_ctr;
 static int csp_dag_cache_entry_alloc(CSOUND *csound,
                                      struct dag_cache_entry_t **entry,
                                      INSDS *chain, uint32_t hash_val);
-static int csp_dag_cache_compare(CSOUND *csound,
-                                 struct dag_cache_entry_t *entry, INSDS *chain);
+static int csp_dag_cache_compare(struct dag_cache_entry_t *entry, INSDS *chain);
 #if 0
 static int csp_dag_cache_entry_dealloc(CSOUND *csound,
                                        struct dag_cache_entry_t **entry);
@@ -2473,13 +2458,15 @@ void csp_dag_cache_print(CSOUND *csound)
         else if (entry->dag->weight < weight_min) weight_min = entry->dag->weight;
 
         instr_num_sum += entry->instrs;
-        if (entry->instrs > instr_num_max) instr_num_max = entry->instrs;
-        else if (entry->instrs < instr_num_min) instr_num_min = entry->instrs;
+        if ((uint32_t)entry->instrs > instr_num_max)
+          instr_num_max = entry->instrs;
+        else if ((uint32_t)entry->instrs < instr_num_min)
+          instr_num_min = entry->instrs;
 
         root_avail_sum += entry->dag->max_roots;
-        if (entry->dag->max_roots > root_avail_max)
+        if ((uint32_t)entry->dag->max_roots > root_avail_max)
           root_avail_max = entry->dag->max_roots;
-        else if (entry->dag->max_roots < root_avail_min)
+        else if ((uint32_t)entry->dag->max_roots < root_avail_min)
           root_avail_min = entry->dag->max_roots;
 
         entry = entry->next;
@@ -2551,7 +2538,7 @@ static void csp_dag_cache_print_weights_dump(CSOUND *csound)
         fprintf(f, "%u\n", dag->weight);
         fprintf(f, "%u\n", dag->max_roots);
 
-        dag_str = csp_dag_string(csound, dag);
+        dag_str = csp_dag_string(dag);
         if (dag_str != NULL) {
           fprintf(f, "%s", dag_str);
           free(dag_str);
@@ -2682,8 +2669,7 @@ static void csp_dag_cache_update(CSOUND *csound)
 }
 #endif
 
-static int csp_dag_cache_compare(CSOUND *csound,
-                                 struct dag_cache_entry_t *entry, INSDS *chain)
+static int csp_dag_cache_compare(struct dag_cache_entry_t *entry, INSDS *chain)
 {
 #ifdef CAUTIOUS
     if (entry == NULL) csound->Die(csound, Str("Invalid NULL Parameter entry"));
@@ -2730,7 +2716,7 @@ void csp_dag_cache_fetch(CSOUND *csound, DAG **dag, INSDS *chain)
 
 /* #ifdef HYBRID_HASH_CACHE */
 /*     if (cache_last != NULL && */
-/*         csp_dag_cache_compare(csound, cache_last, chain)) { */
+/*         csp_dag_cache_compare(cache_last, chain)) { */
 /*       struct dag_cache_entry_t *curr = cache_last; */
 /* #if TRACE > 4 */
 /*       csound->Message(csound, "Cache Hit (Last) [%i]\n", cache_ctr); */
@@ -2739,8 +2725,8 @@ void csp_dag_cache_fetch(CSOUND *csound, DAG **dag, INSDS *chain)
 /*       TAKE_LOCK(&(curr->dag->consume_spinlock)); */
 /*       curr->uses++; */
 
-/*       csp_dag_prepare_use_insds(csound, curr->dag, chain); */
-/*       csp_dag_prepare_use(csound, curr->dag); */
+/*       csp_dag_prepare_use_insds(curr->dag, chain); */
+/*       csp_dag_prepare_use(curr->dag); */
 /*       RELS_LOCK(&(curr->dag->consume_spinlock)); */
 /*       return; */
 /*     } */
@@ -2749,7 +2735,7 @@ void csp_dag_cache_fetch(CSOUND *csound, DAG **dag, INSDS *chain)
     uint32_t hash_val = hash_chain(chain, DAG_2_CACHE_SIZE);
     struct dag_cache_entry_t *curr = csound->cache[hash_val];
     while (curr != NULL) {
-      if (csp_dag_cache_compare(csound, curr, chain)) {
+      if (csp_dag_cache_compare(curr, chain)) {
         TRACE_2("Cache Hit [%i]\n", cache_ctr);
 
         *dag = curr->dag;
@@ -2757,8 +2743,8 @@ void csp_dag_cache_fetch(CSOUND *csound, DAG **dag, INSDS *chain)
         TAKE_LOCK(&(curr->dag->consume_spinlock));
         curr->uses++;
 
-        csp_dag_prepare_use_insds(csound, curr->dag, chain);
-        csp_dag_prepare_use(csound, curr->dag);
+        csp_dag_prepare_use_insds(curr->dag, chain);
+        csp_dag_prepare_use(curr->dag);
 /* #ifdef HYBRID_HASH_CACHE */
 /*         cache_last = curr; */
 /* #endif */
@@ -2783,6 +2769,7 @@ void csp_dag_cache_fetch(CSOUND *csound, DAG **dag, INSDS *chain)
 
 #endif
 
+#ifdef TESTING
 static long x = 0;
 
 int waste_time(CSOUND* csound, WASTE *p)
@@ -2793,3 +2780,4 @@ int waste_time(CSOUND* csound, WASTE *p)
     for (k=0; k<n; k++) x = (x+1)^1234;
     return OK;
 }
+#endif
