@@ -90,7 +90,7 @@ static TREE * optimize_ifun(CSOUND *csound, TREE *root)
 }
 
 /** Verifies and optimise; constant fold and opcodes and args are correct*/
-static TREE * verify_tree1(CSOUND *csound, TREE *root) 
+static TREE * verify_tree1(CSOUND *csound, TREE *root)
 {
     TREE *ans, *last;
     double lval, rval;
@@ -110,7 +110,7 @@ static TREE * verify_tree1(CSOUND *csound, TREE *root)
           last = last->next;
         }
       }
-      if (root->right->type == T_FUNCTION &&                 
+      if (root->right->type == T_FUNCTION &&
           (strcmp(root->right->value->lexeme, "i") == 0)) {  /* i() function */
         root->right = optimize_ifun(csound, root->right);
       }
@@ -121,7 +121,7 @@ static TREE * verify_tree1(CSOUND *csound, TREE *root)
       }
       root->right = verify_tree1(csound, root->right);
       if (root->left) {
-        if (root->left->type == T_FUNCTION &&                 
+        if (root->left->type == T_FUNCTION &&
             (strcmp(root->left->value->lexeme, "i") == 0)) {  /* i() function */
           root->left = optimize_ifun(csound, root->left);
         }
@@ -136,43 +136,46 @@ static TREE * verify_tree1(CSOUND *csound, TREE *root)
           rval = (root->right->type == INTEGER_TOKEN ?
                   (double)root->right->value->value :root->right->value->fvalue);
           ans = root->left;
-          ans->type = ans->value->type = NUMBER_TOKEN;
           /* **** Something wrong here -- subtraction confuses memory **** */
           switch (root->type) {
           case '+':
+            ans->type = ans->value->type = NUMBER_TOKEN;
             ans->value->fvalue = lval+rval;
             ans->value->lexeme =
               (char*)mrealloc(csound, ans->value->lexeme, 24);
             sprintf(ans->value->lexeme, "%f", ans->value->fvalue);
             ans->next = root->next;
-            //Memory leak!! 
+            //Memory leak!!
             //mfree(csound, root); mfree(csound root->right);
             return ans;
           case '-':
+            ans->type = ans->value->type = NUMBER_TOKEN;
             ans->value->fvalue = lval-rval;
             ans->value->lexeme =
               (char*)mrealloc(csound, ans->value->lexeme, 24);
             sprintf(ans->value->lexeme, "%f", ans->value->fvalue);
             ans->next = root->next;
-            //Memory leak!! 
+            //Memory leak!!
             //mfree(csound, root); mfree(csound, root->right);
             return ans;
           case '*':
+            ans->type = ans->value->type = NUMBER_TOKEN;
             ans->value->fvalue = lval*rval;
             ans->value->lexeme =
               (char*)mrealloc(csound, ans->value->lexeme, 24);
             sprintf(ans->value->lexeme, "%f", ans->value->fvalue);
             ans->next = root->next;
-            //Memory leak!! 
+            //Memory leak!!
             //mfree(csound, root); mfree(csound, root->right);
             return ans;
           case '/':
+            ans->type = ans->value->type = NUMBER_TOKEN;
             ans->value->fvalue = lval/rval;
             ans->value->lexeme =
               (char*)mrealloc(csound, ans->value->lexeme, 24);
             sprintf(ans->value->lexeme, "%f", ans->value->fvalue);
             ans->next = root->next;
-            //Memory leak!! 
+            //Memory leak!!
             //mfree(csound, root); mfree(csound, root->right);
             return ans;
             /* case S_NEQ: */
@@ -218,7 +221,7 @@ static TREE * verify_tree1(CSOUND *csound, TREE *root)
     return root;
 }
 
-TREE * verify_tree(CSOUND *csound, TREE *root) 
+TREE * verify_tree(CSOUND *csound, TREE *root)
 {
     TREE *original=root, *last = NULL;
     while (root) {
@@ -260,7 +263,7 @@ void csound_orcerror(PARSE_PARM *pp, void *yyscanner,
     /*  csound->Message(csound, Str("error: %s (\"\\n\")"), */
     /*                 str); */
     /*  csound->Message(csound, Str(" line %d:\n>>> "), */
-    /*     	     csound_orcget_lineno(yyscanner)); */
+    /*               csound_orcget_lineno(yyscanner)); */
     /* } */
     /* else { */
     /*  csound->Message(csound, Str("\nerror: %s  (token \"%s\")"), */
@@ -283,7 +286,7 @@ void csound_orcerror(PARSE_PARM *pp, void *yyscanner,
  * down the linked list to append at end; checks for NULL's and returns
  * appropriate nodes
  */
-TREE* appendToTree(CSOUND * csound, TREE *first, TREE *newlast) {
+TREE* appendToTree(TREE *first, TREE *newlast) {
     TREE *current;
     if (first == NULL) {
         return newlast;
@@ -791,38 +794,44 @@ void handle_optional_args(CSOUND *csound, TREE *l)
         switch (ep->intypes[incnt]) {
         case 'O':             /* Will this work?  Doubtful code.... */
         case 'o':
-          temp = make_leaf(csound, l->line, l->locn, INTEGER_TOKEN, make_int(csound, "0"));
+          temp = make_leaf(csound, l->line, l->locn,
+                           INTEGER_TOKEN, make_int(csound, "0"));
           if (l->right==NULL) l->right = temp;
-          else appendToTree(csound, l->right, temp);
+          else appendToTree(l->right, temp);
           break;
         case 'P':
         case 'p':
-          temp = make_leaf(csound, l->line, l->locn, INTEGER_TOKEN, make_int(csound, "1"));
+          temp = make_leaf(csound, l->line, l->locn,
+                           INTEGER_TOKEN, make_int(csound, "1"));
           if (l->right==NULL) l->right = temp;
-          else appendToTree(csound, l->right, temp);
+          else appendToTree(l->right, temp);
           break;
         case 'q':
-          temp = make_leaf(csound, l->line, l->locn, INTEGER_TOKEN, make_int(csound, "10"));
+          temp = make_leaf(csound, l->line, l->locn,
+                           INTEGER_TOKEN, make_int(csound, "10"));
           if (l->right==NULL) l->right = temp;
-          else appendToTree(csound, l->right, temp);
+          else appendToTree(l->right, temp);
           break;
 
         case 'V':
         case 'v':
-          temp = make_leaf(csound, l->line, l->locn, NUMBER_TOKEN, make_num(csound, ".5"));
+          temp = make_leaf(csound, l->line, l->locn,
+                           NUMBER_TOKEN, make_num(csound, ".5"));
           if (l->right==NULL) l->right = temp;
-          else appendToTree(csound, l->right, temp);
+          else appendToTree(l->right, temp);
           break;
         case 'h':
-          temp = make_leaf(csound, l->line, l->locn, INTEGER_TOKEN, make_int(csound, "127"));
+          temp = make_leaf(csound, l->line, l->locn,
+                           INTEGER_TOKEN, make_int(csound, "127"));
           if (l->right==NULL) l->right = temp;
-          else appendToTree(csound, l->right, temp);
+          else appendToTree(l->right, temp);
           break;
         case 'J':
         case 'j':
-          temp = make_leaf(csound, l->line, l->locn, INTEGER_TOKEN, make_int(csound, "-1"));
+          temp = make_leaf(csound, l->line, l->locn,
+                           INTEGER_TOKEN, make_int(csound, "-1"));
           if (l->right==NULL) l->right = temp;
-          else appendToTree(csound, l->right, temp);
+          else appendToTree(l->right, temp);
           break;
         case 'M':
         case 'N':
@@ -831,7 +840,8 @@ void handle_optional_args(CSOUND *csound, TREE *l)
           break;
         default:
           synterr(csound,
-                  Str("insufficient required arguments for opcode %s on line %d\n"),
+                  Str("insufficient required arguments for "
+                      "opcode %s on line %d\n"),
                   ep->opname, l->line, l->locn);
         }
         incnt++;
