@@ -212,6 +212,7 @@ OENTRY opcodlst_1[] = {
 { "taninv.i", S(EVAL),  1,      "i",    "i",    atan1                   },
 { "taninv2.i",S(AOP),   1,      "i",    "ii",   atan21                  },
 { "log10.i",S(EVAL),    1,      "i",    "i",    log101                  },
+{ "log2.i",S(EVAL),     1,      "i",    "i",    log21                   },
 { "sinh.i", S(EVAL),    1,      "i",    "i",    sinh1                   },
 { "cosh.i", S(EVAL),    1,      "i",    "i",    cosh1                   },
 { "tanh.i", S(EVAL),    1,      "i",    "i",    tanh1                   },
@@ -239,6 +240,7 @@ OENTRY opcodlst_1[] = {
 { "cosh.k", S(EVAL),    2,      "k",    "k",    NULL,   cosh1           },
 { "tanh.k", S(EVAL),    2,      "k",    "k",    NULL,   tanh1           },
 { "log10.k",S(EVAL),    2,      "k",    "k",    NULL,   log101          },
+{ "log2.k",S(EVAL),     2,      "k",    "k",    NULL,   log21           },
 { "int.a",  S(EVAL),    4,      "a",    "a",    NULL, NULL, int1a       },
 { "frac.a", S(EVAL),    4,      "a",    "a",    NULL, NULL, frac1a      },
 { "round.a",S(EVAL),    4,      "a",    "a",    NULL, NULL, int1a_round },
@@ -261,6 +263,7 @@ OENTRY opcodlst_1[] = {
 { "cosh.a", S(EVAL),    4,      "a",    "a",    NULL,   NULL,   cosha   },
 { "tanh.a", S(EVAL),    4,      "a",    "a",    NULL,   NULL,   tanha   },
 { "log10.a",S(EVAL),    4,      "a",    "a",    NULL,   NULL,   log10a  },
+{ "log2.a",S(EVAL),     4,      "a",    "a",    NULL,   NULL,   log2a   },
 { "ampdb.a",S(EVAL),    4,      "a",    "a",    NULL,   NULL,   aampdb  },
 { "ampdb.i",S(EVAL),    1,      "i",    "i",    ampdb                   },
 { "ampdb.k",S(EVAL),    2,      "k",    "k",    NULL,   ampdb           },
@@ -321,20 +324,23 @@ OENTRY opcodlst_1[] = {
 { "chanctrl.k",S(CHANCTL),3,    "k",    "iioh", chctlset,chanctl        },
 { "line",   S(LINE),    7,      "s",    "iii",  linset, kline,  aline   },
 { "expon",  S(EXPON),   7,      "s",    "iii",  expset, kexpon, expon   },
+{ "cosseg", S(COSSEG),  7,      "s",    "iin",  csgset, kosseg, cosseg  },
+{ "cossegb", S(COSSEG), 7,      "s",    "iin",  csgset_bkpt, kosseg, cosseg  },
+{ "cossegr", S(COSSEG),  7,     "s",    "iin",  csgrset, kcssegr, cossegr  },
 { "linseg", S(LINSEG),  7,      "s",    "iin",  lsgset, klnseg, linseg  },
-{ "linsegb", S(LINSEG),  7,      "s",    "iin", lsgset_bkpt, klnseg, linseg  },
+{ "linsegb", S(LINSEG), 7,      "s",    "iin",  lsgset_bkpt, klnseg, linseg  },
 { "linsegr",S(LINSEG),  7,      "s",    "iin",  lsgrset,klnsegr,linsegr },
 { "expseg", S(EXXPSEG),  7,     "s",    "iin",  xsgset, kxpseg, expseg  },
-{ "expsegb", S(EXXPSEG),  7,     "s",    "iin",  xsgset_bkpt, kxpseg, expseg  },
+{ "expsegb", S(EXXPSEG),  7,    "s",    "iin",  xsgset_bkpt, kxpseg, expseg  },
 { "expsega",S(EXPSEG2),  7,     "a",    "iin",  xsgset2, NULL, expseg2  },
-{ "expsegba",S(EXPSEG2),  7,     "a",    "iin",  xsgset2b, NULL, expseg2  },
+{ "expsegba",S(EXPSEG2),  7,    "a",    "iin",  xsgset2b, NULL, expseg2  },
 { "expsegr",S(EXPSEG),  7,      "s",    "iin",  xsgrset,kxpsegr,expsegr },
 { "linen",  S(LINEN),   7,      "s",    "xiii", lnnset, klinen, linen   },
 { "linenr", S(LINENR),  7,      "s",    "xiii", lnrset, klinenr,linenr  },
 { "envlpx", S(ENVLPX),  TR|7,   "s","xiiiiiio", evxset, knvlpx, envlpx  },
 { "envlpxr", S(ENVLPR), TR|7,   "s","xiiiiioo", evrset, knvlpxr,envlpxr },
 { "phasor", S(PHSOR),   7,      "s",    "xo",   phsset, kphsor, phsor   },
-{ "ephasor", S(EPHSOR),  5,    "ss",    "xko",  ephsset, NULL, ephsor   },
+{ "ephasor", S(EPHSOR),  5,     "ss",    "xko",  ephsset, NULL, ephsor  },
 { "table",  0xffff, TR                                                  },
 { "tablei", 0xffff, TR                                                  },
 { "table3", 0xffff, TR                                                  },
@@ -413,8 +419,8 @@ OENTRY opcodlst_1[] = {
 { "pan",    S(PAN),   5, "aaaa", "akkioo",(SUBR)panset,NULL, (SUBR)pan  },
 { "soundin",S(SOUNDIN_),5,"mmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmm","Toooo",
                                                 sndinset, NULL, soundin   },
-{ "soundout",S(SNDOUT), DP|5,   "",     "aTo",  sndo1set, NULL, soundout  },
-{ "soundouts",S(SNDOUTS),DP|5,  "",     "aaTo", sndo1set, NULL, soundouts },
+{ "soundout",S(SNDOUT), _QQ|5,   "",     "aTo",  sndo1set, NULL, soundout  },
+{ "soundouts",S(SNDOUTS),_QQ|5,  "",     "aaTo", sndo1set, NULL, soundouts },
 { "in",     S(INM),     4,      "a",    "",     NULL,   NULL,   in      },
 { "ins",    S(INS),     4,      "aa",   "",     NULL,   NULL,   ins     },
 { "inq",    S(INQ),     4,      "aaaa", "",     NULL,   NULL,   inq     },
@@ -505,10 +511,11 @@ OENTRY opcodlst_1[] = {
 { "unirand.i",S(PRAND), 1,     "i",     "k",    ikuniform, NULL,  NULL  },
 { "unirand.k",S(PRAND), 2,     "k",     "k",    NULL,    ikuniform, NULL},
 { "unirand.a",S(PRAND), 4,     "a",     "k",    NULL,    NULL, auniform },
-{ "diskin",S(SOUNDINEW),DP|5, "mmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmm", 
+
+{ "diskin",S(SOUNDINEW),_QQ|5, "mmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmm",
                             "Tkooooo",
                             (SUBR) newsndinset, NULL, (SUBR) soundinew  },
-{ "diskin2",S(DISKIN2), 5,  "mmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmm", 
+{ "diskin2",S(DISKIN2), 5,  "mmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmm",
                             "Tkoooooo",
                             (SUBR) diskin2_init, (SUBR) NULL,
                             (SUBR) diskin2_perf                         },
@@ -573,7 +580,7 @@ OENTRY opcodlst_1[] = {
 { "tableicopy",S(TABLECOPY),TB|1, "", "ii",   (SUBR)itablecopy, NULL, NULL},
 { "tablecopy", S(TABLECOPY),TB|2, "", "kk",
                                       (SUBR)tablecopyset, (SUBR)tablecopy, NULL},
-{ "tablera", S(TABLERA),TR|5,   "a",  "kkk",  
+{ "tablera", S(TABLERA),TR|5,   "a",  "kkk",
                                       (SUBR)tableraset, NULL, (SUBR)tablera},
 { "tablewa", S(TABLEWA),TW|5,   "k",  "kak",
                                       (SUBR)tablewaset, NULL, (SUBR)tablewa},
@@ -657,7 +664,7 @@ OENTRY opcodlst_1[] = {
 { "event", S(LINEVENT),  2,     "",     "SUz",  NULL, eventOpcode, NULL   },
 { "event_i", S(LINEVENT),1,     "",     "STm",  eventOpcodeI, NULL, NULL  },
 { "lfo", S(LFO),         7,     "s",    "kko",  lfoset,   lfok,   lfoa    },
-{ "oscils",   S(OSCILS), 5,     "a", "iiio",     
+{ "oscils",   S(OSCILS), 5,     "a", "iiio",
                                          (SUBR)oscils_set, NULL, (SUBR)oscils },
 { "lphasor",  S(LPHASOR),5,     "a", "xooooooo" ,
                                          (SUBR)lphasor_set, NULL, (SUBR)lphasor },
@@ -665,10 +672,10 @@ OENTRY opcodlst_1[] = {
                                          (SUBR)tablexkt_set, NULL, (SUBR)tablexkt },
 { "reverb2",  S(NREV2),  5,     "a",    "akkoojoj",
                                          (SUBR)reverbx_set,NULL,(SUBR)reverbx },
-{ "nreverb",  S(NREV2),  5,     "a",    "akkoojoj", 
+{ "nreverb",  S(NREV2),  5,     "a",    "akkoojoj",
                                          (SUBR)reverbx_set,NULL,(SUBR) reverbx },
-{ "=.f",      S(FASSIGN), 2,    "f",   "f",      NULL, fassign, NULL    },
-{ "init.f",   S(FASSIGN), 2,    "f",   "f",      fassign, NULL, NULL    },
+{ "=.f",      S(FASSIGN), 3,    "f",   "f",      (SUBR)fassign_set,(SUBR) fassign, NULL    },
+{ "init.f",   S(FASSIGN), 1,    "f",   "f",      (SUBR)fassign_set, NULL, NULL    },
 { "pvsanal",  S(PVSANAL), 5,    "f",   "aiiiioo",  pvsanalset, NULL, pvsanal  },
 { "pvsynth",  S(PVSYNTH), 5,    "a",   "fo",     pvsynthset, NULL, pvsynth  },
 { "pvsadsyn", S(PVADS),   7,    "a",   "fikopo", pvadsynset, pvadsyn, pvadsyn },
@@ -760,7 +767,7 @@ OENTRY opcodlst_1[] = {
 { "a.k",    S(INTERP),  5,  "a", "k",    (SUBR)a_k_set,NULL,   (SUBR)interp  },
 { "integ", S(INDIFF), 7, "s", "xo", (SUBR)indfset,(SUBR)kntegrate,(SUBR)integrate},
 { "diff",   S(INDIFF),  7,  "s", "xo",   (SUBR)indfset,(SUBR)kdiff, (SUBR)diff },
-{ "samphold",S(SAMPHOLD),7, "s", "xxoo", 
+{ "samphold",S(SAMPHOLD),7, "s", "xxoo",
                                  (SUBR)samphset,(SUBR)ksmphold,(SUBR)samphold},
 { "delay",  S(DELAY),   5,  "a", "aio",  (SUBR)delset, NULL,   (SUBR)delay   },
 { "delayr", S(DELAYR),  5,  "aX","io",   (SUBR)delrset,NULL,   (SUBR)delayr  },
@@ -773,7 +780,7 @@ OENTRY opcodlst_1[] = {
 { "reverb", S(REVERB),  5,  "a", "ako",  (SUBR)rvbset, NULL,   (SUBR)reverb  },
 { "vdelay",   S(VDEL),  5,  "a", "axio", (SUBR)vdelset, NULL,  (SUBR)vdelay  },
 { "vdelay3",  S(VDEL),  5,  "a", "axio", (SUBR)vdelset, NULL,  (SUBR)vdelay3 },
-{ "vdelayxwq",S(VDELXQ),5,  "aaaa", "aaaaaiio", 
+{ "vdelayxwq",S(VDELXQ),5,  "aaaa", "aaaaaiio",
                                          (SUBR)vdelxqset, NULL, (SUBR)vdelayxwq},
 { "vdelayxws",S(VDELXS),5,  "aa", "aaaiio", (SUBR)vdelxsset, NULL, (SUBR)vdelayxws},
 { "vdelayxw", S(VDELX), 5,  "a",  "aaiio", (SUBR)vdelxset, NULL, (SUBR)vdelayxw},
@@ -786,6 +793,7 @@ OENTRY opcodlst_1[] = {
 { "multitap", S(MDEL),  5,   "a", "am",
                                    (SUBR)multitap_set,NULL,(SUBR)multitap_play},
 { "comb",   S(COMB),    5,  "a",  "akioo", (SUBR)cmbset,NULL,   (SUBR)comb    },
+{ "combinv",S(COMB),    5,  "a",  "akioo", (SUBR)cmbset,NULL,   (SUBR)invcomb },
 { "alpass", S(COMB),    5,  "a",  "akioo", (SUBR)cmbset,NULL,   (SUBR)alpass  },
 {  "strset",   S(STRSET_OP),   1,  "",     "iS",
    (SUBR) strset_init, (SUBR) NULL, (SUBR) NULL                        },
@@ -934,9 +942,9 @@ OENTRY opcodlst_1[] = {
 { "remove",      S(DELETEIN),         1,      "",             "T",
    (SUBR) delete_instr, (SUBR) NULL, (SUBR) NULL                       },
 #ifdef PARCS
-{ "##globallock",   S(GLOBAL_LOCK_UNLOCK), 3, "", "k", 
+{ "##globallock",   S(GLOBAL_LOCK_UNLOCK), 3, "", "k",
                     globallock,   globallock,   NULL},
-{ "##globalunlock", S(GLOBAL_LOCK_UNLOCK), 3, "", "k", 
+{ "##globalunlock", S(GLOBAL_LOCK_UNLOCK), 3, "", "k",
                     globalunlock, globalunlock, NULL},
 #endif
 { "##error",S(ERRFN), 1,          "i",     "i",   error_fn, NULL,    NULL    },
@@ -954,4 +962,3 @@ OENTRY opcodlst_1[] = {
 /* terminate list */
 {  NULL, 0, 0, NULL, NULL, (SUBR) NULL, (SUBR) NULL, (SUBR) NULL       }
 };
-
