@@ -65,6 +65,7 @@ static void set_xtratim(CSOUND *csound, INSDS *ip)
                   csound->ksmps * (double) ip->xtratim)/csound->esr;
     ip->offbet = csound->curBeat + (csound->curBeat_inc * (double) ip->xtratim);
     ip->relesing = 1;
+    csound->instrtxtp[ip->insno]->pending_release++;
 }
 
 /* insert an instr copy into active list */
@@ -75,6 +76,7 @@ int insert(CSOUND *csound, int insno, EVTBLK *newevtp)
     INSTRTXT  *tp;
     INSDS     *ip, *prvp, *nxtp;
     OPARMS    *O = csound->oparms;
+  
 
     if (csound->advanceCnt)
       return 0;
@@ -195,6 +197,7 @@ int insert(CSOUND *csound, int insno, EVTBLK *newevtp)
       if (UNLIKELY(O->odebug))
         csound->Message(csound, "   ending at %p\n", (void*) flp);
     }
+
     if (O->Beatmode)
       ip->p2 = (MYFLT) (csound->icurTime/csound->esr - csound->timeOffs);
     ip->offtim       = (double) ip->p3;         /* & duplicate p3 for now */
@@ -371,7 +374,7 @@ int MIDIinsert(CSOUND *csound, int insno, MCHNBLK *chn, MEVENT *mep)
       MYFLT value = (MYFLT) ip->m_pitch;
       pfields[index] = value;
       if (O->msglevel & WARNMSG) {
-        csound->Message(csound, "  midiKey:         pfield: %3d  value: %.3f\n",
+        csound->Message(csound, "  midiKey:         pfield: %3d  value: %3d\n",
                         pfield, (int) pfields[index]);
       }
     }
@@ -431,7 +434,7 @@ int MIDIinsert(CSOUND *csound, int insno, MCHNBLK *chn, MEVENT *mep)
     }
     else if (O->midiVelocityAmp) {
       int pfield = O->midiVelocityAmp;
-      int index = pfield - 1; 
+      int index = pfield - 1;
       MYFLT *pfields = &ip->p1;
       MYFLT value = (MYFLT) ip->m_veloc;
       value = value * value / FL(16239.0);
@@ -442,17 +445,17 @@ int MIDIinsert(CSOUND *csound, int insno, MCHNBLK *chn, MEVENT *mep)
                         pfield, pfields[index]);
       }
     }
-    /* 
-       the code above assumes &p1 is a pointer to an array of N pfields, but 
+    /*
+       the code above assumes &p1 is a pointer to an array of N pfields, but
        this is wrong. It overwrites memory and uses it for passing p-field
        values. When the overwritten memory is taken to be a pointer in the
        loop below, the loop does not stop at the end of the opcode list
-       and causes iopadr to be garbage, leading to a segfault. 
-       This happens where there is exactly one opcode in an instrument. 
-       It is a nasty bug that needs to be fixed. 
-        
+       and causes iopadr to be garbage, leading to a segfault.
+       This happens where there is exactly one opcode in an instrument.
+       It is a nasty bug that needs to be fixed.
+
        A possible solution is to  allocate always a minimum of 5 p-fields (see line
-       approx 1809 below). The extra p-fields appear to be hanging at the end of 
+       approx 1809 below). The extra p-fields appear to be hanging at the end of
        an INSDS structure, and &p1 appears to be a legal array start address.
        This allows p4 and p5 to be mapped, but no further p-fields (possibly).
 
@@ -520,12 +523,12 @@ static void schedofftim(CSOUND *csound, INSDS *ip)
       ip->nxtoff = nxtp;
       /* IV - Feb 24 2006: check if this note already needs to be turned off */
       /* the following comparisons must match those in sensevents() */
-#ifdef BETA
+      #ifdef BETA
       if (UNLIKELY(csound->oparms->odebug))
         csound->Message(csound,"schedofftim: %lf %lf %f\n",
                         ip->offtim, csound->icurTime/csound->esr,
                         csound->curTime_inc);
-#endif
+      #endif
       if (csound->oparms_.Beatmode) {
         double  tval = csound->curBeat + (0.505 * csound->curBeat_inc);
         if (ip->offbet <= tval) beatexpire(csound, tval);
@@ -563,6 +566,8 @@ static void deact(CSOUND *csound, INSDS *ip)
     if (ip->nxtd != NULL)
       csoundDeinitialiseOpcodes(csound, ip);
     csound->instrtxtp[ip->insno]->active--; /* remove an active instrument */
+    if (ip->xtratim > 0)
+      csound->instrtxtp[ip->insno]->pending_release--;
     csound->cpu_power_busy -= csound->instrtxtp[ip->insno]->cpuload;
     /* IV - Sep 8 2002: free subinstr instances */
     /* that would otherwise result in a memory leak */
@@ -724,7 +729,7 @@ void infoff(CSOUND *csound, MYFLT p1)   /* turn off an indef copy of instr p1 */
             cannot be removed, as it breaks turning off extratime instances */
             && ip->p1 == p1) {
           if (UNLIKELY(csound->oparms->odebug))
-            csound->Message(csound, "turning off inf copy of instr %d\n",
+            csound->Message(csound, Str("turning off inf copy of instr %d\n"),
                                     insno);
           xturnoff(csound, ip);
           return;                       /*      turn it off  */
@@ -1103,7 +1108,7 @@ int xinset(CSOUND *csound, XIN *p)
     *(tmp++) = NULL;            /* put delimiter */
     /* ... same for k-rate */
     while (*++ndx_list >= 0) {
-      *(tmp++) = *(bufs + *ndx_list);   /* "from" address */   
+      *(tmp++) = *(bufs + *ndx_list);   /* "from" address */
       *(tmp++) = *(p->args + *ndx_list);/* "to" address */
     }
     *(tmp++) = NULL;            /* put delimiter */
@@ -1111,23 +1116,23 @@ int xinset(CSOUND *csound, XIN *p)
      while (*++ndx_list >= 0) {
        void *in, *out;
        in = (void *)*(bufs + *ndx_list);
-       *(tmp++) = (MYFLT *) in;   
+       *(tmp++) = (MYFLT *) in;
        out = (void *) *(p->args + *ndx_list);
        *(tmp++) = (MYFLT *) out;
-       memcpy(out, in, sizeof(PVSDAT));    
+       memcpy(out, in, sizeof(PVSDAT));
     }
      *(tmp++) = NULL;
     /* tsigs: similar to avove */
      while (*++ndx_list >= 0) {
        void *in, *out;
        in = (void *)*(bufs + *ndx_list);
-       *(tmp++) = (MYFLT *) in;   
+       *(tmp++) = (MYFLT *) in;
        out = (void *) *(p->args + *ndx_list);
        *(tmp++) = (MYFLT *) out;
-       memcpy(out, in, sizeof(TABDAT));   
+       memcpy(out, in, sizeof(TABDAT));
     }
      *(tmp++) = NULL;
-   
+
     /* fix for case when xout is omitted */
     *(tmp++) = NULL;  *(tmp++) = NULL;  *(tmp++) = NULL; *tmp = NULL;
     return OK;
@@ -1139,7 +1144,7 @@ int xoutset(CSOUND *csound, XOUT *p)
     OPCODINFO   *inm;
     int16       *ndx_list;
     MYFLT       **tmp, **bufs;
-    
+
     (void) csound;
     buf = (OPCOD_IOBUFS*) p->h.insdshead->opcod_iobufs;
     inm = buf->opcode_info;
@@ -1163,11 +1168,12 @@ int xoutset(CSOUND *csound, XOUT *p)
     tmp = buf->iobufp_ptrs;
     /* VL: needs to check if there are not 4 nulls in a sequence, which
        would indicate no a, k, f or t sigs */
-    if (*tmp || *(tmp + 1) || *(tmp + 2) || *(tmp + 3)) tmp += (inm->perf_incnt << 1);
+    if (*tmp || *(tmp + 1) || *(tmp + 2) || *(tmp + 3))
+      tmp += (inm->perf_incnt << 1);
     tmp += 4;  /* VL: this was 2, now 4 with fsigs and tsigs added */
     if (*tmp || *(tmp + 1))
     return OK;
-   
+
     /* find a-rate variables and add to list of perf-time buf ptrs ... */
     while (*++ndx_list >= 0) {
       *(tmp++) = *(p->args + *ndx_list);/* "from" address */
@@ -1180,23 +1186,23 @@ int xoutset(CSOUND *csound, XOUT *p)
       *(tmp++) = *(bufs + *ndx_list);   /* "to" address */
     }
     *(tmp++) = NULL;                /* put delimiter */
- 
+
     /* fsigs: we'll need to do extra work */
     while (*++ndx_list >= 0) {
       void *in, *out;
       in =  (void *) *(p->args + *ndx_list);
       *(tmp++) = (MYFLT *) in;
-      out = (void *) *(bufs + *ndx_list); 
+      out = (void *) *(bufs + *ndx_list);
       *(tmp++) = (MYFLT *) out;
       memcpy(out, in, sizeof(PVSDAT));
     }
-    *(tmp++) = NULL; 
+    *(tmp++) = NULL;
    /* tsigs: as above */
     while (*++ndx_list >= 0) {
       void *in, *out;
       in =  (void *) *(p->args + *ndx_list);
       *(tmp++) = (MYFLT *) in;
-      out = (void *) *(bufs + *ndx_list); 
+      out = (void *) *(bufs + *ndx_list);
       *(tmp++) = (MYFLT *) out;
       memcpy(out, in, sizeof(TABDAT));
     }
@@ -1294,7 +1300,7 @@ INSDS *insert_event(CSOUND *csound,
     }
     /* Insert this event into event queue */
     if (UNLIKELY(O->odebug))
-      csound->Message(csound, "activating instr %d\n", insno);
+      csound->Message(csound, Str("activating instr %d\n"), insno);
     if (UNLIKELY((tp->mdepends & 4) && !midi)) {
       char *name = csound->instrtxtp[ip->insno]->insname;
       if (name)
@@ -1421,7 +1427,7 @@ INSDS *insert_event(CSOUND *csound,
       ip->offtim = -1.0;        /* else mark indef */
     }
     if (UNLIKELY(O->odebug)) {
-      csound->Message(csound, "instr %d now active:\n", insno);
+      csound->Message(csound, Str("instr %d now active:\n"), insno);
       showallocs(csound);
     }
  endsched:
@@ -1464,7 +1470,7 @@ void beatexpire(CSOUND *csound, double beat)
       while ((ip = ip->nxtoff) != NULL && ip->offbet <= beat);
       csound->frstoff = ip;
       if (UNLIKELY(csound->oparms->odebug)) {
-        csound->Message(csound, "deactivated all notes to beat %7.3f\n", beat);
+        csound->Message(csound, Str("deactivated all notes to beat %7.3f\n"), beat);
         csound->Message(csound, "frstoff = %p\n", (void*) csound->frstoff);
       }
     }
@@ -1501,7 +1507,7 @@ void timexpire(CSOUND *csound, double time)
       while ((ip = ip->nxtoff) != NULL && ip->offtim <= time);
       csound->frstoff = ip;
       if (UNLIKELY(csound->oparms->odebug)) {
-        csound->Message(csound, "deactivated all notes to time %7.3f\n", time);
+        csound->Message(csound, Str("deactivated all notes to time %7.3f\n"), time);
         csound->Message(csound, "frstoff = %p\n", (void*) csound->frstoff);
       }
     }
@@ -1593,16 +1599,16 @@ int useropcd1(CSOUND *csound, UOPCODE *p)
           ptr1 = *tmp; *(*(++tmp)) = *ptr1;
         }
         /* VL: fsigs in need to be dealt with here */
-        while (*(++tmp)) {                
-         ptr1 = *tmp; 
-         memcpy((void *)(*(++tmp)), (void *) ptr1, sizeof(PVSDAT)); 
+        while (*(++tmp)) {
+         ptr1 = *tmp;
+         memcpy((void *)(*(++tmp)), (void *) ptr1, sizeof(PVSDAT));
          }
         /* and tsigs */
-        while (*(++tmp)) {                
-         ptr1 = *tmp; 
-         memcpy((void *)(*(++tmp)), (void *) ptr1, sizeof(TABDAT)); 
+        while (*(++tmp)) {
+         ptr1 = *tmp;
+         memcpy((void *)(*(++tmp)), (void *) ptr1, sizeof(TABDAT));
          }
-        
+
         /*  run each opcode  */
         csound->pds = (OPDS *) (p->ip);
         while ((csound->pds = csound->pds->nxtp)) {
@@ -1630,15 +1636,15 @@ int useropcd1(CSOUND *csound, UOPCODE *p)
           ptr1 = *tmp; *(*(++tmp)) = *ptr1;
         }
         /* VL: fsigs in need to be dealt with here */
-        while (*(++tmp)) {                
-         ptr1 = *tmp; 
-         memcpy((void *)(*(++tmp)), (void *) ptr1, sizeof(PVSDAT)); 
+        while (*(++tmp)) {
+         ptr1 = *tmp;
+         memcpy((void *)(*(++tmp)), (void *) ptr1, sizeof(PVSDAT));
          }
         /* and tsigs */
-        while (*(++tmp)) {                
-         ptr1 = *tmp; 
-         memcpy((void *)(*(++tmp)), (void *) ptr1, sizeof(TABDAT)); 
-         } 
+        while (*(++tmp)) {
+         ptr1 = *tmp;
+         memcpy((void *)(*(++tmp)), (void *) ptr1, sizeof(TABDAT));
+         }
         /*  run each opcode  */
         csound->pds = (OPDS *) (p->ip);
         while ((csound->pds = csound->pds->nxtp)) {
@@ -1658,20 +1664,20 @@ int useropcd1(CSOUND *csound, UOPCODE *p)
     /* k-rate outputs are copied only in the last sub-kperiod, */
     /* so we do it now */
     while (*(++tmp)) {                  /* k-rate */
-      ptr1 = *tmp; 
+      ptr1 = *tmp;
       *(*(++tmp)) = *ptr1;
     }
     /* VL: fsigs out need to be dealt with here */
-     while (*(++tmp)) {                
+     while (*(++tmp)) {
        ptr1 = *tmp;
        memcpy((void *)(*(++tmp)), (void *)ptr1, sizeof(PVSDAT));
     }
      /* tsigs  */
-    while (*(++tmp)) {                
+    while (*(++tmp)) {
        ptr1 = *tmp;
        memcpy((void *)(*(++tmp)), (void *)ptr1, sizeof(TABDAT));
     }
-    
+
     /* restore globals */
     csound->ksmps = g_ksmps;
     csound->pool[csound->poolcount + 2] = (MYFLT) g_ksmps;
@@ -1694,13 +1700,14 @@ int useropcd2(CSOUND *csound, UOPCODE *p)
     OPDS    *saved_pds = csound->pds;
     int     n;
     MYFLT   **tmp, *ptr1, *ptr2;
-    
+
      if (!(csound->pds = (OPDS*) (p->ip->nxtp))) goto endop; /* no perf code */
 
-    //csound->Message(csound, "end input\n"); /* FOR SOME REASON the opcode has no perf code */ 
+    //csound->Message(csound, "end input\n");
+    /* FOR SOME REASON the opcode has no perf code */
     /* IV - Nov 16 2002: update release flag */
     p->ip->relesing = p->parent_ip->relesing;
-   
+
     tmp = p->buf->iobufp_ptrs;
     if (csound->ksmps != 1) {           /* generic case for kr != sr */
 
@@ -1712,23 +1719,23 @@ int useropcd2(CSOUND *csound, UOPCODE *p)
           *(ptr2++) = *(ptr1++);
         } while (--n);
       }
-   
+
       while (*(++tmp)) {                /* k-rate */
         ptr1 = *tmp; *(*(++tmp)) = *ptr1;
       }
-  
+
       /* VL: fsigs in need to be dealt with here */
-       while (*(++tmp)) {                
-         ptr1 = *tmp; 
-         memcpy((void *)(*(++tmp)), (void *) ptr1, sizeof(PVSDAT)); 
-         } 
+       while (*(++tmp)) {
+         ptr1 = *tmp;
+         memcpy((void *)(*(++tmp)), (void *) ptr1, sizeof(PVSDAT));
+         }
        /* VL: tsigs */
-        while (*(++tmp)) {                
-         ptr1 = *tmp; 
-         memcpy((void *)(*(++tmp)), (void *) ptr1, sizeof(TABDAT)); 
-         } 
-       
-        
+        while (*(++tmp)) {
+         ptr1 = *tmp;
+         memcpy((void *)(*(++tmp)), (void *) ptr1, sizeof(TABDAT));
+         }
+
+
       /*  run each opcode  */
       do {
         (*csound->pds->opadr)(csound, csound->pds);
@@ -1745,22 +1752,22 @@ int useropcd2(CSOUND *csound, UOPCODE *p)
     else {                      /* special case for kr == sr */
       /* copy inputs */
       while (*tmp) {                    /* a-rate */
-        ptr1 = *(tmp++); 
+        ptr1 = *(tmp++);
         *(*(tmp++)) = *ptr1;
       }
       while (*(++tmp)) {                /* k-rate */
         ptr1 = *tmp; *(*(++tmp)) = *ptr1;
       }
       /* VL: fsigs in need to be dealt with here */
-       while (*(++tmp)) {                
-         ptr1 = *tmp; 
-         memcpy((void *)(*(++tmp)), (void *) ptr1, sizeof(PVSDAT)); 
+       while (*(++tmp)) {
+         ptr1 = *tmp;
+         memcpy((void *)(*(++tmp)), (void *) ptr1, sizeof(PVSDAT));
          }
        /* VL: tsigs */
-       while (*(++tmp)) {                
-         ptr1 = *tmp; 
-         memcpy((void *)(*(++tmp)), (void *) ptr1, sizeof(TABDAT)); 
-         } 
+       while (*(++tmp)) {
+         ptr1 = *tmp;
+         memcpy((void *)(*(++tmp)), (void *) ptr1, sizeof(TABDAT));
+         }
       /*  run each opcode  */
       do {
         (*csound->pds->opadr)(csound, csound->pds);
@@ -1774,15 +1781,15 @@ int useropcd2(CSOUND *csound, UOPCODE *p)
       ptr1 = *tmp; *(*(++tmp)) = *ptr1;
     }
     /* VL: fsigs out need to be dealt with here */
-     while (*(++tmp)) {                
+     while (*(++tmp)) {
        ptr1 = *tmp;
        memcpy((void *)(*(++tmp)), (void *)ptr1, sizeof(PVSDAT));
        }
      /* tsigs */
-    while (*(++tmp)) {                
+    while (*(++tmp)) {
        ptr1 = *tmp;
        memcpy((void *)(*(++tmp)), (void *)ptr1, sizeof(TABDAT));
-       } 
+       }
  endop:
     /* restore globals */
     csound->pds = saved_pds;
@@ -1804,7 +1811,7 @@ static void instance(CSOUND *csound, int insno)
     const OENTRY  *ep;
     LBLBLK    **lopdsp;
     LARGNO    *largp;
-    int       n, cnt, pextent, opnum;
+    int       n, cnt, pextent, opnum, pextra;
     char      *nxtopds, *opdslim;
     MYFLT     **argpp, *lclbas, *gbloffbas, *lcloffbas;
     int       *ndxp;
@@ -1823,7 +1830,9 @@ static void instance(CSOUND *csound, int insno)
     if (O->midiKeyPch>n) n = O->midiKeyPch;
     if (O->midiVelocity>n) n = O->midiVelocity;
     if (O->midiVelocityAmp>n) n = O->midiVelocityAmp;
-    pextent = sizeof(INSDS) + tp->pextrab + (n-3)*sizeof(MYFLT *);      /* alloc new space,  */
+    pextra = n-3;
+    /* alloc new space  */
+    pextent = sizeof(INSDS) + tp->pextrab + pextra*sizeof(MYFLT *);
     ip = (INSDS*) mcalloc(csound, (size_t) pextent + tp->localen + tp->opdstot);
     ip->csound = csound;
     ip->m_chnbp = (MCHNBLK*) NULL;
@@ -1900,7 +1909,8 @@ static void instance(CSOUND *csound, int insno)
       if ((n = ep->thread & 06) != 0) {         /* thread 2 OR 4:   */
         prvpds = prvpds->nxtp = opds;           /* link into pchain */
         if (!(n & 04) ||
-            (ttp->pftype == 'k' && ep->kopadr != NULL))
+            ((ttp->pftype == 'k' || ttp->pftype == 'c') &&
+             ep->kopadr != NULL))
           opds->opadr = ep->kopadr;             /*      krate or    */
         else opds->opadr = ep->aopadr;          /*      arate       */
         if (UNLIKELY(odebug))
@@ -2040,5 +2050,3 @@ int delete_instr(CSOUND *csound, DELETEIN *p)
       }
     return NOTOK;
 }
-
-
