@@ -39,7 +39,7 @@ extern  int     MIDIinsert(CSOUND *, int, MCHNBLK*, MEVENT*);
 extern  int     insert(CSOUND *, int, EVTBLK*);
 extern  void    MidiOpen(CSOUND *);
 extern  void    m_chn_init_all(CSOUND *);
-extern  void    scsortstr(CSOUND *, CORFIL *);
+extern  void    scsortstr(CSOUND *);
 extern  void    infoff(CSOUND*, MYFLT), orcompact(CSOUND*);
 extern  void    beatexpire(CSOUND *, double), timexpire(CSOUND *, double);
 extern  void    sfopenin(CSOUND *), sfopenout(CSOUND*), sfnopenout(CSOUND*);
@@ -85,7 +85,7 @@ static void settempo(CSOUND *csound, MYFLT tempo)
 {
     if (tempo <= FL(0.0)) return;
     if (csound->oparms->Beatmode==1)
-      csound->ibeatTime = (int)(csound->esr*60.0 / (double) tempo);
+      csound->ibeatTime = (int64_t)(csound->esr*60.0 / (double) tempo);
     csound->curBeat_inc = (double) tempo / (60.0 * (double) csound->global_ekr);
 }
 
@@ -178,23 +178,23 @@ int musmon(CSOUND *csound)
 {
     OPARMS  *O = csound->oparms;
 
-#ifdef USE_DOUBLE
-#ifdef BETA
-    csound->Message(csound, Str("Csound version %s beta (double samples) %s\n"),
-                            CS_PACKAGE_VERSION, __DATE__);
-#else
-    csound->Message(csound, Str("Csound version %s (double samples) %s\n"),
-                            CS_PACKAGE_VERSION, __DATE__);
-#endif
-#else
-#ifdef BETA
-    csound->Message(csound, Str("Csound version %s beta (float samples) %s\n"),
-                            CS_PACKAGE_VERSION, __DATE__);
-#else
-    csound->Message(csound, Str("Csound version %s (float samples) %s\n"),
-                            CS_PACKAGE_VERSION, __DATE__);
-#endif
-#endif
+/* #ifdef USE_DOUBLE */
+/* #ifdef BETA */
+/*     csound->Message(csound, Str("Csound version %s beta (double samples) %s\n"), */
+/*                             CS_PACKAGE_VERSION, __DATE__); */
+/* #else */
+/*     csound->Message(csound, Str("Csound version %s (double samples) %s\n"), */
+/*                             CS_PACKAGE_VERSION, __DATE__); */
+/* #endif */
+/* #else */
+/* #ifdef BETA */
+/*     csound->Message(csound, Str("Csound version %s beta (float samples) %s\n"), */
+/*                             CS_PACKAGE_VERSION, __DATE__); */
+/* #else */
+/*     csound->Message(csound, Str("Csound version %s (float samples) %s\n"), */
+/*                             CS_PACKAGE_VERSION, __DATE__); */
+/* #endif */
+/* #endif */
     if (LIKELY(csound->musmonGlobals == NULL))
       csound->musmonGlobals = csound->Calloc(csound, sizeof(MUSMON_GLOBALS));
     /* initialise search path cache */
@@ -314,8 +314,7 @@ int musmon(CSOUND *csound)
         csoundDie(csound, Str("cannot reopen cscore.srt"));
       csoundNotifyFileOpened(csound, "cscore.srt", CSFTYPE_SCORE_OUT, 1, 0);
       csound->Message(csound, Str("sorting cscore.out ..\n"));
-      /* csound->scorestr = copy_to_corefile(csound, "cscore.srt", NULL, 1); */
-      scsortstr(csound, csound->scorestr);  /* call the sorter again */
+      scsortstr(csound);  /* call the sorter again */
       fclose(csound->scfp); csound->scfp = NULL;
       fputs(corfile_body(csound->scstr), csound->oscfp);
       fclose(csound->oscfp); csound->oscfp = NULL;
@@ -395,7 +394,7 @@ PUBLIC int csoundCleanup(CSOUND *csound)
     }
     orcompact(csound);
     corfile_rm(&csound->scstr);
-  
+
     /* print stats only if musmon was actually run */
     if (UNLIKELY(csound->musmonGlobals != NULL)) {
       csound->Message(csound, Str("end of score.\t\t   overall amps:"));
@@ -417,12 +416,12 @@ PUBLIC int csoundCleanup(CSOUND *csound)
                               csound->perferrcnt);
       print_benchmark_info(csound, Str("end of performance"));
     }
-     
+
     /* close line input (-L) */
     RTclose(csound);
     /* close MIDI input */
     MidiClose(csound);
- 
+
     /* IV - Feb 03 2005: do not need to call rtclose from here, */
     /* as sfclosein/sfcloseout will do that. */
     if (!csound->enableHostImplementedAudioIO) {
@@ -435,7 +434,7 @@ PUBLIC int csoundCleanup(CSOUND *csound)
     if (csound->remoteGlobals) remote_Cleanup(csound);
     if (csound->oparms->ringbell)
       cs_beep(csound);
-   
+
     return dispexit(csound);    /* hold or terminate the display output     */
 }
 
@@ -614,9 +613,10 @@ static int process_score_event(CSOUND *csound, EVTBLK *evt, int rtEvt)
       return (evt->opcod == 'l' ? 3 : (evt->opcod == 's' ? 1 : 2));
     case 'q':
       if (evt->p[1] == SSTRCOD && evt->strarg) {    /* IV - Oct 31 2002 */
-        if (UNLIKELY((insno = (int) named_instr_find(csound, evt->strarg)) < 1)) {
-          printScoreError(csound, rtEvt, Str(" - note deleted. instr %s undefined"),
-                                    evt->strarg);
+        if (UNLIKELY((insno = (int)named_instr_find(csound, evt->strarg)) < 1)) {
+          printScoreError(csound, rtEvt,
+                          Str(" - note deleted. instr %s undefined"),
+                          evt->strarg);
           break;
         }
         csound->Message(csound, Str("Setting instrument %s %s\n"),
@@ -628,8 +628,8 @@ static int process_score_event(CSOUND *csound, EVTBLK *evt, int rtEvt)
         if (UNLIKELY((unsigned int)(insno-1) >= (unsigned int) csound->maxinsno ||
                      csound->instrtxtp[insno] == NULL)) {
           printScoreError(csound, rtEvt,
-                          Str(" - note deleted. instr %d(%d) undefined"),
-                          insno, csound->maxinsno);
+                          Str(" - note deleted. instr %d undefined"),
+                          insno);
           break;
         }
         csound->Message(csound, Str("Setting instrument %d %s\n"),
@@ -656,7 +656,8 @@ static int process_score_event(CSOUND *csound, EVTBLK *evt, int rtEvt)
         evt->p[1] = (MYFLT) insno;
         if (csound->oparms->Beatmode && !rtEvt && evt->p3orig > FL(0.0))
           evt->p[3] = evt->p3orig * (MYFLT) csound->ibeatTime/csound->esr;
-        if (UNLIKELY((n = insert(csound, insno, evt)))) {  /* else alloc, init, activate */
+        if (UNLIKELY((n = insert(csound, insno, evt)))) {
+          /* else alloc, init, activate */
           printScoreError(csound, rtEvt,
                           Str(" - note deleted.  i%d (%s) had %d init errors"),
                           insno, evt->strarg, n);
@@ -667,8 +668,8 @@ static int process_score_event(CSOUND *csound, EVTBLK *evt, int rtEvt)
         if (UNLIKELY((unsigned int)(insno-1) >= (unsigned int)csound->maxinsno ||
                      csound->instrtxtp[insno] == NULL)) {
           printScoreError(csound, rtEvt,
-                          Str(" - note deleted. instr %d(%d) undefined"),
-                          insno, csound->maxinsno);
+                          Str(" - note deleted. instr %d undefined"),
+                          insno);
           break;
         }
         if ((rfd = getRemoteInsRfd(csound, insno))) {
@@ -704,8 +705,8 @@ static int process_score_event(CSOUND *csound, EVTBLK *evt, int rtEvt)
       break;
     case 'a':
       {
-        int kCnt;
-        kCnt = (int) ((double) csound->global_ekr * (double) evt->p[3] + 0.5);
+        int64_t kCnt;
+        kCnt = (int64_t) ((double) csound->global_ekr * (double) evt->p[3] + 0.5);
         if (kCnt > csound->advanceCnt) {
           csound->advanceCnt = kCnt;
           csound->Message(csound,
@@ -724,7 +725,7 @@ static void process_midi_event(CSOUND *csound, MEVENT *mep, MCHNBLK *chn)
 {
     int n, insno = chn->insno;
     if (mep->type == NOTEON_TYPE && mep->dat2) {      /* midi note ON: */
-      if (UNLIKELY((n = MIDIinsert(csound, insno, chn, mep)))) { 
+      if (UNLIKELY((n = MIDIinsert(csound, insno, chn, mep)))) {
         /* alloc,init,activ */
         csound->Message(csound,
                         Str("\t\t   T%7.3f - note deleted. "), csound->curp2);
@@ -805,7 +806,7 @@ static int process_rt_event(CSOUND *csound, int sensType)
     return retval;
 }
 
-#define RNDINT(x) ((int) ((double) (x) + ((double) (x) < 0.0 ? -0.5 : 0.5)))
+#define RNDINT64(x) ((int64_t) ((double) (x) + ((double) (x) < 0.0 ? -0.5 : 0.5)))
 
 extern  int     sensMidi(CSOUND *);
 
@@ -901,7 +902,7 @@ int sensevents(CSOUND *csound)
           csound->nxtbt = (double) e->p2orig + csound->beatOffs;
           if (e->opcod=='i')
             if (UNLIKELY(csound->oparms->odebug))
-              csound->Message(csound, "new event: %16.13lf %16.13lf\n",
+              csound->Message(csound, Str("new event: %16.13lf %16.13lf\n"),
                               csound->nxtim, csound->nxtbt);
           break;
         case 'e':
@@ -916,15 +917,19 @@ int sensevents(CSOUND *csound)
           continue;
         }
       }
-      /* calculate the number of k-periods remaining until next event */
-      if (O->Beatmode)
+      
+
+       if (O->Beatmode)
         csound->cyclesRemaining =
-          RNDINT((csound->nxtbt - csound->curBeat) / csound->curBeat_inc);
+          RNDINT64((csound->nxtbt - csound->curBeat) / csound->curBeat_inc);
       else {
         csound->cyclesRemaining =
-          RNDINT((csound->nxtim*csound->esr - csound->icurTime) / csound->ksmps);
-        csound->nxtim = (csound->cyclesRemaining*csound->ksmps+csound->icurTime)/csound->esr;
-      }
+          RNDINT64((csound->nxtim*csound->esr - csound->icurTime) / csound->ksmps);
+        csound->nxtim =
+          (csound->cyclesRemaining*csound->ksmps+csound->icurTime)/csound->esr;
+      } 
+      
+     
     }
 
     /* handle any real time events now: */
@@ -976,8 +981,8 @@ int sensevents(CSOUND *csound)
                 MEVENT *mep = (MEVENT *)bp->data;
                 if (UNLIKELY(mep->type == 0xFF && mep->dat1 == 0x2F)) {
                   csound->MTrkend = 1;                     /* catch a Trkend    */
-                  csound->Message(csound, "SERVER%c: ", remoteID(csound));
-                  csound->Message(csound, "caught a Trkend\n");
+                  csound->Message(csound, Str("SERVER%c: "), remoteID(csound));
+                  csound->Message(csound, Str("caught a Trkend\n"));
                   /*csoundCleanup(csound);
                   exit(0);*/
                   return 2;  /* end of performance */
@@ -1013,7 +1018,8 @@ int sensevents(CSOUND *csound)
       delete_pending_rt_events(csound);
       if (O->Beatmode)
         csound->curbt = csound->curBeat;
-      csound->curp2 = csound->nxtim = csound->timeOffs = csound->icurTime/csound->esr;
+      csound->curp2 = csound->nxtim =
+        csound->timeOffs = csound->icurTime/csound->esr;
       csound->prvbt = csound->nxtbt = csound->beatOffs = csound->curbt;
       section_amps(csound, 1);
     }
@@ -1029,14 +1035,14 @@ int sensevents(CSOUND *csound)
     return 2;                   /* done with entire score */
 }
 
-static inline uint32 time2kcnt(CSOUND *csound, double tval)
+static inline uint64_t time2kcnt(CSOUND *csound, double tval)
 {
     if (tval > 0.0) {
       tval *= (double) csound->global_ekr;
 #ifdef HAVE_C99
-      return (uint32) llrint(tval);
+      return (uint64_t) llrint(tval);
 #else
-      return (uint32) (tval + 0.5);
+      return (uint64_t) (tval + 0.5);
 #endif
     }
     return 0UL;
@@ -1057,7 +1063,7 @@ static inline uint32 time2kcnt(CSOUND *csound, double tval)
 /* made.                                                              */
 /* Return value is zero on success.                                   */
 
-int insert_score_event_at_sample(CSOUND *csound, EVTBLK *evt, long time_ofs)
+int insert_score_event_at_sample(CSOUND *csound, EVTBLK *evt, int64_t time_ofs)
 {
     double        start_time;
     EVTNODE       *e, *prv;
@@ -1268,4 +1274,3 @@ PUBLIC int csoundRegisterSenseEventCallback(CSOUND *csound,
 
     return 0;
 }
-
