@@ -125,6 +125,12 @@ static int parse_opcode_args(CSOUND *csound, OENTRY *opc)
       case 'a':
         a_incnt++; *otypes++ = *types;
         break;
+      case 'O':
+        k_incnt++; *otypes++ = 'O'; break;
+      case 'P':
+         k_incnt++;*otypes++ = 'P'; break;
+      case 'V':
+         k_incnt++;*otypes++ = 'V'; break;
       case 'K':
         i_incnt++;              /* also updated at i-time */
       case 'k':
@@ -135,7 +141,7 @@ static int parse_opcode_args(CSOUND *csound, OENTRY *opc)
         break;
       case 't':
           t_incnt++; *otypes++ = *types;
-          break;              
+          break;
       case 'i':
       case 'o':
       case 'p':
@@ -183,7 +189,7 @@ static int parse_opcode_args(CSOUND *csound, OENTRY *opc)
         break;
       case 't':
         t_outcnt++; *otypes++ = *types;
-        break;              
+        break;
       case 'i':
         i_outcnt++; *otypes++ = *types;
         break;
@@ -211,14 +217,18 @@ static int parse_opcode_args(CSOUND *csound, OENTRY *opc)
     a_inlist = S_inlist + S_incnt + 1;
     k_inlist = a_inlist + a_incnt + 1;
     f_inlist = k_inlist + k_incnt + 1;
-    t_inlist = f_inlist + f_incnt + 1;    
+    t_inlist = f_inlist + f_incnt + 1;
     i = 0; types = inm->intypes;
     while (*types) {
       switch (*types++) {
         case 'a': *a_inlist++ = i; break;
+        case 'O':
+        case 'P':
+        case 'V':
         case 'k': *k_inlist++ = i; break;
         case 'f': *f_inlist++ = i; break;
-        case 't': *t_inlist++ = i; break;      
+        case 't': *t_inlist++ = i; break;
+
         case 'K': *k_inlist++ = i;      /* also updated at i-time */
         case 'i':
         case 'o':
@@ -228,20 +238,21 @@ static int parse_opcode_args(CSOUND *csound, OENTRY *opc)
       }
       i++;
     }
-    *i_inlist = *S_inlist = *a_inlist = *k_inlist = *f_inlist = *t_inlist = -1;     /* put delimiters */
+    *i_inlist = *S_inlist = *a_inlist =
+      *k_inlist = *f_inlist = *t_inlist = -1;     /* put delimiters */
     i_outlist = inm->out_ndx_list = t_inlist + 1;
     S_outlist = i_outlist + i_outcnt + 1;
     a_outlist = S_outlist + S_outcnt + 1;
     k_outlist = a_outlist + a_outcnt + 1;
     f_outlist = k_outlist + k_outcnt + 1;
-    t_outlist = f_outlist + f_outcnt + 1;    
+    t_outlist = f_outlist + f_outcnt + 1;
     i = 0; types = inm->outtypes;
     while (*types) {
       switch (*types++) {
         case 'a': *a_outlist++ = i; break;
         case 'k': *k_outlist++ = i; break;
         case 'f': *f_outlist++ = i; break;
-        case 't': *t_outlist++ = i; break;      
+        case 't': *t_outlist++ = i; break;
         case 'K': *k_outlist++ = i;     /* also updated at i-time */
         case 'i': *i_outlist++ = i; break;
         case 'S': *S_outlist++ = i; break;
@@ -303,7 +314,6 @@ void otran(CSOUND *csound)
     ST(poolcount) = 0;
     ST(nconsts) = NCONSTS;
     ST(constTbl) = (int*) mcalloc(csound, (256 + NCONSTS) * sizeof(int));
-    setlocale(LC_NUMERIC, "C"); /* Ensure C syntax */
     constndx(csound, "0");
 
     while ((tp = getoptxt(csound, &init)) != NULL) {
@@ -991,14 +1001,14 @@ int lgexist(CSOUND *csound, const char *s)
 {
     unsigned char h = name_hash(csound, s);
     NAME          *p;
- 
-    
+
+
 
     for (p = ST(gblNames)[h]; p != NULL && sCmp(p->namep, s); p = p->nxt);
     if (p != NULL)
       return 1;
     for (p = ST(lclNames)[h]; p != NULL && sCmp(p->namep, s); p = p->nxt);
-  
+
     return (p == NULL ? 0 : 1);
 
 }
@@ -1223,24 +1233,29 @@ void oload(CSOUND *p)
     int     *strConstIndexList;
     MYFLT   ensmps;
 
-    p->esr = p->tran_sr; p->ekr = p->tran_kr;
-    p->e0dbfs = p->tran_0dbfs;
-    p->ksmps = (int) ((ensmps = p->tran_ksmps) + FL(0.5));
-    ip = p->instxtanchor.nxtinstxt;        /* for instr 0 optxts:  */
-    optxt = (OPTXT *) ip;
-    while ((optxt = optxt->nxtop) !=  NULL) {
-      TEXT  *ttp = &optxt->t;
-      ARGOFFS *inoffp, *outoffp;
-      int opnum = ttp->opnum;
-      if (opnum == ENDIN) break;
-      if (opnum == LABEL) continue;
-      outoffp = ttp->outoffs;           /* use unexpanded ndxes */
-      inoffp = ttp->inoffs;             /* to find sr.. assigns */
-      if (outoffp->count == 1 && inoffp->count == 1) {
-        int rindex = (int) outoffp->indx[0] - (int) p->poolcount;
-        if (rindex > 0 && rindex <= 6) {
-          MYFLT conval = p->pool[inoffp->indx[0] - 1];
-          switch (rindex) {
+    if (O->newParser) {
+      p->esr = p->tran_sr; p->ekr = p->tran_kr; p->ksmps = ensmps = p->tran_ksmps;
+      //p->nchnls = p->tran_nchnls;
+      p->e0dbfs = p->tran_0dbfs;
+    }
+    else {
+      p->esr = p->tran_sr; p->ekr = p->tran_kr; p->ksmps = ensmps = p->tran_ksmps;
+      p->e0dbfs = p->tran_0dbfs;
+      ip = p->instxtanchor.nxtinstxt;        /* for instr 0 optxts:  */
+      optxt = (OPTXT *) ip;
+      while ((optxt = optxt->nxtop) !=  NULL) {
+        TEXT  *ttp = &optxt->t;
+        ARGOFFS *inoffp, *outoffp;
+        int opnum = ttp->opnum;
+        if (opnum == ENDIN) break;
+        if (opnum == LABEL) continue;
+        outoffp = ttp->outoffs;           /* use unexpanded ndxes */
+        inoffp = ttp->inoffs;             /* to find sr.. assigns */
+        if (outoffp->count == 1 && inoffp->count == 1) {
+          int rindex = (int) outoffp->indx[0] - (int) p->poolcount;
+          if (rindex > 0 && rindex <= 6) {
+            MYFLT conval = p->pool[inoffp->indx[0] - 1];
+            switch (rindex) {
             case 1:  p->esr = conval;   break;  /* & use those values */
             case 2:  p->ekr = conval;   break;  /*  to set params now */
             case 3:  p->ksmps = (int) ((ensmps = conval) + FL(0.5)); break;
@@ -1248,17 +1263,18 @@ void oload(CSOUND *p)
             case 5:  p->inchnls = (int) (conval + FL(0.5));  break;
             case 6:
             default: p->e0dbfs = conval; break;
+            }
           }
         }
       }
+      /* why I want oload() to return an error value.... */
+      if (UNLIKELY(p->e0dbfs <= FL(0.0)))
+        p->Die(p, Str("bad value for 0dbfs: must be positive."));
+      if (UNLIKELY(O->odebug))
+        p->Message(p, "esr = %7.1f, ekr = %7.1f, ksmps = %d, nchnls = %d "
+                   "0dbfs = %.1f\n",
+                   p->esr, p->ekr, p->ksmps, p->nchnls, p->e0dbfs);
     }
-    /* why I want oload() to return an error value.... */
-    if (UNLIKELY(p->e0dbfs <= FL(0.0)))
-      p->Die(p, Str("bad value for 0dbfs: must be positive."));
-    if (UNLIKELY(O->odebug))
-      p->Message(p, "esr = %7.1f, ekr = %7.1f, ksmps = %d, nchnls = %d "
-                    "0dbfs = %.1f\n",
-                    p->esr, p->ekr, p->ksmps, p->nchnls, p->e0dbfs);
     if (O->sr_override) {        /* if command-line overrides, apply now */
       p->esr = (MYFLT) O->sr_override;
       p->ekr = (MYFLT) O->kr_override;
@@ -1266,7 +1282,7 @@ void oload(CSOUND *p)
                                    / (MYFLT) O->kr_override)) + FL(0.5));
       p->Message(p, Str("sample rate overrides: "
                         "esr = %7.4f, ekr = %7.4f, ksmps = %d\n"),
-                    p->esr, p->ekr, p->ksmps);
+                 p->esr, p->ekr, p->ksmps);
     }
     /* number of MYFLT locations to allocate for a string variable */
     p->strVarSamples = (p->strVarMaxLen + (int) sizeof(MYFLT) - 1)
@@ -1443,7 +1459,7 @@ void oload(CSOUND *p)
     if (O->Beatmode && O->cmdTempo > 0) {
       /* if performing from beats, set the initial tempo */
       p->curBeat_inc = (double) O->cmdTempo / (60.0 * (double) p->ekr);
-      p->ibeatTime = (int)(p->esr*60.0 / (double) O->cmdTempo);
+      p->ibeatTime = (int64_t)(p->esr*60.0 / (double) O->cmdTempo);
     }
     else {
       p->curBeat_inc = 1.0 / (double) p->ekr;
@@ -1460,4 +1476,3 @@ void oload(CSOUND *p)
     if (UNLIKELY(init0(p) != 0))
       csoundDie(p, Str("header init errors"));
 }
-
