@@ -228,10 +228,10 @@ static void print_input_backtrace(CSOUND *csound, int needLFs,
                 (lastsource == 0 ? csound->scoLineOffset + curr->line - 1 :
                  csound->scoLineOffset + curr->line), csound->csdname, lf);
       }
-      else {
-        msgfunc(csound, m, (lastsource == 0 ? curr->line - 1 : curr->line),
-                corfile_tell(curr->cf), lf);  /* #include is one line before */
-      }
+      /* else { */
+      /*   msgfunc(csound, m, (lastsource == 0 ? curr->line - 1 : curr->line), */
+      /*      corfile_tell(curr->cf), lf); /\* #include is one line before *\/ */
+      /* } */
     } while (!lastsource);
     curr--;
     return;
@@ -270,7 +270,8 @@ static int undefine_score_macro(CSOUND *csound, const char *name)
         corfile_rm(&(ST(macros)->body));
       mfree(csound, ST(macros)->name);
  #ifdef MACDEBUG
-     csound->DebugMsg(csound,"%s(%d): corfile is %p\n", __FILE__, __LINE__, ST(macros)->body);
+     csound->DebugMsg(csound,"%s(%d): corfile is %p\n",
+                      __FILE__, __LINE__, ST(macros)->body);
  #endif
      for (i = 0; i < ST(macros)->acnt; i++)
         mfree(csound, ST(macros)->arg[i]);
@@ -319,7 +320,7 @@ static int getscochar(CSOUND *csound, int expand)
     c = corfile_getc(ST(str)->cf);
     if (c == EOF) {
       if (ST(str) == &ST(inputs)[0]) {
-        corfile_ungetc(ST(str)->cf);      /* to ensure repeated EOF */
+        corfile_putc('\n', ST(str)->cf);  /* to ensure repeated EOF */
         return EOF;
       }
       if (ST(str)->mac == 0) {
@@ -333,7 +334,8 @@ static int getscochar(CSOUND *csound, int expand)
       goto top;
     }
 #ifdef MACDEBUG
-    csound->DebugMsg(csound,"%s(%d): character = %c(%.2d)\n", __FILE__, __LINE__, c, c);
+    csound->DebugMsg(csound,"%s(%d): character = %c(%.2d)\n",
+                     __FILE__, __LINE__, c, c);
 #endif
     if (c == '\r') {    /* can only occur in files, and not in macros */
       if ((c = corfile_getc(ST(str)->cf)) != '\n') {
@@ -413,7 +415,8 @@ static int getscochar(CSOUND *csound, int expand)
 #endif
           nn->body = corfile_create_w();
 #ifdef MACDEBUG
-          csound->DebugMsg(csound,"%s(%d): creating\n", __FILE__, __LINE__, nn->body);
+          csound->DebugMsg(csound,"%s(%d): creating\n",
+                           __FILE__, __LINE__, nn->body);
 #endif
           while ((c = getscochar(csound, 1))!= term && c != trm1) {
             if (UNLIKELY(c==EOF))
@@ -601,14 +604,15 @@ static int getscochar(CSOUND *csound, int expand)
         }
       } while (c != '$');
       /* Make string macro or value */
-      sprintf(buffer, "%f", *pv);
+      sprintf(buffer, "%g", *pv);
       {
         MACRO *nn = (MACRO*) mmalloc(csound, sizeof(MACRO));
         nn->name = mmalloc(csound, 2);
         strcpy(nn->name, "[");
         nn->body = corfile_create_r(buffer);
 #ifdef MACDEBUG
-        csound->DebugMsg(csound,"%s(%d): creating arg %p\n", __FILE__, __LINE__, nn->body);
+        csound->DebugMsg(csound,"%s(%d): creating arg %p\n",
+                         __FILE__, __LINE__, nn->body);
 #endif
         nn->acnt = 0;   /* No arguments for arguments */
         nn->next = ST(macros);
@@ -668,7 +672,7 @@ static int nested_repeat(CSOUND *csound)                /* gab A9*/
 #ifdef MACDEBUG
       csound->DebugMsg(csound,"%s(%d) reset point to %d\n", __FILE__, __LINE__,
              ST(repeat_point_n)[ST(repeat_index)], i);
-      csound->DebugMsg(csound,"%s(%d) corefile: %s %d %d\n", __FILE__, __LINE__, 
+      csound->DebugMsg(csound,"%s(%d) corefile: %s %d %d\n", __FILE__, __LINE__,
              ST(repeat_mm_n)[ST(repeat_index)]->body->body,
              ST(repeat_mm_n)[ST(repeat_index)]->body->p,
              ST(repeat_mm_n)[ST(repeat_index)]->body->len);
@@ -678,13 +682,14 @@ static int nested_repeat(CSOUND *csound)                /* gab A9*/
         char buffer[128];
         sprintf(buffer, "%d", i);
 #ifdef MACDEBUG
-        csound->DebugMsg(csound,"%s(%d) new i = %s\n", __FILE__, __LINE__,  buffer);
+        csound->DebugMsg(csound,"%s(%d) new i = %s\n",
+                         __FILE__, __LINE__,  buffer);
 #endif
         corfile_reset(ST(repeat_mm_n)[ST(repeat_index)]->body);
         corfile_puts(buffer, ST(repeat_mm_n)[ST(repeat_index)]->body);
         corfile_rewind(ST(repeat_mm_n)[ST(repeat_index)]->body);
 #ifdef MACDEBUG
-        csound->DebugMsg(csound,"%s(%d) corefile: %s %d %d\n", __FILE__, __LINE__, 
+        csound->DebugMsg(csound,"%s(%d) corefile: %s %d %d\n", __FILE__, __LINE__,
                ST(repeat_mm_n)[ST(repeat_index)]->body->body,
                ST(repeat_mm_n)[ST(repeat_index)]->body->p,
                ST(repeat_mm_n)[ST(repeat_index)]->body->len);
@@ -788,14 +793,15 @@ static void init_smacros(CSOUND *csound, NAMES *nn)
         p++;
       mm->body = corfile_create_r(p);
 #ifdef MACDEBUG
-      csound->DebugMsg(csound,"%s(%d): init %s %p\n", __FILE__, __LINE__, mm->name, mm->body);
+      csound->DebugMsg(csound,"%s(%d): init %s %p\n",
+                       __FILE__, __LINE__, mm->name, mm->body);
 #endif
       nn = nn->next;
     }
     mm = (MACRO*) mcalloc(csound, sizeof(MACRO));
     mm->name = (char*)mmalloc(csound,4);
     strcpy(mm->name, "INF");
-    mm->body = corfile_create_r("2147483647.0");
+    mm->body = corfile_create_r("800000000000.0");
 #ifdef MACDEBUG
     csound->DebugMsg(csound,"%s(%d): INF %p\n", __FILE__, __LINE__, mm->body);
 #endif
@@ -998,7 +1004,7 @@ int sread(CSOUND *csound)       /*  called from main,  reads from SCOREIN   */
           flushlin(csound);     /* Ignore rest of line */
           ST(repeat_point_n)[ST(repeat_index)] =
             corfile_tell(ST(str)->cf);
-          
+
           /* { does not start a new section - akozar */
           /* ST(clock_base) = FL(0.0);
           ST(warp_factor) = FL(1.0);
@@ -1052,7 +1058,8 @@ int sread(CSOUND *csound)       /*  called from main,  reads from SCOREIN   */
             ST(repeat_cnt) = 10 * ST(repeat_cnt) + c - '0';
             c = getscochar(csound, 1);
           }
-          if (UNLIKELY(ST(repeat_cnt) <= 0 || (c != ' ' && c != '\t' && c != '\n')))
+          if (UNLIKELY(ST(repeat_cnt) <= 0 ||
+                       (c != ' ' && c != '\t' && c != '\n')))
             scorerr(csound, Str("r: invalid repeat count"));
           if (csound->oparms->msglevel & TIMEMSG)
             csound->Message(csound, Str("Repeats=%d\n"), ST(repeat_cnt));
@@ -1074,7 +1081,8 @@ int sread(CSOUND *csound)       /*  called from main,  reads from SCOREIN   */
             ST(repeat_mm)->acnt = 0;
             ST(repeat_mm)->body = corfile_create_r("1");
 #ifdef MACDEBUG
-            csound->DebugMsg(csound,"%s(%d): 1 %p\n", __FILE__, __LINE__,ST(repeat_mm)->body);
+            csound->DebugMsg(csound,"%s(%d): 1 %p\n",
+                             __FILE__, __LINE__,ST(repeat_mm)->body);
 #endif
             ST(repeat_mm)->next = ST(macros);
             ST(macros) = ST(repeat_mm);
@@ -1110,7 +1118,7 @@ int sread(CSOUND *csound)       /*  called from main,  reads from SCOREIN   */
           else mfree(csound, ST(names)[j].file);
           ST(names)[ST(next_name)].posit = corfile_tell(ST(str)->cf);
           ST(names)[ST(next_name)].line = ST(str)->line;
-          ST(names)[ST(next_name)].file = 
+          ST(names)[ST(next_name)].file =
             mmalloc(csound, strlen(corfile_body(ST(str)->cf)) + 1);
           strcpy(ST(names)[ST(next_name)].file, corfile_body(ST(str)->cf));
           if (csound->oparms->msglevel & TIMEMSG)
@@ -1153,7 +1161,7 @@ int sread(CSOUND *csound)       /*  called from main,  reads from SCOREIN   */
             }
             ST(str)++;
             ST(str)->is_marked_repeat = 1;
-            /* ST(str)->cf = copy_to_corefile(csound, ST(names)[i].file, NULL, 1); */
+/*          ST(str)->cf = copy_to_corefile(csound, ST(names)[i].file, NULL, 1); */
             ST(str)->cf = corfile_create_r(ST(names)[i].file);
 //            ST(str)->cf = corfile_create_r(csound->GetFileName(ST(str)->fd));
             ST(str)->line = ST(names)[i].line;
@@ -1319,7 +1327,8 @@ static void ifa(CSOUND *csound)
       else switch (ST(bp)->pcnt) {      /*  watch for p1,p2,p3, */
       case 1:                           /*   & MYFLT, setinsno..*/
         if ((ST(op) == 'i' || ST(op) == 'q') && *ST(sp) == '"') {
-        /*   csound->DebugMsg(csound,"***Entering second dubious code scnt=%d\n", csound->scnt0); */
+        /*   csound->DebugMsg(csound,"***Entering second dubious code scnt=%d\n",
+             csound->scnt0); */
         /*   ST(bp)->p1val = ((int[4]){SSTRCOD,SSTRCOD1,
                                        SSTRCOD2,SSTRCOD3})[csound->scnt0++]; */
         /*   if (csound->scnt0>3) { */
@@ -1628,7 +1637,8 @@ static int sget1(CSOUND *csound)    /* get first non-white, non-comment char */
         }
         mm->body = corfile_create_w();
 #ifdef MACDEBUG
-        csound->DebugMsg(csound,"%s(%d): macro %s %p\n", __FILE__, __LINE__, mname, mm->body);
+        csound->DebugMsg(csound,"%s(%d): macro %s %p\n",
+                         __FILE__, __LINE__, mname, mm->body);
 #endif
         while ((c = getscochar(csound, 0)) != '#') {  /* Do not expand here!! */
           if (UNLIKELY(c==EOF))
@@ -1836,7 +1846,7 @@ MYFLT stof(CSOUND *csound, char s[])            /* convert string to MYFLT  */
     char    *p;
     MYFLT   x = (MYFLT) strtod(s, &p);
 
-    if (*p=='z') return FL(INF); /* Infinity or 7 years */
+    if (*p=='z') return FL(800000000000.0); /* 25367 years */
     if (UNLIKELY(s == p || !(*p == '\0' || isspace(*p)))) {
       csound->Message(csound, Str("sread: illegal number format:  "));
       p = s;
@@ -1850,4 +1860,3 @@ MYFLT stof(CSOUND *csound, char s[])            /* convert string to MYFLT  */
     }
     return x;
 }
-
