@@ -27,7 +27,7 @@
 #include <string.h>
 #include "csoundCore.h"
 #include "tok.h"
-#include "csound_orcparse.h"
+#include "csound_orc.h"
 #include "insert.h"
 #include "namedins.h"
 #include "interlocks.h"
@@ -132,6 +132,7 @@ void init_symbtab(CSOUND *csound)
     add_token(csound, "cosinv", T_FUNCTION);
     add_token(csound, "taninv", T_FUNCTION);
     add_token(csound, "log10", T_FUNCTION);
+    add_token(csound, "log2", T_FUNCTION);
     add_token(csound, "sinh", T_FUNCTION);
     add_token(csound, "cosh", T_FUNCTION);
     add_token(csound, "tanh", T_FUNCTION);
@@ -139,6 +140,7 @@ void init_symbtab(CSOUND *csound)
     add_token(csound, "ampdbfs", T_FUNCTION);
     add_token(csound, "dbamp", T_FUNCTION);
     add_token(csound, "dbfsamp", T_FUNCTION);
+    add_token_p(csound, "ftcps", T_FUNCTION, TR);
     add_token_p(csound, "ftlen", T_FUNCTION, TR);
     add_token_p(csound, "ftsr", T_FUNCTION, TR);
     add_token_p(csound, "ftlptim", T_FUNCTION, TR);
@@ -205,7 +207,7 @@ ORCTOKEN *add_token(CSOUND *csound, char *s, int type)
     while (a!=NULL) {
       if (strcmp(a->lexeme, s)==0) {
         if (type == a->type) return a;
-        if (type!= T_FUNCTION || a->type!=T_OPCODE) 
+        if (type!= T_FUNCTION || a->type!=T_OPCODE)
           csound->Warning(csound,
                           Str("Type confusion for %s (%d,%d), replacing\n"),
                           s, type, a->type);
@@ -230,13 +232,13 @@ static ORCTOKEN *add_token_p(CSOUND *csound, char *s, int type, int val)
     ans->value = val;
     return ans;
 }
-    
+
 int isUDOArgList(char *s)
 {
     int len = strlen(s) - 1;
 
     while (len >= 0) {
-      if (UNLIKELY(strchr("aijkftKopS0", s[len]) == NULL)) {
+      if (UNLIKELY(strchr("aijkftKOPVopS0", s[len]) == NULL)) {
         /* printf("Invalid char '%c' in '%s'", *p, s); */
         return 0;
       }
@@ -297,7 +299,7 @@ ORCTOKEN *lookup_token(CSOUND *csound, char *s, void *yyscanner)
         if (PARSER_DEBUG)
           csound->Message(csound, "Looking up token for: %d: %d: %s : %s\n",
                           hash("reverb"), hash("a4"), s, a->lexeme);
-			  }
+      }
       if (strcmp(a->lexeme, s)==0) {
         ans = (ORCTOKEN*)mmalloc(csound, sizeof(ORCTOKEN));
         memcpy(ans, a, sizeof(ORCTOKEN));
@@ -308,7 +310,7 @@ ORCTOKEN *lookup_token(CSOUND *csound, char *s, void *yyscanner)
       }
       a = a->next;
     }
-   
+
 
     ans = new_token(csound, T_IDENT);
     ans->lexeme = (char*)mmalloc(csound, 1+strlen(s));
@@ -367,7 +369,8 @@ ORCTOKEN *lookup_token(CSOUND *csound, char *s, void *yyscanner)
 /* UDO code below was from otran, broken out and modified for new parser by
  * SYY
  */
-/* VL -- I have made the modifications below to allow for f-sigs & t-sigs and on line 224 and 238*/
+/* VL -- I have made the modifications below to allow for f-sigs & t-sigs
+   and on line 224 and 238*/
 
 /* IV - Oct 12 2002: new function to parse arguments of opcode definitions */
 static int parse_opcode_args(CSOUND *csound, OENTRY *opc)
@@ -378,7 +381,7 @@ static int parse_opcode_args(CSOUND *csound, OENTRY *opc)
     int     S_incnt, S_outcnt, f_outcnt, f_incnt, t_incnt, t_outcnt;
     int16   *a_inlist, *k_inlist, *i_inlist, *a_outlist, *k_outlist, *i_outlist;
     int16   *S_inlist, *S_outlist, *f_inlist, *f_outlist, *t_inlist, *t_outlist;
-  
+
     /* count the number of arguments, and check types */
     i = i_incnt = S_incnt = a_incnt = k_incnt = f_incnt = f_outcnt =
         i_outcnt = S_outcnt = a_outcnt = k_outcnt = t_incnt = t_outcnt = err = 0;
@@ -391,6 +394,12 @@ static int parse_opcode_args(CSOUND *csound, OENTRY *opc)
       case 'a':
         a_incnt++; *otypes++ = *types;
         break;
+      case 'O':
+        k_incnt++; *otypes++ = 'O'; break;
+      case 'P':
+         k_incnt++;*otypes++ = 'P'; break;
+      case 'V':
+         k_incnt++;*otypes++ = 'V'; break;
       case 'K':
         i_incnt++;              /* also updated at i-time */
       case 'k':
@@ -482,9 +491,13 @@ static int parse_opcode_args(CSOUND *csound, OENTRY *opc)
     while (*types) {
       switch (*types++) {
         case 'a': *a_inlist++ = i; break;
+        case 'O':
+        case 'P':
+        case 'V':
         case 'k': *k_inlist++ = i; break;
         case 'f': *f_inlist++ = i; break;
         case 't': *t_inlist++ = i; break;
+
         case 'K': *k_inlist++ = i;      /* also updated at i-time */
         case 'i':
         case 'o':
@@ -494,9 +507,9 @@ static int parse_opcode_args(CSOUND *csound, OENTRY *opc)
       }
       i++;
     }
-      
+
     /* put delimiters */
-    *i_inlist = *S_inlist = *a_inlist = *k_inlist = *f_inlist = *t_inlist = -1; 
+    *i_inlist = *S_inlist = *a_inlist = *k_inlist = *f_inlist = *t_inlist = -1;
     i_outlist = inm->out_ndx_list = t_inlist + 1;
     S_outlist = i_outlist + i_outcnt + 1;
     a_outlist = S_outlist + S_outcnt + 1;
@@ -516,7 +529,7 @@ static int parse_opcode_args(CSOUND *csound, OENTRY *opc)
       }
       i++;
     }
-    
+
     *i_outlist = *S_outlist = *a_outlist = *k_outlist =
       *f_outlist = *t_outlist = -1;  /* put delimiters */
     return err;
