@@ -102,7 +102,7 @@ int     is_inf(CSOUND *, void *), is_infa(CSOUND *, void *);
 int     tan1(CSOUND *, void *), asin1(CSOUND *, void *);
 int     acos1(CSOUND *, void *), atan1(CSOUND *, void *);
 int     sinh1(CSOUND *, void *), cosh1(CSOUND *, void *);
-int     tanh1(CSOUND *, void *), log101(CSOUND *, void *);
+int     tanh1(CSOUND *, void *), log101(CSOUND *, void *), log21(CSOUND *, void *);
 int     atan21(CSOUND *, void *), atan2aa(CSOUND *, void *);
 int     absa(CSOUND *, void *), expa(CSOUND *, void *);
 int     loga(CSOUND *, void *), sqrta(CSOUND *, void *);
@@ -110,12 +110,13 @@ int     sina(CSOUND *, void *), cosa(CSOUND *, void *);
 int     tana(CSOUND *, void *), asina(CSOUND *, void *);
 int     acosa(CSOUND *, void *), atana(CSOUND *, void *);
 int     sinha(CSOUND *, void *), cosha(CSOUND *, void *);
-int     tanha(CSOUND *, void *), log10a(CSOUND *, void *);
+int     tanha(CSOUND *, void *), log10a(CSOUND *, void *), log2a(CSOUND *, void *);
 int     dbamp(CSOUND *, void *), ampdb(CSOUND *, void *);
 int     aampdb(CSOUND *, void *), dbfsamp(CSOUND *, void *);
 int     ampdbfs(CSOUND *, void *), aampdbfs(CSOUND *, void *);
 int     ftlen(CSOUND *, void *), ftlptim(CSOUND *, void *);
-int     ftchnls(CSOUND *, void *), ftcps(CSOUND *, void *), rtclock(CSOUND *, void *);
+int     ftchnls(CSOUND *, void *), ftcps(CSOUND *, void *);
+int     rtclock(CSOUND *, void *);
 int     cpsoct(CSOUND *, void *), octpch(CSOUND *, void *);
 int     cpspch(CSOUND *, void *), pchoct(CSOUND *, void *);
 int     octcps(CSOUND *, void *), acpsoct(CSOUND *, void *);
@@ -146,6 +147,10 @@ int     kline(CSOUND *, void *), aline(CSOUND *, void *);
 int     expset(CSOUND *, void *), kexpon(CSOUND *, void *);
 int     expon(CSOUND *, void *), lsgset(CSOUND *, void *);
 int     klnseg(CSOUND *, void *), linseg(CSOUND *, void *);
+int     csgset(CSOUND *, void *), kosseg(CSOUND *, void *);
+int     csgset_bkpt(CSOUND *, void *), cosseg(CSOUND *, void *);
+int     csgrset(CSOUND *, void *);
+int     kcssegr(CSOUND *, void *), cossegr(CSOUND *, void *);
 int     madsrset(CSOUND *, void *), adsrset(CSOUND *, void *);
 int     xdsrset(CSOUND *, void *), mxdsrset(CSOUND *, void *);
 int     expseg2(CSOUND *, void *), xsgset(CSOUND *, void *);
@@ -316,7 +321,7 @@ int     lp2_set(CSOUND *, void *), lp2(CSOUND *, void *);
 int     phaser2set(CSOUND *, void *), phaser2(CSOUND *, void *);
 int     phaser1set(CSOUND *, void *), phaser1(CSOUND *, void *);
 int     balnset(CSOUND *, void *), balance(CSOUND *, void *);
-int     prealloc(CSOUND *, void *);
+int     prealloc(CSOUND *, void *), active_alloc(CSOUND*, void*);
 int     cpsxpch(CSOUND *, void *), cps2pch(CSOUND *, void *);
 int     cpstmid(CSOUND *, void *);
 int     cpstun(CSOUND *, void *), cpstun_i(CSOUND *, void *);
@@ -403,3 +408,4 @@ int     xsgset_bkpt(CSOUND *csound, void *p);
 int     xsgset_bkpt(CSOUND *csound, void *p), xsgset2b(CSOUND *, void *);
 int     resize_table(CSOUND *csound, void *p);
 int     error_fn(CSOUND *csound, void *p);
+int fassign_set(CSOUND *csound, FASSIGN *p);
