@@ -51,7 +51,7 @@ typedef struct {
 
 #ifdef PIPES
 # if defined(SGI) || defined(LINUX) || defined(__BEOS__) || defined(NeXT) ||  \
-     defined(__MACH__)
+     defined(__MACH__) || defined(__HAIKU__)
 #  define _popen popen
 #  define _pclose pclose
 # endif
@@ -222,14 +222,14 @@ static void writesf_dither_16(CSOUND *csound, const MYFLT *outbuf, int nbytes)
       return;
 
     for (n=0; n<m; n++) {
-        int   tmp = ((ST(dither) * 15625) + 1) & 0xFFFF;
-        int   rnd = ((tmp * 15625) + 1) & 0xFFFF;
-        MYFLT result;
-        ST(dither) = rnd;
-        rnd = (rnd+tmp)>>1;           /* triangular distribution */
-        result = (MYFLT) (rnd - 0x8000)  / ((MYFLT) 0x10000);
-        result /= ((MYFLT) 0x7fff);
-        buf[n] += result;
+      int   tmp = ((ST(dither) * 15625) + 1) & 0xFFFF;
+      int   rnd = ((tmp * 15625) + 1) & 0xFFFF;
+      MYFLT result;
+      ST(dither) = rnd;
+      rnd = (rnd+tmp)>>1;           /* triangular distribution */
+      result = (MYFLT) (rnd - 0x8000)  / ((MYFLT) 0x10000);
+      result /= ((MYFLT) 0x7fff);
+      buf[n] += result;
     }
     n = (int) sf_write_MYFLT(ST(outfile), (MYFLT*) outbuf,
                              nbytes / sizeof(MYFLT)) * (int) sizeof(MYFLT);
@@ -521,13 +521,14 @@ void sfopenin(CSOUND *csound)           /* init for continuous soundin */
       ST(infile) = sf_open_fd(isfd, SFM_READ, &sfinfo, 0);
       if (UNLIKELY(ST(infile) == NULL)) {
         /* open failed: possibly raw file, but cannot seek back to try again */
-        csoundDie(csound, Str("isfinit: cannot open %s"), sfname);
+        const char *sfError = sf_strerror(NULL);
+        csoundDie(csound, Str("isfinit: cannot open %s -- %s"), sfname, sfError);
       }
     }
     else {
       fullName = csoundFindInputFile(csound, sfname, "SFDIR;SSDIR");
       if (UNLIKELY(fullName == NULL))                     /* if not found */
-        csoundDie(csound, Str("isfinit: cannot open %s"), sfname);
+        csoundDie(csound, Str("isfinit: cannot open %s [%n]"), sfname, __LINE__);
       ST(infile) = sf_open(fullName, SFM_READ, &sfinfo);
       if (ST(infile) == NULL) {
         /* open failed: maybe raw file ? */
@@ -538,8 +539,10 @@ void sfopenin(CSOUND *csound)           /* init for continuous soundin */
         sfinfo.format = TYPE2SF(TYP_RAW) | FORMAT2SF(O->outformat);
         ST(infile) = sf_open(fullName, SFM_READ, &sfinfo);  /* try again */
       }
-      if (UNLIKELY(ST(infile) == NULL))
-        csoundDie(csound, Str("isfinit: cannot open %s"), fullName);
+      if (UNLIKELY(ST(infile) == NULL)) {
+        const char *sfError = sf_strerror(NULL);
+        csoundDie(csound, Str("isfinit: cannot open %s -- %s"), fullName, sfError);
+      }
       /* only notify the host if we opened a real file, not stdin or a pipe */
       csoundNotifyFileOpened(csound, fullName,
                               sftype2csfiletype(sfinfo.format), 0, 0);
@@ -611,9 +614,17 @@ void sfopenout(CSOUND *csound)                  /* init for sound out       */
       osfd = fileno(ST(pout));
       ST(pipdevout) = 1;
       if (O->filetyp == TYP_AIFF || O->filetyp == TYP_WAV) {
-        csound->Message(csound, Str("Output file type changed to IRCAM "
-                                    "for use in pipe\n"));
-        O->filetyp = TYP_IRCAM;
+        char fmt_name[6];
+        if (O->sfsampsize == 8) {
+          strcpy(fmt_name, "AU");
+          O->filetyp = TYP_AU;
+        }
+        else {
+          strcpy(fmt_name, "IRCAM");
+          O->filetyp = TYP_IRCAM;
+        }
+        csound->Message(csound, Str("Output file type changed to %s "
+                                    "for use in pipe\n"), fmt_name);
       }
     }
 #endif
@@ -640,7 +651,8 @@ void sfopenout(CSOUND *csound)                  /* init for sound out       */
       }
       else if (strcmp(fName, "null") == 0) {
         ST(outfile) = NULL;
-        if (csound->dither_output && csound->oparms->outformat!=AE_FLOAT) {
+        if (csound->dither_output && csound->oparms->outformat!=AE_FLOAT &&
+            csound->oparms->outformat!=AE_DOUBLE) {
           if (csound->oparms->outformat==AE_SHORT)
             if (csound->dither_output==1)
               csound->audtran = writesf_dither_16;
@@ -668,15 +680,42 @@ void sfopenout(CSOUND *csound)                  /* init for sound out       */
     /* open file */
     if (ST(pipdevout)) {
       ST(outfile) = sf_open_fd(osfd, SFM_WRITE, &sfinfo, 0);
+#ifdef PIPES
+      if (ST(outfile) == NULL) {
+        char fmt_name[6];
+        if (O->sfsampsize == 8) {
+          if (O->filetyp == TYP_AU)
+            csoundDie(csound, Str("sfinit: cannot open fd %d [%d]\n%s"), osfd,
+                      __LINE__, sf_strerror(NULL));
+          strcpy(fmt_name, "AU");
+          O->filetyp = TYP_AU;
+        }
+        else {
+          if (O->filetyp == TYP_IRCAM)
+            csoundDie(csound, Str("sfinit: cannot open fd %d [%d]\n%s"), osfd,
+                      __LINE__, sf_strerror(NULL));
+          strcpy(fmt_name, "IRCAM");
+          O->filetyp = TYP_IRCAM;
+        }
+        csound->Message(csound, Str("Output file type changed to %s "
+                                    "for use in pipe\n"), fmt_name);
+        sfinfo.format = TYPE2SF(O->filetyp) | FORMAT2SF(O->outformat);
+        ST(outfile) = sf_open_fd(osfd, SFM_WRITE, &sfinfo, 0);
+      }
+#endif
+      if (UNLIKELY(ST(outfile) == NULL))
+        csoundDie(csound, Str("sfinit: cannot open fd %d\n%s"), osfd,
+                  sf_strerror(NULL));
     }
     else {
       fullName = csoundFindOutputFile(csound, fName, "SFDIR");
       if (UNLIKELY(fullName == NULL))
-        csoundDie(csound, Str("sfinit: cannot open %s"), fName);
+        csoundDie(csound, Str("sfinit: cannot open %s (%s) [%d]"),
+                  fName, fullName, __LINE__);
       ST(sfoutname) = fullName;
       ST(outfile) = sf_open(fullName, SFM_WRITE, &sfinfo);
       if (UNLIKELY(ST(outfile) == NULL))
-        csoundDie(csound, Str("sfinit: cannot open %s"), fullName);
+        csoundDie(csound, Str("sfinit: cannot open %s [%d]"), fullName, __LINE__);
       /* only notify the host if we opened a real file, not stdout or a pipe */
       csoundNotifyFileOpened(csound, fullName,
                               type2csfiletype(O->filetyp, O->outformat), 1, 0);
@@ -703,7 +742,8 @@ void sfopenout(CSOUND *csound)                  /* init for sound out       */
       csound->spoutran = spoutsf;       /* accumulate output */
     else
       csound->spoutran = spoutsf_noscale;
-    if (csound->dither_output && csound->oparms->outformat!=AE_FLOAT) {
+    if (csound->dither_output && csound->oparms->outformat!=AE_FLOAT &&
+        csound->oparms->outformat!=AE_DOUBLE) {
       if (csound->oparms->outformat==AE_SHORT)
         csound->audtran = writesf_dither_16;
       else if (csound->oparms->outformat==AE_CHAR)
@@ -797,7 +837,7 @@ void sfcloseout(CSOUND *csound)
     if (ST(pipdevout) == 2)
       goto report;
     if (ST(outfile) != NULL) {
-      if (!ST(pipdevout))
+      if (!ST(pipdevout) && O->outformat != AE_VORBIS)
         sf_command(ST(outfile), SFC_UPDATE_HEADER_NOW, NULL, 0);
       sf_close(ST(outfile));
       ST(outfile) = NULL;
