@@ -30,7 +30,7 @@
 #endif
 #include <portaudio.h>
 
-#define NO_FULLDUPLEX_PA_LOCK   0   
+#define NO_FULLDUPLEX_PA_LOCK   0
 
 typedef struct PaAlsaStreamInfo {
     unsigned long   size;
@@ -193,6 +193,8 @@ static int pa_SetStreamParameters(CSOUND *csound, PaStreamParameters *sp,
     if (dev < 0)
       return -1;
     sp->device = (PaDeviceIndex) dev;
+    if(!is_playback && (csound->nchnls != csound->inchnls))
+      parm->nChannels = csound->inchnls;
     sp->channelCount = (parm->nChannels < 2 ? 2 : parm->nChannels);
     sp->sampleFormat = (PaSampleFormat) paFloat32;
     sp->suggestedLatency = (PaTime) ((double) parm->bufSamp_HW
@@ -326,7 +328,8 @@ static int paBlockingReadWriteOpen(CSOUND *csound)
 
     /* clean up and report error */
  err_return:
-    rtclose_(csound);
+    csound->Die(csound, "Portaudio error \n");
+    //rtclose_(csound);
     return -1;
 }
 
@@ -355,12 +358,12 @@ static int paBlockingReadWriteStreamCallback(const void *input,
     float   *paInput = (float*) input;
     float   *paOutput = (float*) output;
 
-   
+
     if (pabs->complete == 1) {
         return paComplete;
     }
-    
-#ifdef WIN32    
+
+#ifdef WIN32
 if (pabs->paStream == NULL
       || pabs->paused
 ) {
@@ -378,13 +381,13 @@ return paContinue;
       /*#  ifdef WIN32 */
       err = csound->WaitThreadLock(pabs->paLock, (size_t) pabs->paLockTimeout);
     /*#  else
-    err = csound->WaitThreadLock(pabs->paLock, (size_t) 500); 
+    err = csound->WaitThreadLock(pabs->paLock, (size_t) 500);
 #  endif
     #else
       csound->WaitThreadLock(pabs->paLock, (size_t) 500);
       err = 0;
      #endif*/
- 
+
     if (pabs->mode & 1) {
       int n = pabs->inBufSamples;
       int i = 0;
@@ -407,7 +410,7 @@ return paContinue;
         paClearOutputBuffer(pabs, paOutput);
       }
     }
-   
+
    paClearOutputBuffer(pabs, pabs->outputBuffer);
    csound->NotifyThreadLock(pabs->clientLock);
 
@@ -499,7 +502,7 @@ static int recopen_(CSOUND *csound, const csRtAudioParams *parm)
     *(p->GetRtRecordUserData(p)) = (void*) pabs;
 
     pabs->complete = 0;
-    
+
     return 0;
 }
 
@@ -523,7 +526,7 @@ static int playopen_(CSOUND *csound, const csRtAudioParams *parm)
     *(p->GetRtPlayUserData(p)) = (void*) pabs;
 
     pabs->complete = 0;
-    
+
     return (paBlockingReadWriteOpen(p));
 }
 
@@ -536,7 +539,7 @@ static void rtclose_(CSOUND *csound)
                                                              "_rtpaGlobals");
     if (pabs == NULL)
       return;
-   
+
     pabs->complete = 1;
 
     if (pabs->paStream != NULL) {
@@ -551,7 +554,7 @@ static void rtclose_(CSOUND *csound)
         csound->NotifyThreadLock(pabs->clientLock);
 //        Pa_Sleep(80);
       }
-      
+
       Pa_StopStream(stream);
       Pa_CloseStream(stream);
 //      Pa_Sleep(80);
@@ -776,8 +779,9 @@ static void rtclose_blocking(CSOUND *csound)
 PUBLIC int csoundModuleCreate(CSOUND *csound)
 {
     /* nothing to do, report success */
-   csound->Message(csound,
-     Str("PortAudio real-time audio module for Csound\n"));
+    if (csound->oparms->msglevel & 0x400)
+      csound->Message(csound,
+                      Str("PortAudio real-time audio module for Csound\n"));
     return 0;
 }
 
@@ -794,7 +798,8 @@ PUBLIC int csoundModuleInit(CSOUND *csound)
     if (!(strcmp(drv, "PORTAUDIO") == 0 || strcmp(drv, "PA") == 0 ||
           strcmp(drv, "PA_BL") == 0 || strcmp(drv, "PA_CB") == 0))
       return 0;
-    csound->Message(csound, Str("rtaudio: PortAudio module enabled ... "));
+    if (csound->oparms->msglevel & 0x400)
+      csound->Message(csound, Str("rtaudio: PortAudio module enabled ... "));
     /* set function pointers */
 #ifdef LINUX
     if (strcmp(drv, "PA_CB") != 0)
@@ -833,4 +838,3 @@ PUBLIC int csoundModuleInfo(void)
 {
     return ((CS_APIVERSION << 16) + (CS_APISUBVER << 8) + (int) sizeof(MYFLT));
 }
-
