@@ -28,7 +28,11 @@
 #include <time.h>
 
 #define POW2TABSIZI 4096
-#define POW2MAX   24.0
+#if ULONG_MAX == 18446744073709551615UL
+#  define POW2MAX   (24.0)
+#else
+#  define POW2MAX   (15.0)
+#endif
 #define EIPT3       (25.0/3.0)
 #define LOGTWO      (0.69314718055994530942)
 #define STEPS       (32768)
@@ -48,35 +52,42 @@
     for (i = 0; i < OCTRES; i++)
       cpsocfrc[i] = POWER(FL(2.0), (MYFLT)i / OCTRES) * ONEPT;
     for (i = 0; i < POW2TABSIZI; i++)
-      powerof2[i] = POWER(FL(2.0), (MYFLT)i * (MYFLT)(1.0/POW2TABSIZI) - FL(POW2MAX));
+      powerof2[i] = POWER(FL(2.0),
+                          (MYFLT)i * (MYFLT)(1.0/POW2TABSIZI) - FL(POW2MAX));
 }*/
 
 /* initialise the tables, called by csoundPreCompile() */
 void csound_aops_init_tables(CSOUND *csound)
 {
     int   i;
-    if(csound->cpsocfrc==NULL)csound->cpsocfrc = (MYFLT *) csound->Malloc(csound, sizeof(MYFLT)*OCTRES);
-    if(csound->powerof2==NULL) csound->powerof2 = (MYFLT *) csound->Malloc(csound, sizeof(MYFLT)*POW2TABSIZI);
+    if (csound->cpsocfrc==NULL)
+      csound->cpsocfrc = (MYFLT *) csound->Malloc(csound, sizeof(MYFLT)*OCTRES);
+    if (csound->powerof2==NULL)
+      csound->powerof2 = (MYFLT *) csound->Malloc(csound,
+                                                  sizeof(MYFLT)*POW2TABSIZI);
     for (i = 0; i < OCTRES; i++)
       csound->cpsocfrc[i] = POWER(FL(2.0), (MYFLT)i / OCTRES) * ONEPT;
-    for (i = 0; i < POW2TABSIZI; i++)
-      csound->powerof2[i] = POWER(FL(2.0), (MYFLT)i * (MYFLT)(1.0/POW2TABSIZI) - FL(POW2MAX));
+    for (i = 0; i < POW2TABSIZI; i++) {
+      csound->powerof2[i] =
+        POWER(FL(2.0), (MYFLT)i * (MYFLT)(1.0/POW2TABSIZI) - FL(POW2MAX));
+    }
 }
 
 
-MYFLT csoundPow2(CSOUND *csound, MYFLT a){
-
-  if(a > POW2MAX) a = POW2MAX;
-  else if(a < -POW2MAX) a = -POW2MAX;
-    int n = (int)MYFLT2LRND(a * FL(POW2TABSIZI)) + POW2MAX*POW2TABSIZI;   /* 4096 * 15 */
+MYFLT csoundPow2(CSOUND *csound, MYFLT a)
+{
+    int n;
+    if (a > POW2MAX) a = POW2MAX;
+    else if (a < -POW2MAX) a = -POW2MAX;
+  /* 4096 * 15 */
+    n = (int)MYFLT2LRND(a * FL(POW2TABSIZI)) + POW2MAX*POW2TABSIZI;
     return ((MYFLT) (1UL << (n >> 12)) * csound->powerof2[n & (POW2TABSIZI-1)]);
-
 }
 
 
 /*static inline MYFLT pow2(MYFLT a)
 {
-    int n = (int)MYFLT2LRND(a * FL(POW2TABSIZI)) + POW2MAX*POW2TABSIZI;  
+    int n = (int)MYFLT2LRND(a * FL(POW2TABSIZI)) + POW2MAX*POW2TABSIZI;
     return ((MYFLT) (1 << (n >> 12)) * powerof2[n & (POW2TABSIZI-1)]);
 }*/
 
@@ -162,7 +173,7 @@ typedef struct {
     OPDS    h;
     TABDAT  *tab;
 } TABDEL;
-  
+
 static int tabdel(CSOUND *csound, void *p)
 {
     TABDAT *t = ((TABDEL*)p)->tab;
@@ -177,7 +188,7 @@ int tinit(CSOUND *csound, INITT *p)
     MYFLT val = *p->value;
     TABDAT *t = p->a;
     int i;
- 
+
     t->size = size;
     mfree(csound, t->data);
     t->data = mmalloc(csound, sizeof(MYFLT)*(size+1));
@@ -195,7 +206,7 @@ int tassign(CSOUND *csound, ASSIGNT *p)
 {
     TABDAT *t = p->tab;
     int ind = MYFLT2LRND(*p->ind);
-    if (ind<0 || ind>t->size) 
+    if (ind<0 || ind>t->size)
       return csound->PerfError(csound,
                                Str("Index %d out of range [0,%d] in t[]\n"),
                                ind, t->size);
@@ -214,7 +225,7 @@ int tabref(CSOUND *csound, TABREF *p)
 {
     int ind = MYFLT2LRND(*p->ind);
     TABDAT *t = p->tab;
-     if (ind<0 || ind>t->size) 
+     if (ind<0 || ind>t->size)
       return csound->PerfError(csound,
                                Str("Index %d out of range [0,%d] in t[]\n"),
                                ind, t->size);
@@ -562,6 +573,7 @@ LIB1(sinh1,SINH)
 LIB1(cosh1,COSH)
 LIB1(tanh1,TANH)
 LIB1(log101,LOG10)
+LIB1(log21,LOG2)
 
 int atan21(CSOUND *csound, AOP *p)
 {
@@ -593,6 +605,7 @@ LIBA(sinha,SINH)
 LIBA(cosha,COSH)
 LIBA(tanha,TANH)
 LIBA(log10a,LOG10)
+LIBA(log2a,LOG2)
 
 int atan2aa(CSOUND *csound, AOP *p)
 {
@@ -1097,9 +1110,9 @@ int ilogbasetwo(CSOUND *csound, EVAL *p)
 
 int in(CSOUND *csound, INM *p)
 {
-    CSOUND_SPIN_SPINLOCK
+    csoundSpinLock(&csound->spinlock);
     memcpy(p->ar, csound->spin, csound->ksmps * sizeof(MYFLT));
-    CSOUND_SPIN_SPINUNLOCK
+    csoundSpinUnLock(&csound->spinlock);
     return OK;
 }
 
@@ -1108,7 +1121,7 @@ int ins(CSOUND *csound, INS *p)
     MYFLT       *sp, *ar1, *ar2;
     int n, k;
     int nsmps = csound->ksmps;
-    CSOUND_SPIN_SPINLOCK
+    csoundSpinLock(&csound->spinlock);
     sp = csound->spin;
     ar1 = p->ar1;
     ar2 = p->ar2;
@@ -1116,7 +1129,7 @@ int ins(CSOUND *csound, INS *p)
       ar1[n] = sp[k];
       ar2[n] = sp[k+1];
     }
-    CSOUND_SPIN_SPINUNLOCK
+    csoundSpinUnLock(&csound->spinlock);
     return OK;
 }
 
@@ -1126,14 +1139,14 @@ int inq(CSOUND *csound, INQ *p)
                                     *ar3 = p->ar3, *ar4 = p->ar4;
     int n, k;
     int nsmps = csound->ksmps;
-    CSOUND_SPIN_SPINLOCK
+    csoundSpinLock(&csound->spinlock);
     for (n=0, k=0; n<nsmps; n++, k+=4) {
       ar1[n] = sp[k];
       ar2[n] = sp[k+1];
       ar3[n] = sp[k+2];
       ar4[n] = sp[k+3];
     }
-    CSOUND_SPIN_SPINUNLOCK
+    csoundSpinUnLock(&csound->spinlock);
     return OK;
 }
 
@@ -1143,7 +1156,7 @@ int inh(CSOUND *csound, INH *p)
                                     *ar4 = p->ar4, *ar5 = p->ar5, *ar6 = p->ar6;
     int n, k;
     int nsmps = csound->ksmps;
-    CSOUND_SPIN_SPINLOCK
+    csoundSpinLock(&csound->spinlock);
     for (n=0, k=0; n<nsmps; n++, k+=6) {
       ar1[n] = sp[k];
       ar2[n] = sp[k+1];
@@ -1152,7 +1165,7 @@ int inh(CSOUND *csound, INH *p)
       ar5[n] = sp[k+4];
       ar6[n] = sp[k+5];
     }
-    CSOUND_SPIN_SPINUNLOCK
+    csoundSpinUnLock(&csound->spinlock);
     return OK;
 }
 
@@ -1163,7 +1176,7 @@ int ino(CSOUND *csound, INO *p)
                                     *ar7 = p->ar7, *ar8 = p->ar8;
     int n, k;
     int nsmps = csound->ksmps;
-    CSOUND_SPIN_SPINLOCK
+    csoundSpinLock(&csound->spinlock);
     for (n=0, k=0; n<nsmps; n++, k+=8) {
       ar1[n] = sp[k];
       ar2[n] = sp[k+1];
@@ -1174,7 +1187,7 @@ int ino(CSOUND *csound, INO *p)
       ar7[n] = sp[k+6];
       ar8[n] = sp[k+7];
     }
-    CSOUND_SPIN_SPINUNLOCK
+    csoundSpinUnLock(&csound->spinlock);
     return OK;
 }
 
@@ -1184,12 +1197,12 @@ static int inn(CSOUND *csound, INALL *p, int n)
     int   m;
     int   i;
     int   nsmps = csound->ksmps;
-    CSOUND_SPIN_SPINLOCK
+    csoundSpinLock(&csound->spinlock);
     for (m = 0; m < nsmps; m++) {
       for (i = 0; i < n; i++)
         *ara[i] = *sp++;
     }
-    CSOUND_SPIN_SPINUNLOCK
+    csoundSpinUnLock(&csound->spinlock);
     return OK;
 }
 
@@ -1242,12 +1255,12 @@ int inch_opcode(CSOUND *csound, INCH *p)
 /*       return NOTOK; */
 /*     } */
 /*     /\* Are APINLOCKS really necessary for reading?? *\/ */
-/*     CSOUND_SPIN_SPINLOCK */
+/*     csoundSpinLock(&csound->spinlock); */
 /*     for (n = 0; n < nsmps; n++) { */
 /*       ain[n] = *sp; */
 /*       sp += csound->inchnls; */
 /*     } */
-/*     CSOUND_SPIN_SPINUNLOCK */
+/*     csoundSpinUnLock(&csound->spinlock); */
 /*     return OK; */
 /* } */
 
@@ -1257,7 +1270,7 @@ int inall_opcode(CSOUND *csound, INALL *p)
     int   m;
     int   i, j = 0, k = 0, nsmps = csound->ksmps;
     MYFLT *spin = csound->spin;
-    CSOUND_SPIN_SPINLOCK
+    csoundSpinLock(&csound->spinlock);
     m = (n < csound->inchnls ? n : csound->inchnls);
     for (j=0; j<nsmps; j++) {
       for (i=0; i<m; i++) {
@@ -1267,7 +1280,7 @@ int inall_opcode(CSOUND *csound, INALL *p)
         p->ar[i][j] = FL(0.0);
       k += csound->inchnls;
     }
-    CSOUND_SPIN_SPINUNLOCK
+    csoundSpinUnLock(&csound->spinlock);
     return OK;
 }
 
@@ -1277,7 +1290,7 @@ int out(CSOUND *csound, OUTM *p)
     int n;
     int nsmps = csound->ksmps;
     MYFLT *smp = p->asig;
-    CSOUND_SPOUT_SPINLOCK
+    csoundSpinLock(&csound->spoutlock);
     if (!csound->spoutactive) {
       memcpy(csound->spout, smp, nsmps * sizeof(MYFLT));
       csound->spoutactive = 1;
@@ -1286,7 +1299,7 @@ int out(CSOUND *csound, OUTM *p)
       for (n=0; n<nsmps; n++)
         csound->spout[n] += smp[n];
     }
-    CSOUND_SPOUT_SPINUNLOCK
+    csoundSpinUnLock(&csound->spoutlock);
     return OK;
 }
 
@@ -1294,7 +1307,7 @@ int outs(CSOUND *csound, OUTS *p)
 {
     MYFLT       *sp= csound->spout, *ap1 = p->asig1, *ap2= p->asig2;
     int nsmps = csound->ksmps;
-    CSOUND_SPOUT_SPINLOCK
+    csoundSpinLock(&csound->spoutlock);
     if (!csound->spoutactive) {
       int n, m;                   /* Amazingly this compiles better!!! */
       for (n=0, m=0; n<nsmps; n++) {
@@ -1310,7 +1323,7 @@ int outs(CSOUND *csound, OUTS *p)
         sp[m++] += ap2[n];
       }
     }
-    CSOUND_SPOUT_SPINUNLOCK
+    csoundSpinUnLock(&csound->spoutlock);
     return OK;
 }
 
@@ -1319,7 +1332,7 @@ int outq(CSOUND *csound, OUTQ *p)
     MYFLT       *sp= csound->spout, *ap1= p->asig1, *ap2= p->asig2,
                 *ap3= p->asig3, *ap4= p->asig4;
     int nsmps = csound->ksmps;
-    CSOUND_SPOUT_SPINLOCK
+    csoundSpinLock(&csound->spoutlock);
     sp = csound->spout;
     if (!csound->spoutactive) {
       int n, m;                   /* Amazingly this compiles better!!! */
@@ -1340,7 +1353,7 @@ int outq(CSOUND *csound, OUTQ *p)
         sp[m+3] += ap4[n];
       }
     }
-    CSOUND_SPOUT_SPINUNLOCK
+    csoundSpinUnLock(&csound->spoutlock);
     return OK;
 }
 #endif
@@ -1349,7 +1362,7 @@ int outs1(CSOUND *csound, OUTM *p)
 {
     MYFLT       *sp= csound->spout, *ap1= p->asig;
     int nsmps = csound->ksmps;
-    CSOUND_SPOUT_SPINLOCK
+    csoundSpinLock(&csound->spoutlock);
     if (!csound->spoutactive) {
       int n, m;                   /* Amazingly this compiles better!!! */
       for (n=0, m=0; n<nsmps; n++) {
@@ -1364,7 +1377,7 @@ int outs1(CSOUND *csound, OUTM *p)
         sp[m]   += ap1[n];
       }
     }
-    CSOUND_SPOUT_SPINUNLOCK
+    csoundSpinUnLock(&csound->spoutlock);
     return OK;
 }
 
@@ -1372,7 +1385,7 @@ int outs2(CSOUND *csound, OUTM *p)
 {
     MYFLT       *sp = csound->spout, *ap2 = p->asig;
     int nsmps = csound->ksmps;
-    CSOUND_SPOUT_SPINLOCK
+    csoundSpinLock(&csound->spoutlock);
     if (!csound->spoutactive) {
       int n, m;                   /* Amazingly this compiles better!!! */
       for (n=0, m=0; n<nsmps; n++) {
@@ -1387,7 +1400,7 @@ int outs2(CSOUND *csound, OUTM *p)
         sp[m] += ap2[n];
       }
     }
-    CSOUND_SPOUT_SPINUNLOCK
+    csoundSpinUnLock(&csound->spoutlock);
     return OK;
 }
 
@@ -1395,7 +1408,7 @@ int outs12(CSOUND *csound, OUTM *p)
 {
     MYFLT       *sp = csound->spout, *ap = p->asig;
     int nsmps = csound->ksmps;
-    CSOUND_SPOUT_SPINLOCK
+    csoundSpinLock(&csound->spoutlock);
 
     if (!csound->spoutactive) {
       int n, m;
@@ -1411,7 +1424,7 @@ int outs12(CSOUND *csound, OUTM *p)
         sp[m++] += ap[n];
       }
     }
-    CSOUND_SPOUT_SPINUNLOCK
+    csoundSpinUnLock(&csound->spoutlock);
     return OK;
 }
 
@@ -1419,7 +1432,7 @@ int outq1(CSOUND *csound, OUTM *p)
 {
     MYFLT       *sp = csound->spout, *ap1 = p->asig;
     int nsmps = csound->ksmps;
-    CSOUND_SPOUT_SPINLOCK
+    csoundSpinLock(&csound->spoutlock);
     if (!csound->spoutactive) {
       int n, m;
       for (n=0, m=0; n<nsmps; n++, m+=4) {
@@ -1436,7 +1449,7 @@ int outq1(CSOUND *csound, OUTM *p)
         sp[m]   += ap1[n];
       }
     }
-    CSOUND_SPOUT_SPINUNLOCK
+    csoundSpinUnLock(&csound->spoutlock);
     return OK;
 }
 
@@ -1444,7 +1457,7 @@ int outq2(CSOUND *csound, OUTM *p)
 {
     MYFLT       *sp = csound->spout, *ap2 = p->asig;
     int nsmps = csound->ksmps;
-    CSOUND_SPOUT_SPINLOCK
+    csoundSpinLock(&csound->spoutlock);
     if (!csound->spoutactive) {
       int n, m;
       for (n=0, m=0; n<nsmps; n++, m+=4) {
@@ -1461,7 +1474,7 @@ int outq2(CSOUND *csound, OUTM *p)
         sp[m]   += ap2[n];
       }
     }
-    CSOUND_SPOUT_SPINUNLOCK
+    csoundSpinUnLock(&csound->spoutlock);
     return OK;
 }
 
@@ -1469,7 +1482,7 @@ int outq3(CSOUND *csound, OUTM *p)
 {
     MYFLT       *sp = csound->spout, *ap3 = p->asig;
     int nsmps = csound->ksmps;
-    CSOUND_SPOUT_SPINLOCK
+    csoundSpinLock(&csound->spoutlock);
     if (!csound->spoutactive) {
       int n, m;
       for (n=0, m=0; n<nsmps; n++, m+=4) {
@@ -1486,7 +1499,7 @@ int outq3(CSOUND *csound, OUTM *p)
         sp[m]   += ap3[n];
       }
     }
-    CSOUND_SPOUT_SPINUNLOCK
+    csoundSpinUnLock(&csound->spoutlock);
     return OK;
 }
 
@@ -1494,7 +1507,7 @@ int outq4(CSOUND *csound, OUTM *p)
 {
     MYFLT       *sp = csound->spout, *ap4 = p->asig;
     int nsmps = csound->ksmps;
-    CSOUND_SPOUT_SPINLOCK
+    csoundSpinLock(&csound->spoutlock);
     if (!csound->spoutactive) {
       int n, m;
       for (n=0, m=0; n<nsmps; n++, m+=4) {
@@ -1511,7 +1524,7 @@ int outq4(CSOUND *csound, OUTM *p)
         sp[m]   += ap4[n];
       }
     }
-    CSOUND_SPOUT_SPINUNLOCK
+    csoundSpinUnLock(&csound->spoutlock);
     return OK;
 }
 
@@ -1521,7 +1534,7 @@ int outh(CSOUND *csound, OUTH *p)
     MYFLT *sp = csound->spout, *ap1 = p->asig1, *ap2 = p->asig2, *ap3 = p->asig3,
                                *ap4 = p->asig4, *ap5 = p->asig5, *ap6 = p->asig6;
     int nsmps = csound->ksmps;
-    CSOUND_SPOUT_SPINLOCK
+    csoundSpinLock(&csound->spoutlock);
     if (!csound->spoutactive) {
       int n, m;
       for (n=0, m=0; n<nsmps; n++, m+=6) {
@@ -1545,7 +1558,7 @@ int outh(CSOUND *csound, OUTH *p)
         sp[m+5] += ap6[n];
       }
     }
-    CSOUND_SPOUT_SPINUNLOCK
+    csoundSpinUnLock(&csound->spoutlock);
     return OK;
 }
 
@@ -1555,7 +1568,7 @@ int outo(CSOUND *csound, OUTO *p)
                                *ap4 = p->asig4, *ap5 = p->asig5, *ap6 = p->asig6,
                                *ap7 = p->asig7, *ap8 = p->asig8;
     int nsmps = csound->ksmps;
-    CSOUND_SPOUT_SPINLOCK
+    csoundSpinLock(&csound->spoutlock);
     if (!csound->spoutactive) {
       int n, m;
       for (n=0, m=0; n<nsmps; n++, m+=8) {
@@ -1583,7 +1596,7 @@ int outo(CSOUND *csound, OUTO *p)
         sp[m+7] += ap8[n];
       }
     }
-    CSOUND_SPOUT_SPINUNLOCK
+    csoundSpinUnLock(&csound->spoutlock);
     return OK;
 }
 #endif
@@ -1592,7 +1605,7 @@ static int outn(CSOUND *csound, int n, OUTX *p)
 {
     int   i, j = 0, k = 0;
     int nsmps = csound->ksmps;
-    CSOUND_SPOUT_SPINLOCK
+    csoundSpinLock(&csound->spoutlock);
     if (!csound->spoutactive) {
       for (j=0; j<nsmps; j++) {
         for (i=0; i<n; i++) {
@@ -1613,7 +1626,7 @@ static int outn(CSOUND *csound, int n, OUTX *p)
         k += csound->nchnls;
       }
     }
-    CSOUND_SPOUT_SPINUNLOCK
+    csoundSpinUnLock(&csound->spoutlock);
     return OK;
 }
 
@@ -1644,7 +1657,7 @@ int outch(CSOUND *csound, OUTCH *p)
     int         count = (int)p->INOCOUNT;
     MYFLT       **args = p->args;
     int         nchnls = csound->nchnls;
-    CSOUND_SPOUT_SPINLOCK
+    csoundSpinLock(&csound->spoutlock);
     for (j = 0; j < count; j += 2) {
       ch = (int)(*args[j] + FL(0.5));
       apn = args[j + 1];
@@ -1667,7 +1680,7 @@ int outch(CSOUND *csound, OUTCH *p)
         }
       }
     }
-    CSOUND_SPOUT_SPINUNLOCK
+    csoundSpinUnLock(&csound->spoutlock);
     return OK;
 }
 
@@ -1804,7 +1817,7 @@ int is_NaNa(CSOUND *csound, ASSIGN *p)
     int k, nsmps = csound->ksmps;
     MYFLT *a = p->a;
     *p->r = FL(0.0);
-    for (k=0; k<nsmps; k++) 
+    for (k=0; k<nsmps; k++)
       *p->r += isnan(a[k]);
     return OK;
 }
