@@ -500,7 +500,7 @@ static CS_NOINLINE channelEntry_t *alloc_channel(CSOUND *csound, MYFLT **p,
 {
     channelEntry_t  dummy;
     void            *pp;
-    int             nbytes, nameOffs, dataOffs;
+    int             nbytes, nameOffs, dataOffs, lockOffs;
 
     (void) dummy;
     nameOffs = (int)((char*) &(dummy.name[0]) - (char*) &dummy);
@@ -508,6 +508,7 @@ static CS_NOINLINE channelEntry_t *alloc_channel(CSOUND *csound, MYFLT **p,
     dataOffs += ((int)sizeof(MYFLT) - 1);
     dataOffs = (dataOffs / (int)sizeof(MYFLT)) * (int)sizeof(MYFLT);
     nbytes = dataOffs;
+    lockOffs = (int)((char*) &(dummy.lock) - (char*) &dummy);
     if (*p == NULL) {
       switch (type & CSOUND_CHANNEL_TYPE_MASK) {
       case CSOUND_CONTROL_CHANNEL:
@@ -525,6 +526,11 @@ static CS_NOINLINE channelEntry_t *alloc_channel(CSOUND *csound, MYFLT **p,
     if (pp == NULL)
       return (channelEntry_t*) NULL;
     memset(pp, 0, (size_t) nbytes);
+#ifndef MACOSX
+#if defined(HAVE_PTHREAD_SPIN_LOCK) 
+    pthread_spin_init((int*)((char*) pp + (int)lockOffs), PTHREAD_PROCESS_PRIVATE);
+#endif
+#endif
     if (*p == NULL)
       *p = (MYFLT*) ((char*) pp + (int)dataOffs);
     return (channelEntry_t*) pp;
@@ -547,7 +553,7 @@ static CS_NOINLINE int create_new_channel(CSOUND *csound, MYFLT **p,
     do {
       h = strhash_tabl_8[(unsigned char) *(s++) ^ h];
     } while (isalnum((unsigned char) *s) ||
-             *s == (char) '_' || *s == (char) '.');
+             *s == (char) '_' || *s == (char) '-' || *s == (char) '.');
     if (*s != (char) 0)
       return CSOUND_ERROR;
     /* create new empty database on first call */
@@ -1389,8 +1395,9 @@ int sensekey_perf(CSOUND *csound, KSENSE *p)
         retval = select(1, &rfds, NULL, NULL, &tv);
 
         if (retval) {
-          char    ch = (char) 0;
-          read(0, &ch, 1);
+          char    ch = '\0';
+          if (UNLIKELY(read(0, &ch, 1)!=1))
+            csound->Die(csound, "read failure in sensekey\n");
           keyCode = (int)((unsigned char) ch);
           /* FD_ISSET(0, &rfds) will be true. */
         }
