@@ -140,7 +140,7 @@ int pvssanalset(CSOUND *csound, PVSANAL *p)
       double *s = c+NB;
       p->cosine = c;
       p->sine = s;
-      c[0] = 1.0; s[0] = 0.0;
+      c[0] = 1.0; s[0] = 0.0; // assignment to s unnecessary as auxalloc zeros
         /*
           direct computation of c and s may be better for large n
           c[i] = cos(2*M_PI*i/n);
@@ -164,7 +164,7 @@ int pvsanalset(CSOUND *csound, PVSANAL *p)
     MYFLT *analwinhalf,*analwinbase;
     MYFLT sum;
     int32 halfwinsize,buflen;
-    int i,nBins,Mf,Lf;
+    int i,nBins,Mf;
 
     /* opcode params */
     int32 N =(int32) *(p->fftsize);
@@ -196,7 +196,7 @@ int pvsanalset(CSOUND *csound, PVSANAL *p)
     /* we can exclude/simplify all sorts of stuff in CARL
      * as we will never do time-scaling with this opcode
      */
-    Lf = Mf = 1 - M%2;
+    Mf = 1 - M%2;
 
     csound->AuxAlloc(csound, overlap * sizeof(MYFLT), &p->overlapbuf);
     csound->AuxAlloc(csound, (N+2) * sizeof(MYFLT), &p->analbuf);
@@ -228,13 +228,13 @@ int pvsanalset(CSOUND *csound, PVSANAL *p)
     }
     /* get net amp */
     sum = FL(0.0);
-    
+
     for (i = -halfwinsize; i <= halfwinsize; i++)
       sum += *(analwinhalf + i);
     sum = FL(2.0) / sum;  /* factor of 2 comes in later in trig identity */
     for (i = -halfwinsize; i <= halfwinsize; i++)
       *(analwinhalf + i) *= sum;
-    
+
 
   /*    p->invR = (float)(FL(1.0) / csound->esr); */
     p->RoverTwoPi = (float)(p->arate / TWOPI_F);
@@ -363,7 +363,9 @@ static void generate_frame(CSOUND *csound, PVSANAL *p)
     }
 #endif
     /*if (format==PVS_AMP_FREQ) {*/
-    for (i=ii=0/*,i0=anal,i1=anal+1,oi=oldInPhase*/; i <= N2; i++,ii+=2/*i0+=2,i1+=2, oi++*/) {
+    for (i=ii=0    /*,i0=anal,i1=anal+1,oi=oldInPhase*/;
+         i <= N2;
+         i++,ii+=2 /*i0+=2,i1+=2, oi++*/) {
       real = anal[ii] /* *i0 */;
       imag = anal[ii+1] /* *i1 */;
       /**i0*/ anal[ii] = HYPOT(real, imag);
@@ -384,7 +386,7 @@ static void generate_frame(CSOUND *csound, PVSANAL *p)
 
       /* add in filter center freq.*/
       /* *i1 */ anal[ii+1]  = angleDif * p->RoverTwoPi + ((MYFLT) i * p->Fexact);
-     
+
     }
     /* } */
     /* else must be PVOC_COMPLEX */
@@ -479,7 +481,7 @@ int pvssanal(CSOUND *csound, PVSANAL *p)
       /* Rectang :Fw_t =     F_t                          */
       /* Hamming :Fw_t = 0.54F_t - 0.23[ F_{t-1}+F_{t+1}] */
       /* Hamming :Fw_t = 0.5 F_t - 0.25[ F_{t-1}+F_{t+1}] */
-      /* Blackman:Fw_t = 0.42F_t - 0.25[ F_{t-1}+F_{t+1}] + 0.04[F_{t-2}+F_{t+2}] */
+      /* Blackman:Fw_t = 0.42F_t - 0.25[ F_{t-1}+F_{t+1}]+0.04[F_{t-2}+F_{t+2}] */
       /* Blackman_exact:Fw_t = 0.42659071367153912296F_t
          - 0.24828030954428202923 [F_{t-1}+F_{t+1}]
          + 0.038424333619948409286 [F_{t-2}+F_{t+2}]      */
@@ -681,7 +683,7 @@ int pvsynthset(CSOUND *csound, PVSYNTH *p)
     int32 halfwinsize,buflen;
     int i,nBins,Mf,Lf;
     double IO;
-      
+
     /* get params from input fsig */
     /* we TRUST they are legal */
     int32 N = p->fsig->N;
@@ -722,34 +724,34 @@ int pvsynthset(CSOUND *csound, PVSYNTH *p)
     csound->AuxAlloc(csound, nBins * sizeof(MYFLT), &p->oldOutPhase);
     csound->AuxAlloc(csound, buflen * sizeof(MYFLT), &p->output);
 
-  
+
 
 
     synwinhalf = (MYFLT *) (p->synwinbuf.auxp) + halfwinsize;
- 
-    
-  
+
+
+
     /* synthesis windows */
     if (M <= N) {
       if (UNLIKELY(PVS_CreateWindow(csound, synwinhalf, wintype, M) != OK))
         return NOTOK;
-  
+
       for (i = 1; i <= halfwinsize; i++)
         *(synwinhalf - i) = *(synwinhalf + i - Lf);
-       
 
-       sum = FL(0.0); 
+
+       sum = FL(0.0);
         for (i = -halfwinsize; i <= halfwinsize; i++)
            sum += *(synwinhalf + i);
          sum = FL(2.0) / sum;
 
        for (i = -halfwinsize; i <= halfwinsize; i++)
         *(synwinhalf + i) *= sum;
-      
-         sum = FL(0.0); 
+
+         sum = FL(0.0);
    /* no timescaling, so I(nterpolation) will always = D(ecimation) = overlap */
         for (i = -halfwinsize; i <= halfwinsize; i+=overlap)
-          sum += *(synwinhalf + i) * *(synwinhalf + i); 
+          sum += *(synwinhalf + i) * *(synwinhalf + i);
     }
     else {
      /* have to make analysis window to get amp scaling */
@@ -761,8 +763,8 @@ int pvsynthset(CSOUND *csound, PVSYNTH *p)
 
     for (i = 1; i <= halfwinsize; i++)
       analwinhalf[-i] = analwinhalf[i - Mf];
-    
-      // sinc function 
+
+      // sinc function
       if (Mf)
         *analwinhalf *= (MYFLT)(dN * sin(PI*0.5/dN) / ( PI*0.5));
       for (i = 1; i <= halfwinsize; i++)
@@ -770,9 +772,9 @@ int pvsynthset(CSOUND *csound, PVSYNTH *p)
           (dN * sin((double)(PI*(i+0.5*Mf)/dN)) / (PI*(i+0.5*Mf)));
       for (i = 1; i <= halfwinsize; i++)
         *(analwinhalf - i) = *(analwinhalf + i - Mf);
-    
+
      /* get net amp */
-    sum = FL(0.0); 
+    sum = FL(0.0);
     for (i = -halfwinsize; i <= halfwinsize; i++)
     sum += *(analwinhalf + i);
     sum = FL(2.0) / sum;  /* factor of 2 comes in later in trig identity */
@@ -792,16 +794,16 @@ int pvsynthset(CSOUND *csound, PVSYNTH *p)
       for (i = 1; i <= halfwinsize; i++)
         *(synwinhalf - i) = *(synwinhalf + i - Lf);
     }
-   
-   
+
+
    if (!(N & (N - 1L)))
      sum = csound->GetInverseRealFFTScale(csound, (int) N) / sum;
     else
       sum = FL(1.0) / sum;
-   
+
   for (i = -halfwinsize; i <= halfwinsize; i++)
       *(synwinhalf + i) *= sum;
- 
+
 /*  p->invR = FL(1.0) / csound->esr; */
     p->RoverTwoPi = p->arate / TWOPI_F;
     p->TwoPioverR = TWOPI_F / p->arate;
@@ -831,7 +833,7 @@ static void process_frame(CSOUND *csound, PVSYNTH *p)
 {
     int i,j,k,ii,NO,NO2;
     float *anal;                                        /* RWD MUST be 32bit */
-    MYFLT *syn,*bsyn,*output;
+    MYFLT *syn,*output;
     MYFLT *oldOutPhase = (MYFLT *) (p->oldOutPhase.auxp);
     int32 N = p->fsig->N;
     MYFLT *obufptr,*outbuf,*synWindow;
@@ -851,7 +853,7 @@ static void process_frame(CSOUND *csound, PVSYNTH *p)
     outbuf = (MYFLT *) (p->overlapbuf.auxp);
     synWindow = (MYFLT *) (p->synwinbuf.auxp) + synWinLen;
 
-    bsyn = syn+1;
+    //bsyn = syn+1;
     /* reconversion: The magnitude and angle-difference-per-second in syn
        (assuming an intermediate sampling rate of rOut) are
        converted to real and imaginary values and are returned in syn.
@@ -1101,4 +1103,3 @@ static void vonhann(MYFLT *win, int winLen, int even)
         win[i] = (MYFLT)(0.5 + 0.5 * cos(ftmp*(double)i));
     }
 }
-
