@@ -87,11 +87,11 @@ int ephsor(CSOUND *csound, EPHSOR *p)
         b *= R;
         if (UNLIKELY(phase >= 1.0)) {
           phase -= 1.0;
-          b = pow(R, 1+phase); 
+          b = pow(R, 1+phase);
         }
         else if (UNLIKELY(phase < 0.0)) {
           phase += 1.0;
-          b = pow(R, 1+phase); 
+          b = pow(R, 1+phase);
         }
       }
     }
@@ -104,11 +104,11 @@ int ephsor(CSOUND *csound, EPHSOR *p)
         b *= R;
         if (UNLIKELY(phase >= 1.0)) {
           phase -= 1.0;
-          b =  pow(R, 1+phase); 
+          b =  pow(R, 1+phase);
         }
         else if (UNLIKELY(phase < 0.0)) {
           phase += 1.0;
-          b = pow(R, 1+phase); 
+          b = pow(R, 1+phase);
         }
       }
     }
@@ -144,8 +144,8 @@ int phsor(CSOUND *csound, PHSOR *p)
         incr = (double)(cps[n] * onedsr);
         rs[n] = (MYFLT)phase;
         phase += incr;
-        if (UNLIKELY((MYFLT)phase >= 1.0)) /* VL convert to MYFLT 
-                                              to avoid rounded output 
+        if (UNLIKELY((MYFLT)phase >= 1.0)) /* VL convert to MYFLT
+                                              to avoid rounded output
                                               exceeding 1.0 on float version */
           phase -= 1.0;
         else if (UNLIKELY((MYFLT)phase < 0.0))
@@ -194,7 +194,7 @@ int phsor(CSOUND *csound, PHSOR *p)
 
 static int itblchk(CSOUND *csound, TABLE *p)
 {
-    if (UNLIKELY((p->ftp = csound->FTFind(csound, p->xfn)) == NULL))
+    if (UNLIKELY((p->ftp = csound->FTnp2Find(csound, p->xfn)) == NULL))
       return NOTOK;
 
     /* Although TABLE has an integer variable for the table number
@@ -1032,7 +1032,7 @@ int oscnset(CSOUND *csound, OSCILN *p)
 {
     FUNC        *ftp;
 
-    if (LIKELY((ftp = csound->FTFind(csound, p->ifn)) != NULL)) {
+    if (LIKELY((ftp = csound->FTnp2Find(csound, p->ifn)) != NULL)) {
       p->ftp = ftp;
       p->inc = ftp->flen * *p->ifrq * csound->onedsr;
       p->index = FL(0.0);
@@ -1134,6 +1134,7 @@ int osckk(CSOUND *csound, OSC *p)
       phs = (phs+inc)&PHMASK;
     }
     p->lphs = phs;
+    
     return OK;
  err1:
     return csound->PerfError(csound, Str("oscil: not initialised"));
@@ -1589,4 +1590,3 @@ int oscaa3(CSOUND *csound, OSC   *p)
  err1:
     return csound->PerfError(csound, Str("oscil3: not initialised"));
 }
-
