@@ -22,14 +22,16 @@
     02111-1307 USA
 */
 
-#include "csdl.h"
+//#include "csdl.h"
+#include "csoundCore.h"
+#include "interlocks.h"
 #include <math.h>
 
 typedef struct {
     OPDS    h;                                      /* required header */
     MYFLT   *mw, *mx, *my, *mz, *mr, *ms, *mt, *mu, *mv, *mk,
             *ml, *mm, *mn, *mo, *mp, *mq;           /* addr outarg */
-  MYFLT   *asig, *kalpha, *kbeta, *kin[4];          /* addr inargs */
+    MYFLT   *asig, *kalpha, *kbeta, *kin[4];          /* addr inargs */
     /* private dataspace */
     double  w, x, y, z, r, s, t, u, v, k, l, m, n, o, p, q;
 } AMBIC;
@@ -287,7 +289,9 @@ static int iambideco(CSOUND *csound, AMBID *p)
                     Str("bformdec is deprecated; use bformdec1 instead\n"));
     if (setup<0) setup = -setup;
     /* check correct number of input arguments */
-    if (UNLIKELY((p->INOCOUNT != 5) && (p->INOCOUNT != 10) && (p->INOCOUNT != 17))) {
+    if (UNLIKELY((p->INOCOUNT != 5)  &&
+                 (p->INOCOUNT != 10) &&
+                 (p->INOCOUNT != 17))) {
       return csound->InitError(csound, Str("Wrong number of input arguments!"));
     }
 
@@ -450,15 +454,20 @@ static int iambideco(CSOUND *csound, AMBID *p)
           }
           else {
             int i;
-            static double w[] = {0.1768, 0.1768, 0.1768, 0.1768, 0.1768, 0.1768, 0.1768, 0.1768};
-            static double x[] = {0.1591, 0.0659,-0.0659,-0.1591,-0.1591,-0.0659, 0.0659, 0.1591};
-            static double y[] = {0.0659, 0.1591, 0.1591, 0.0659,-0.0659,-0.1591,-0.1591,-0.0659};
+            static double w[] = {0.1768, 0.1768, 0.1768, 0.1768,
+                                 0.1768, 0.1768, 0.1768, 0.1768};
+            static double x[] = {0.1591, 0.0659, -0.0659,-0.1591,
+                                 -0.1591,-0.0659, 0.0659, 0.1591};
+            static double y[] = {0.0659,  0.1591, 0.1591, 0.0659,
+                                 -0.0659,-0.1591,-0.1591,-0.0659};
 /*             static double z[] = {0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0}; */
 /*             static double r[] = {0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0}; */
 /*             static double s[] = {0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0}; */
 /*             static double t[] = {0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0}; */
-            static double u[] = {0.0342,-0.0342,-0.0342, 0.0342, 0.0342,-0.0342,-0.0342, 0.0342};
-            static double v[] = {0.0342, 0.0342,-0.0342,-0.0342, 0.0342, 0.0342,-0.0342,-0.0342};
+            static double u[] = {0.0342,-0.0342,-0.0342, 0.0342,
+                                 0.0342,-0.0342,-0.0342, 0.0342};
+            static double v[] = {0.0342, 0.0342,-0.0342,-0.0342,
+                                 0.0342, 0.0342,-0.0342,-0.0342};
             for (i=0; i<8; i++) {
               p->w[i] = w[i];
               p->x[i] = x[i];
@@ -500,15 +509,22 @@ static int iambideco(CSOUND *csound, AMBID *p)
           }
           else {
             int i;
-            static double w[] = {0.1768,0.1768,0.1768,0.1768,0.1768,0.1768,0.1768,0.1768};
-            static double x[] = {0.1140, 0.1140,-0.1140,-0.1140, 0.1140, 0.1140,-0.1140,-0.1140};
-            static double y[] = {0.1140,-0.1140,-0.1140, 0.1140, 0.1140,-0.1140,-0.1140, 0.1140};
-            static double z[] = {-0.1140,-0.1140,-0.1140,-0.1140, 0.1140, 0.1140, 0.1140, 0.1140};
+            static double w[] = {0.1768,0.1768,0.1768,0.1768,
+                                 0.1768,0.1768,0.1768,0.1768};
+            static double x[] = {0.1140, 0.1140,-0.1140,-0.1140,
+                                 0.1140, 0.1140,-0.1140,-0.1140};
+            static double y[] = {0.1140,-0.1140,-0.1140, 0.1140,
+                                 0.1140,-0.1140,-0.1140, 0.1140};
+            static double z[] = {-0.1140,-0.1140,-0.1140,-0.1140,
+                                 0.1140, 0.1140, 0.1140, 0.1140};
 /*             static double r[] = {0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0}; */
-            static double s[] = {-0.0369,-0.0369, 0.0369, 0.0369, 0.0369, 0.0369,-0.0369,-0.0369};
-            static double t[] = {-0.0369, 0.0369, 0.0369,-0.0369, 0.0369,-0.0369,-0.0369, 0.0369};
+            static double s[] = {-0.0369,-0.0369, 0.0369, 0.0369,
+                                 0.0369, 0.0369,-0.0369,-0.0369};
+            static double t[] = {-0.0369, 0.0369, 0.0369,-0.0369,
+                                 0.0369,-0.0369,-0.0369, 0.0369};
 /*             static double u[] = {0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0}; */
-            static double v[] = { 0.0369,-0.0369, 0.0369,-0.0369, 0.0369,-0.0369, 0.0369,-0.0369};
+            static double v[] = { 0.0369,-0.0369, 0.0369,-0.0369,
+                                  0.0369,-0.0369, 0.0369,-0.0369};
             for (i=0; i<8; i++) {
               p->w[i] = w[i];
               p->x[i] = x[i];
@@ -714,9 +730,9 @@ static int aambideco(CSOUND *csound, AMBID *p)
 #define S(x)    sizeof(x)
 
 static OENTRY localops[] = {
-  { "bformenc", S(AMBIC), DP|5, "mmmmmmmmmmmmmmmm", "akkPPPP",
+  { "bformenc", S(AMBIC), _QQ|5, "mmmmmmmmmmmmmmmm", "akkPPPP",
                             (SUBR)iambicode, NULL, (SUBR)aambicode },
-  { "bformdec", S(AMBID), DP|5, "mmmmmmmm", "iaaay",
+  { "bformdec", S(AMBID), _QQ|5, "mmmmmmmm", "iaaay",
                             (SUBR)iambideco, NULL, (SUBR)aambideco }
 };
 
@@ -725,4 +741,3 @@ int ambicode_init_(CSOUND *csound)
     return csound->AppendOpcodes(csound, &(localops[0]),
                                  (int) (sizeof(localops) / sizeof(OENTRY)));
 }
-
