@@ -313,7 +313,7 @@ int tableifilter (CSOUND *csound, TABFILT *p)
     if (p->pdft != (int)*p->dft) {
       /* Get pointer to the function table data structure.
        * csoundFTFindP() for perf time. csoundFTFind() for init time. */
-      if (UNLIKELY((p->funcd = csound->FTFind(csound, p->dft)) == NULL)) {
+      if (UNLIKELY((p->funcd = csound->FTnp2Find(csound, p->dft)) == NULL)) {
         return
           csound->InitError(csound,
                             Str("Farey: Destination dft table %.2f not found."),
@@ -325,7 +325,7 @@ int tableifilter (CSOUND *csound, TABFILT *p)
     }
     /* Source  */
     if (p->psft != (int)*p->sft) {
-      if (UNLIKELY((p->funcs = csound->FTFind(csound, p->sft)) == NULL)) {
+      if (UNLIKELY((p->funcs = csound->FTnp2Find(csound, p->sft)) == NULL)) {
         return csound->InitError(csound,
                                  Str("Farey: Source sft table %.2f not found."),
                                  *p->sft);
@@ -357,12 +357,12 @@ static int dotablefilter (CSOUND *csound, TABFILT *p)
     MYFLT threshold;
     int32 ftype;
     MYFLT previous = FL(0.0);
-    int32 sourcelength;
+    //int32 sourcelength;
 
     ftype = (int32) *p->ftype;
     threshold = Digest (*p->threshold);
     loopcount = p->funcd->flen;
-    sourcelength = loopcount;
+    //sourcelength = loopcount;
 
     /* Now get the base addresses and length masks of the tables. */
     based  = p->funcd->ftable;
@@ -470,7 +470,7 @@ int tableishuffle (CSOUND *csound, TABSHUFFLE *p) {
 
     /* Source  */
     if (p->psft != (int)*p->sft) {
-      if (UNLIKELY((p->funcs = csound->FTFind(csound, p->sft)) == NULL)) {
+      if (UNLIKELY((p->funcs = csound->FTnp2Find(csound, p->sft)) == NULL)) {
         return csound->InitError(csound,
                                  Str("Source sft table %.2f not found."),
                                  *p->sft);
@@ -490,19 +490,19 @@ static int dotableshuffle (CSOUND *csound, TABSHUFFLE *p)
 {
     time_t now;
     unsigned int seed = (unsigned int) time (&now);
-    srand (seed);
 
     MYFLT *bases;       /* Base address of the source table.*/
+    MYFLT *temp;
     int32 sourcelength;
     int32 i = 0;
 
+    srand (seed);
     sourcelength = p->funcs->flen;
 
     /* Now get the base address of the table. */
     bases = p->funcs->ftable;
 
-    MYFLT* temp; 
-    temp = (MYFLT*) calloc (sourcelength, sizeof(MYFLT)); 
+    temp = (MYFLT*) calloc (sourcelength, sizeof(MYFLT));
     memset (temp, 0, sizeof(MYFLT) * sourcelength);
 
     for (i = 0; i < sourcelength; i++) {
@@ -532,7 +532,7 @@ int fareylen (CSOUND *csound, FAREYLEN *p)
 int EulerPhi (int n)
 {
     int i = 0;
-    int pcount;
+    //int pcount;
     MYFLT result;
     PFACTOR p[MAX_PFACTOR];
     memset(p, 0, sizeof(PFACTOR)*MAX_PFACTOR);
@@ -541,7 +541,7 @@ int EulerPhi (int n)
       return 1;
     if (n == 0)
       return 0;
-    pcount = PrimeFactors (n, p);
+    (void)PrimeFactors (n, p);
 
     result = (MYFLT)n;
     for (i = 0; i < MAX_PFACTOR; i++) {
