@@ -54,7 +54,7 @@ static CS_NOINLINE int fout_deinit_callback(CSOUND *csound, void *p_)
           pp->name = (char*) NULL;
           pp->do_scale = 0;
           pp->refCount = 0U;
-      
+
           if (pp->fd != NULL) {
             if ((csound->oparms->msglevel & 7) == 7)
               csound->Message(csound, Str("Closing file '%s'...\n"),
@@ -174,9 +174,9 @@ static CS_NOINLINE int fout_open_file(CSOUND *csound, FOUT_FILE *p, void *fp,
     else {
       SNDFILE *sf;
       void    *fd;
-      int     buf_reqd, do_scale = 0;
+      //int     buf_reqd;
+      int     do_scale = 0;
 
-      buf_reqd = (int) ((SF_INFO*) fileParams)->channels;
       if (fileType == CSFILE_SND_W) {
         do_scale = ((SF_INFO*) fileParams)->format;
         csFileType = csound->sftype2csfiletype(do_scale);
@@ -201,15 +201,17 @@ static CS_NOINLINE int fout_open_file(CSOUND *csound, FOUT_FILE *p, void *fp,
         sf_command(sf, SFC_SET_NORM_FLOAT, NULL, SF_FALSE);
 #endif
       }
-      /* reallocate buffer if necessary */
-      if ((int) ((SF_INFO*) fileParams)->channels > buf_reqd)
-        buf_reqd = (int) ((SF_INFO*) fileParams)->channels;
-      buf_reqd *= csound->ksmps;
+      /* if (csound->ksmps >= 512)
+        buf_reqd = csound->ksmps * ((SF_INFO*) fileParams)->channels;
+      else
+        buf_reqd = (1 + (int)(512 / CS_KSMPS)) * CS_KSMPS
+                   * ((SF_INFO*) fileParams)->channels;
       if (UNLIKELY(buf_reqd > pp->buf_size)) {
         pp->buf_size = buf_reqd;
         pp->buf = (MYFLT*) csound->ReAlloc(csound, pp->buf, sizeof(MYFLT)
                                                             * buf_reqd);
-      }
+							    }
+      */ /* VL - now using per-instance buffer */
       pp->file_opened[idx].file = sf;
       pp->file_opened[idx].fd = fd;
       pp->file_opened[idx].do_scale = do_scale;
@@ -247,10 +249,10 @@ static CS_NOINLINE int fout_open_file(CSOUND *csound, FOUT_FILE *p, void *fp,
 
 static int outfile(CSOUND *csound, OUTFILE *p)
 {
-    STDOPCOD_GLOBALS  *pp = (STDOPCOD_GLOBALS*) csound->stdOp_Env;
     int   i, j, k;
-    int   nsmps = csound->ksmps;
+    int   nsmps = CS_KSMPS;
     int nargs = p->nargs;
+    MYFLT *buf = (MYFLT *) p->buf.auxp;
 
     if (p->f.sf == NULL) {
       if (p->f.f != NULL) { /* VL: make sure there is an open file */
@@ -263,14 +265,19 @@ static int outfile(CSOUND *csound, OUTFILE *p)
       }
     }
     else {
-      for (j = k = 0; j < nsmps; j++)
+      for (j = 0, k = p->buf_pos; j < nsmps; j++) 
         for (i = 0; i < nargs; i++)
-          pp->buf[k++] = p->argums[i][j] * p->scaleFac;
+          buf[k++] = p->argums[i][j] * p->scaleFac;
+      p->buf_pos = k;
+      if (p->buf_pos >= p->guard_pos) {
 #ifndef USE_DOUBLE
-      sf_writef_float(p->f.sf, (float*) pp->buf, nsmps);
+        sf_write_float(p->f.sf, buf, p->buf_pos);
 #else
-      sf_writef_double(p->f.sf, (double*) pp->buf, nsmps);
-#endif
+        sf_write_double(p->f.sf, buf, p->buf_pos);
+	#endif
+        p->buf_pos = 0;
+       }
+      
     }
     return OK;
 }
@@ -306,10 +313,23 @@ static const int fout_format_table[50] = {
     (SF_FORMAT_PCM_24 | SF_FORMAT_IRCAM), (SF_FORMAT_DOUBLE | SF_FORMAT_IRCAM)
 };
 
+static int fout_flush_callback(CSOUND *csound, void *p_)
+{
+    OUTFILE            *p = (OUTFILE*) p_;
+ 
+    if (p->f.sf != NULL && p->buf_pos > 0)
+#ifndef USE_DOUBLE
+      sf_write_float(p->f.sf, (float*) p->buf.auxp, p->buf_pos);
+#else
+      sf_write_double(p->f.sf, (double*) p->buf.auxp, p->buf_pos);
+#endif
+    return OK;
+}
+
 static int outfile_set(CSOUND *csound, OUTFILE *p)
 {
     SF_INFO sfinfo;
-    int     format_, n;
+    int     format_, n, buf_reqd;
 
     memset(&sfinfo, 0, sizeof(SF_INFO));
     format_ = (int) MYFLT2LRND(*p->iflag);
@@ -323,43 +343,70 @@ static int outfile_set(CSOUND *csound, OUTFILE *p)
       sfinfo.format |= TYPE2SF(csound->oparms->filetyp);
     sfinfo.samplerate = (int) MYFLT2LRND(csound->esr);
     p->nargs = p->INOCOUNT - 2;
+    p->buf_pos = 0;
+
+    if (CS_KSMPS >= 512)
+      p->guard_pos = CS_KSMPS * p->nargs;
+    else
+      p->guard_pos = 512 * p->nargs;
+
     sfinfo.channels = p->nargs;
     n = fout_open_file(csound, &(p->f), NULL, CSFILE_SND_W,
                        p->fname, p->XSTRCODE, &sfinfo);
     if (UNLIKELY(n < 0))
       return NOTOK;
 
+     if (CS_KSMPS >= 512)
+        buf_reqd = CS_KSMPS *  p->nargs;
+      else
+        buf_reqd = (1 + (int)(512 / CS_KSMPS)) * CS_KSMPS *  p->nargs;
+     if (p->buf.auxp == NULL || p->buf.size < buf_reqd*sizeof(MYFLT)) {
+	csound->AuxAlloc(csound, sizeof(MYFLT)*buf_reqd, &p->buf);
+      }
+
     if (((STDOPCOD_GLOBALS*) csound->stdOp_Env)->file_opened[n].do_scale)
       p->scaleFac = csound->dbfs_to_float;
     else
       p->scaleFac = FL(1.0);
 
+    csound->RegisterDeinitCallback(csound, p, fout_flush_callback);
     return OK;
 }
 
 static int koutfile(CSOUND *csound, KOUTFILE *p)
 {
-    STDOPCOD_GLOBALS  *pp = (STDOPCOD_GLOBALS*) csound->stdOp_Env;
-    int   i;
+    int   i, k;
     int nargs = p->nargs;
+    MYFLT *buf = (MYFLT *) p->buf.auxp;
 
-    for (i = 0; i < nargs; i++)
-      pp->buf[i] = p->argums[i][0] * p->scaleFac;
+    for (i = 0, k = p->buf_pos; i < nargs; i++)
+      buf[k++] = p->argums[i][0] * p->scaleFac;
+    p->buf_pos = k;
+    if (p->buf_pos >= p->guard_pos) {
 #ifndef USE_DOUBLE
-    sf_writef_float(p->f.sf, (float*) pp->buf, 1);
+      sf_write_float(p->f.sf, buf, p->buf_pos);
 #else
-    sf_writef_double(p->f.sf, (double*) pp->buf, 1);
+      sf_write_double(p->f.sf, buf, p->buf_pos);
 #endif
+      p->buf_pos = 0;
+    }
     return OK;
 }
 
 static int koutfile_set(CSOUND *csound, KOUTFILE *p)
 {
     SF_INFO sfinfo;
-    int     format_, n;
+    int     format_, n, buf_reqd;
 
     memset(&sfinfo, 0, sizeof(SF_INFO));
     p->nargs = p->INOCOUNT - 2;
+    p->buf_pos = 0;
+
+    if (CS_KSMPS >= 512)
+      p->guard_pos = CS_KSMPS * p->nargs;
+    else
+      p->guard_pos = 512 * p->nargs;
+
     sfinfo.channels = p->nargs;
     sfinfo.samplerate = (int) MYFLT2LRND(csound->ekr);
     format_ = (int) MYFLT2LRND(*p->iflag);
@@ -372,11 +419,21 @@ static int koutfile_set(CSOUND *csound, KOUTFILE *p)
     if (UNLIKELY(n < 0))
       return NOTOK;
 
+    if (CS_KSMPS >= 512)
+        buf_reqd = CS_KSMPS *  p->nargs;
+      else
+        buf_reqd = (1 + (int)(512 / CS_KSMPS)) * CS_KSMPS
+	  *  p->nargs;
+     if (p->buf.auxp == NULL || p->buf.size < buf_reqd*sizeof(MYFLT)) {
+	csound->AuxAlloc(csound, sizeof(MYFLT)*buf_reqd, &p->buf);
+      }
+
     if (((STDOPCOD_GLOBALS*) csound->stdOp_Env)->file_opened[n].do_scale)
       p->scaleFac = csound->dbfs_to_float;
     else
       p->scaleFac = FL(1.0);
 
+    csound->RegisterDeinitCallback(csound, p, fout_flush_callback);
     return OK;
 }
 
@@ -483,7 +540,7 @@ static int ioutfile_set(CSOUND *csound, IOUTFILE *p)
       case 1:
         {     /* with prefix (i-statement, p1, p2 and p3) */
           int     p1 = (int) p->h.insdshead->p1;
-          double  p2 = (double) csound->kcounter * csound->onedkr;
+          double  p2 = (double) CS_KCNT * CS_ONEDKR;
           double  p3 = p->h.insdshead->p3;
           if (p3 > FL(0.0))
             fprintf(rfil, "i %i %f %f ", p1, p2, p3);
@@ -493,11 +550,11 @@ static int ioutfile_set(CSOUND *csound, IOUTFILE *p)
         break;
       case 2: /* with prefix (start at 0 time) */
         if (pp->fout_kreset == 0)
-          pp->fout_kreset = csound->kcounter;
+          pp->fout_kreset = CS_KCNT;
         {
           int p1 = (int) p->h.insdshead->p1;
-          double p2 = (double) (csound->kcounter - pp->fout_kreset)
-                      * csound->onedkr;
+          double p2 = (double) (CS_KCNT - pp->fout_kreset)
+                      * CS_ONEDKR;
           double p3 = p->h.insdshead->p3;
           if (p3 > FL(0.0))
             fprintf(rfil, "i %i %f %f ", p1, p2, p3);
@@ -516,7 +573,7 @@ static int ioutfile_set(CSOUND *csound, IOUTFILE *p)
     }
     else { /* binary format */
       for (j = 0; j < p->INOCOUNT - 3; j++) {
-        fwrite(args[j], sizeof(MYFLT), 1, rfil);
+        if (UNLIKELY(1!=fwrite(args[j], sizeof(MYFLT), 1, rfil))) return NOTOK;
       }
     }
     return OK;
@@ -527,10 +584,10 @@ static int ioutfile_set_r(CSOUND *csound, IOUTFILE_R *p)
     STDOPCOD_GLOBALS  *pp = (STDOPCOD_GLOBALS*) csound->stdOp_Env;
     if (p->h.insdshead->xtratim < 1)
       p->h.insdshead->xtratim = 1;
-    p->counter =  csound->kcounter;
+    p->counter =  CS_KCNT;
     p->done = 1;
     if (*p->iflag == 2 && pp->fout_kreset == 0)
-      pp->fout_kreset = csound->kcounter;
+      pp->fout_kreset = CS_KCNT;
     return OK;
 }
 
@@ -557,18 +614,18 @@ static int ioutfile_r(CSOUND *csound, IOUTFILE_R *p)
       case 1:
         {     /* whith prefix (i-statement, p1, p2 and p3) */
           int p1 = (int) p->h.insdshead->p1;
-          double p2 = p->counter * csound->onedkr;
-          double p3 = (double) (csound->kcounter - p->counter)
-                      * csound->onedkr;
+          double p2 = p->counter * CS_ONEDKR;
+          double p3 = (double) (CS_KCNT - p->counter)
+                      * CS_ONEDKR;
           fprintf(rfil, "i %i %f %f ", p1, p2, p3);
         }
         break;
       case 2: /* with prefix (start at 0 time) */
         {
           int p1 = (int) p->h.insdshead->p1;
-          double p2 = (p->counter - pp->fout_kreset) * csound->onedkr;
-          double p3 = (double) (csound->kcounter - p->counter)
-                      * csound->onedkr;
+          double p2 = (p->counter - pp->fout_kreset) * CS_ONEDKR;
+          double p3 = (double) (CS_KCNT - p->counter)
+                      * CS_ONEDKR;
           fprintf(rfil, "i %i %f %f ", p1, p2, p3);
         }
         break;
@@ -583,7 +640,7 @@ static int ioutfile_r(CSOUND *csound, IOUTFILE_R *p)
     }
     else { /* binary format */
       for (j = 0; j < p->INOCOUNT - 3; j++) {
-        fwrite(args[j], sizeof(MYFLT), 1, rfil);
+        if (UNLIKELY(1!=fwrite(args[j], sizeof(MYFLT), 1, rfil))) return NOTOK;
       }
     }
     p->done = 0;
@@ -596,7 +653,7 @@ static int ioutfile_r(CSOUND *csound, IOUTFILE_R *p)
 static int infile_set(CSOUND *csound, INFILE *p)
 {
     SF_INFO sfinfo;
-    int     n;
+    int     n, buf_reqd;
 
     memset(&sfinfo, 0, sizeof(SF_INFO));
     sfinfo.samplerate = (int) MYFLT2LRND(csound->esr);
@@ -618,31 +675,60 @@ static int infile_set(CSOUND *csound, INFILE *p)
     p->currpos = MYFLT2LRND(*p->iskpfrms);
     p->flag = 1;
 
+    if (CS_KSMPS >= 512)
+      p->frames = CS_KSMPS;
+    else
+      p->frames = (int)(512 / CS_KSMPS) * CS_KSMPS;
+
+    if (CS_KSMPS >= 512)
+        buf_reqd = CS_KSMPS *   sfinfo.channels;
+      else
+        buf_reqd = (1 + (int)(512 / CS_KSMPS)) * CS_KSMPS
+	  *  p->nargs;
+     if (p->buf.auxp == NULL || p->buf.size < buf_reqd*sizeof(MYFLT)) {
+	csound->AuxAlloc(csound, sizeof(MYFLT)*buf_reqd, &p->buf);
+      }
+
+    p->guard_pos = p->frames * p->nargs;
+    p->buf_pos = p->guard_pos;
+
     return OK;
 }
 
 static int infile_act(CSOUND *csound, INFILE *p)
 {
-    STDOPCOD_GLOBALS  *pp = (STDOPCOD_GLOBALS*) csound->stdOp_Env;
-    int   i, j = 0, k = 0, n;
-    int nsmps = csound->ksmps, nargs = p->nargs;
+    
+    int   i, j = 0, k;
+    int nsmps = CS_KSMPS, nargs = p->nargs;
+    MYFLT *buf = (MYFLT *) p->buf.auxp;
 
     if (p->flag) {
-      sf_seek(p->f.sf, p->currpos, SEEK_SET);
-      p->currpos += nsmps;
+      if (p->buf_pos >= p->guard_pos) {
+        sf_seek(p->f.sf, p->currpos, SEEK_SET);
+        p->currpos += p->frames;
 #ifndef USE_DOUBLE
-      n = (int) sf_readf_float(p->f.sf, (float*) pp->buf, nsmps);
+        p->remain = (int) sf_readf_float(p->f.sf, (float*) buf, p->frames);
 #else
-      n = (int) sf_readf_double(p->f.sf, (double*) pp->buf, nsmps);
+        p->remain = (int) sf_readf_double(p->f.sf, (double*) buf, p->frames);
 #endif
-      for ( ; j < n; j++)
+        p->buf_pos = 0;
+      }
+      if (p->remain < nsmps)
+        nsmps = p->remain;
+      for (k = p->buf_pos; j < nsmps; j++)
         for (i = 0; i < nargs; i++)
-          p->argums[i][j] = pp->buf[k++] * p->scaleFac;
-      if (n >= csound->ksmps)
-        return OK;
-      p->flag = 0;
+          p->argums[i][j] = buf[k++] * p->scaleFac;
+      p->buf_pos = k;
+      p->remain -= CS_KSMPS;
+      if (p->remain <= 0 && p->buf_pos < p->guard_pos) {
+        p->flag = 0;
+        for (; j < CS_KSMPS; j++)
+          for (i = 0; i < nargs; i++)
+            p->argums[i][j] = FL(0.0);
+      }
+      return OK;
     }
-    for ( ; j < nsmps; j++)
+    for ( ; j < CS_KSMPS; j++)
       for (i = 0; i < nargs; i++)
         p->argums[i][j] = FL(0.0);
 
@@ -654,7 +740,7 @@ static int infile_act(CSOUND *csound, INFILE *p)
 static int kinfile_set(CSOUND *csound, KINFILE *p)
 {
     SF_INFO sfinfo;
-    int     n;
+    int     n, buf_reqd;
 
     memset(&sfinfo, 0, sizeof(SF_INFO));
     sfinfo.samplerate = (int) MYFLT2LRND(csound->ekr);
@@ -676,26 +762,48 @@ static int kinfile_set(CSOUND *csound, KINFILE *p)
     p->currpos = MYFLT2LRND(*p->iskpfrms);
     p->flag = 1;
 
+    if (CS_KSMPS >= 512)
+      p->frames = CS_KSMPS;
+    else
+      p->frames = (int)(512 / CS_KSMPS) * CS_KSMPS;
+
+   if (CS_KSMPS >= 512)
+        buf_reqd = CS_KSMPS *   sfinfo.channels;
+      else
+        buf_reqd = (1 + (int)(512 / CS_KSMPS)) * CS_KSMPS
+	  *  p->nargs;
+     if (p->buf.auxp == NULL || p->buf.size < buf_reqd*sizeof(MYFLT)) {
+	csound->AuxAlloc(csound, sizeof(MYFLT)*buf_reqd, &p->buf);
+      }
+
+    p->guard_pos = p->frames * p->nargs;
+    p->buf_pos = p->guard_pos;
+
     return OK;
 }
 
 static int kinfile(CSOUND *csound, KINFILE *p)
 {
-    STDOPCOD_GLOBALS  *pp = (STDOPCOD_GLOBALS*) csound->stdOp_Env;
-    int   i, n;
+    int   i, k;
     int nargs = p->nargs;
+    MYFLT *buf = (MYFLT *) p->buf.auxp;
 
     if (p->flag) {
-      sf_seek(p->f.sf, p->currpos, SEEK_SET);
-       p->currpos++;
+      if (p->buf_pos >= p->guard_pos) {
+        sf_seek(p->f.sf, p->currpos, SEEK_SET);
+        p->currpos += p->frames;
 #ifndef USE_DOUBLE
-      n = (int) sf_readf_float(p->f.sf, (float*) pp->buf, 1);
+        p->remain = (int) sf_readf_float(p->f.sf, buf, p->frames);
 #else
-      n = (int) sf_readf_double(p->f.sf, (double*) pp->buf, 1);
+        p->remain = (int) sf_readf_double(p->f.sf, buf, p->frames);
 #endif
-      if (n > 0) {
-        for (i = 0; i < nargs; i++)
-          p->argums[i][0] = pp->buf[i] * p->scaleFac;
+        p->buf_pos = 0;
+      }
+      if (p->remain > 0) {
+        for (i = 0, k = p->buf_pos; i < nargs; i++)
+          p->argums[i][0] = buf[k++] * p->scaleFac;
+        p->buf_pos = k;
+        p->remain--;
         return OK;
       }
       p->flag = 0;
@@ -791,15 +899,15 @@ static int incr(CSOUND *csound, INCR *p)
     MYFLT *avar = p->avar, *aincr = p->aincr;
     int   n;
 
-    for (n = 0; n < csound->ksmps; n++)
+    for (n = 0; n < CS_KSMPS; n++)
       avar[n] += aincr[n];
     return OK;
 }
 
 static int clear(CSOUND *csound, CLEARS *p)
 {
-    int   nsmps = csound->ksmps, j;
-    
+    int   nsmps = CS_KSMPS, j;
+
     for (j = 0; j < p->INOCOUNT; j++) {
       memset(p->argums[j], 0, sizeof(MYFLT)*nsmps);
     }
@@ -942,7 +1050,7 @@ static void sprints(char *outstring, char *fmt, MYFLT **kvals, int32 numVals)
 
           switch (*segwaiting) {
           case '%':
-            sprintf(outstring, "%");
+            sprintf(outstring, "%%");
             j--;
             break;
           case 'd':
@@ -993,7 +1101,7 @@ static void sprints(char *outstring, char *fmt, MYFLT **kvals, int32 numVals)
       if (segwaiting) {
         switch (*segwaiting) {
           case '%':
-            sprintf(outstring, "%");
+            sprintf(outstring, "%%");
             j--;
             break;
         case 'd':
