@@ -101,7 +101,7 @@ static int ftgen(CSOUND *csound, FTGEN *p)
     fp[2] = ftevt->p2orig = FL(0.0);                    /* force time 0 */
     fp[3] = ftevt->p3orig = *p->p3;
     fp[4] = *p->p4;
-    
+
     if ((n = csound->GetInputArgSMask(p)))
       if (n&0x8) {              /* Named gen */
         NAMEDGEN *n = (NAMEDGEN*) csound->GetNamedGens(csound);
@@ -252,77 +252,78 @@ static int ftload(CSOUND *csound, FTLOAD *p)
         memset(&header, 0, sizeof(FUNC));
         /* IMPORTANT!! If FUNC structure and/or GEN01ARGS structure
            will be modified, the following code has to be modified too */
-        fgets(s, 64, file);
-        fgets(s, 64, file);  s1 = strchr(s, ' ')+1;
+        if (UNLIKELY(NULL==fgets(s, 64, file))) goto err4;
+        if (UNLIKELY(NULL==fgets(s, 64, file))) goto err4;
+        s1 = strchr(s, ' ')+1;
         header.flen = strtol(s1, &endptr, 10);
         if (UNLIKELY(endptr==NULL)) goto err4;
-        fgets(s, 64, file);  s1 = strchr(s, ' ')+1;
+        if (UNLIKELY(NULL==fgets(s, 64, file))) goto err4;  s1 = strchr(s, ' ')+1;
         header.lenmask = strtol(s1, &endptr, 10);
         if (UNLIKELY(endptr==NULL)) goto err4;
-        fgets(s, 64, file);  s1 = strchr(s, ' ')+1;
+        if (UNLIKELY(NULL==fgets(s, 64, file))) goto err4;  s1 = strchr(s, ' ')+1;
         header.lobits = strtol(s1, &endptr, 10);
         if (UNLIKELY(endptr==NULL)) goto err4;
-        fgets(s, 64, file);  s1 = strchr(s, ' ')+1;
+        if (UNLIKELY(NULL==fgets(s, 64, file))) goto err4;  s1 = strchr(s, ' ')+1;
         header.lomask = strtol(s1, &endptr, 10);
         if (UNLIKELY(endptr==NULL)) goto err4;
-        fgets(s, 64, file);  s1 = strchr(s, ' ')+1;
+        if (UNLIKELY(NULL==fgets(s, 64, file))) goto err4;  s1 = strchr(s, ' ')+1;
         header.lodiv = (MYFLT)strtol(s1, &endptr, 10);
         if (UNLIKELY(endptr==NULL)) goto err4;
-        fgets(s, 64, file);  s1 = strchr(s, ' ')+1;
+        if (UNLIKELY(NULL==fgets(s, 64, file))) goto err4;  s1 = strchr(s, ' ')+1;
         header.cvtbas = (MYFLT)strtol(s1, &endptr, 10);
         if (UNLIKELY(endptr==NULL)) goto err4;
-        fgets(s, 64, file);  s1 = strchr(s, ' ')+1;
+        if (UNLIKELY(NULL==fgets(s, 64, file))) goto err4;  s1 = strchr(s, ' ')+1;
         header.cpscvt = (MYFLT)strtol(s1, &endptr, 10);
         if (UNLIKELY(endptr==NULL)) goto err4;
-        fgets(s, 64, file);  s1 = strchr(s, ' ')+1;
+        if (UNLIKELY(NULL==fgets(s, 64, file))) goto err4;  s1 = strchr(s, ' ')+1;
         header.loopmode1 = (int16) strtol(s1, &endptr, 10);
         if (UNLIKELY(endptr==NULL)) goto err4;
-        fgets(s, 64, file);  s1 = strchr(s, ' ')+1;
+        if (UNLIKELY(NULL==fgets(s, 64, file))) goto err4;  s1 = strchr(s, ' ')+1;
         header.loopmode2 = (int16) strtol(s1, &endptr, 10);
         if (UNLIKELY(endptr==NULL)) goto err4;
-        fgets(s, 64, file);  s1 = strchr(s, ' ')+1;
+        if (UNLIKELY(NULL==fgets(s, 64, file))) goto err4;  s1 = strchr(s, ' ')+1;
         header.begin1 = strtol(s1, &endptr, 10);
         if (UNLIKELY(endptr==NULL)) goto err4;
-        fgets(s, 64, file);  s1 = strchr(s, ' ')+1;
+        if (UNLIKELY(NULL==fgets(s, 64, file))) goto err4;  s1 = strchr(s, ' ')+1;
         header.end1 = strtol(s1, &endptr, 10);
         if (UNLIKELY(endptr==NULL)) goto err4;
-        fgets(s, 64, file);  s1 = strchr(s, ' ')+1;
+        if (UNLIKELY(NULL==fgets(s, 64, file))) goto err4;  s1 = strchr(s, ' ')+1;
         header.begin2 = strtol(s1, &endptr, 10);
         if (UNLIKELY(endptr==NULL)) goto err4;
-        fgets(s, 64, file);  s1 = strchr(s, ' ')+1;
+        if (UNLIKELY(NULL==fgets(s, 64, file))) goto err4;  s1 = strchr(s, ' ')+1;
         header.end2 = strtol(s1, &endptr, 10);
         if (UNLIKELY(endptr==NULL)) goto err4;
-        fgets(s, 64, file);  s1 = strchr(s, ' ')+1;
+        if (UNLIKELY(NULL==fgets(s, 64, file))) goto err4;  s1 = strchr(s, ' ')+1;
         header.soundend = strtol(s1, &endptr, 10);
         if (UNLIKELY(endptr==NULL)) goto err4;
-        fgets(s, 64, file);  s1 = strchr(s, ' ')+1;
+        if (UNLIKELY(NULL==fgets(s, 64, file))) goto err4;  s1 = strchr(s, ' ')+1;
         header.flenfrms = strtol(s1, &endptr, 10);
         if (UNLIKELY(endptr==NULL)) goto err4;
-        fgets(s, 64, file);  s1 = strchr(s, ' ')+1;
+        if (UNLIKELY(NULL==fgets(s, 64, file))) goto err4;  s1 = strchr(s, ' ')+1;
         header.nchanls = strtol(s1, &endptr, 10);
         if (UNLIKELY(endptr==NULL)) goto err4;
-        fgets(s, 64, file);  s1 = strchr(s, ' ')+1;
+        if (UNLIKELY(NULL==fgets(s, 64, file))) goto err4;  s1 = strchr(s, ' ')+1;
         header.fno = strtol(s1, &endptr, 10);
         if (UNLIKELY(endptr==NULL)) goto err4;
-        fgets(s, 64, file);  s1 = strchr(s, ' ')+1;
+        if (UNLIKELY(NULL==fgets(s, 64, file))) goto err4;  s1 = strchr(s, ' ')+1;
         header.gen01args.gen01 = (MYFLT)strtod(s1, &endptr);
         if (UNLIKELY(endptr==NULL)) goto err4;
-        fgets(s, 64, file);  s1 = strchr(s, ' ')+1;
+        if (UNLIKELY(NULL==fgets(s, 64, file))) goto err4;  s1 = strchr(s, ' ')+1;
         header.gen01args.ifilno = (MYFLT)strtod(s1, &endptr);
         if (UNLIKELY(endptr==NULL)) goto err4;
-        fgets(s, 64, file);  s1 = strchr(s, ' ')+1;
+        if (UNLIKELY(NULL==fgets(s, 64, file))) goto err4;  s1 = strchr(s, ' ')+1;
         header.gen01args.iskptim = (MYFLT)strtod(s1, &endptr);
         if (UNLIKELY(endptr==NULL)) goto err4;
-        fgets(s, 64, file);  s1 = strchr(s, ' ')+1;
+        if (UNLIKELY(NULL==fgets(s, 64, file))) goto err4;  s1 = strchr(s, ' ')+1;
         header.gen01args.iformat = (MYFLT)strtod(s1, &endptr);
         if (UNLIKELY(endptr==NULL)) goto err4;
-        fgets(s, 64, file);  s1 = strchr(s, ' ')+1;
+        if (UNLIKELY(NULL==fgets(s, 64, file))) goto err4;  s1 = strchr(s, ' ')+1;
         header.gen01args.channel = (MYFLT)strtod(s1, &endptr);
         if (UNLIKELY(endptr==NULL)) goto err4;
-        fgets(s, 64, file);  s1 = strchr(s, ' ')+1;
+        if (UNLIKELY(NULL==fgets(s, 64, file))) goto err4;  s1 = strchr(s, ' ')+1;
         header.gen01args.sample_rate = (MYFLT)strtod(s1, &endptr);
         if (UNLIKELY(endptr==NULL)) goto err4;
-        fgets(s, 64, file);
+        if (UNLIKELY(NULL==fgets(s, 64, file))) goto err4;  s1 = strchr(s, ' ')+1;
         /* WARNING! skips header.gen01args.strarg from saving/loading
            in text format */
         header.fno = (int32) fno;
@@ -332,11 +333,11 @@ static int ftload(CSOUND *csound, FTLOAD *p)
         memcpy(ftp, &header, sizeof(FUNC) - sizeof(MYFLT));
         memset(&(ftp->ftable[0]), 0, sizeof(MYFLT) * (ftp->flen + 1));
         for (j = 0; j <= ftp->flen; j++) {
-          fgets(s, 64, file);
+          if (UNLIKELY(NULL==fgets(s, 64, file))) goto err4;
           ftp->ftable[j] = (MYFLT) strtod(s, &endptr);
           if (UNLIKELY(endptr==NULL)) goto err4;
         }
-        fgets(s, 64, file);
+        if (UNLIKELY(NULL==fgets(s, 64, file))) goto err4;
         argp++;
       }
     }
