@@ -78,10 +78,10 @@
 static Image * __doOpenImage(char * filename, CSOUND *csound)
 {
 #ifdef USE_LIBPNG
+#define HS (8)
     FILE *fp;
     void *fd;
-    const int hs = 8;
-    unsigned char header[8];
+    unsigned char header[HS];
     png_structp png_ptr;
     png_infop info_ptr;
     /* png_infop end_ptr; */
@@ -103,8 +103,11 @@ static Image * __doOpenImage(char * filename, CSOUND *csound)
       return NULL;
     }
 
-    fread(header, 1, hs, fp);
-    is_png = !png_sig_cmp(header, 0, hs);
+    if (UNLIKELY(HS!=fread(header, 1, HS, fp)))
+      csound->InitError(csound,
+                        Str("imageload: file %s is not in PNG format.\n"),
+                        filename);
+    is_png = !png_sig_cmp(header, 0, HS);
 
     if (UNLIKELY(!is_png)) {
       csound->InitError(csound,
@@ -137,7 +140,7 @@ static Image * __doOpenImage(char * filename, CSOUND *csound)
     /* } */
 
     png_init_io(png_ptr, fp);
-    png_set_sig_bytes(png_ptr, hs);
+    png_set_sig_bytes(png_ptr, HS);
 
     png_read_info(png_ptr, info_ptr);
     {
@@ -487,7 +490,7 @@ static int imagegetpixel_a (CSOUND *csound, IMGGETPIXEL * p)
     MYFLT *tx = p->kx;
     MYFLT *ty = p->ky;
 
-    int i, n=csound->ksmps;
+    int i, n=CS_KSMPS;
     int w, h, x, y, pixel;
 
     pimages = (Images *) csound->QueryGlobalVariable(csound,
@@ -529,7 +532,7 @@ static int imagesetpixel_a (CSOUND *csound, IMGSETPIXEL * p)
     MYFLT *tx = p->kx;
     MYFLT *ty = p->ky;
 
-    int i, n=csound->ksmps;
+    int i, n=CS_KSMPS;
     int h,w,x, y, pixel;
 
     pimages = (Images *) csound->QueryGlobalVariable(csound,
