@@ -521,7 +521,7 @@ struct JackoState
       result = pthread_mutex_init(&conditionMutex, 0);
       result = pthread_cond_init(&csoundCondition, 0);
       result = pthread_cond_init(&closeCondition, 0);
-      // Create a thread to run the close routine. It will immediately 
+      // Create a thread to run the close routine. It will immediately
       // block until it is signaled.
       result = pthread_create(&closeThread, 0, &JackoState::closeRoutine_, this);
       std::memset(&jack_position, 0, sizeof(jack_position_t));
@@ -703,8 +703,8 @@ struct JackoState
         // thread. Doing this inside the Jack process callback
         // takes too long and may cause other problems.
         result = pthread_mutex_lock(&conditionMutex);
-        result = pthread_cond_signal(&closeCondition);
-        result = pthread_mutex_unlock(&conditionMutex);
+        result |= pthread_cond_signal(&closeCondition);
+        result |= pthread_mutex_unlock(&conditionMutex);
         return result;
       }
   }
@@ -713,15 +713,17 @@ struct JackoState
       int result = 0;
       // Wait until signaled to actually shut down the Jack client.
       result = pthread_mutex_lock(&conditionMutex);
-      result = pthread_cond_wait(&closeCondition, &conditionMutex);
-      result = pthread_mutex_unlock(&conditionMutex);
+      result |= pthread_cond_wait(&closeCondition, &conditionMutex);
+      result |= pthread_mutex_unlock(&conditionMutex);
       close();
-      return (void *) result;
+      void *result_ = 0;
+      memcpy(&result_, &result, std::min(sizeof(result), sizeof(result_)));
+      return result_;
   }
   static void *closeRoutine_(void *userdata)
   {
       return ((JackoState *)userdata)->closeRoutine();
-  }
+  }\
   void startTransport()
   {
       midiInputQueue.clear();
@@ -1623,7 +1625,8 @@ extern "C"
     int result = OK;
 #pragma omp critical
     {
-      std::map<CSOUND *, JackoState *>::iterator it = jackoStatesForCsoundInstances.find(csound);
+      std::map<CSOUND *, JackoState *>::iterator it =
+        jackoStatesForCsoundInstances.find(csound);
       if (it != jackoStatesForCsoundInstances.end()) {
         //delete it->second;
         jackoStatesForCsoundInstances.erase(it);
