@@ -275,7 +275,7 @@ static void oscbnk_lfo(OSCBNK *p, OSCBNK_OSC *o)
 
 static int oscbnkset(CSOUND *csound, OSCBNK *p)
 {
-    int32    i;
+    uint32_t    i;
     FUNC    *ftp;
     MYFLT   x;
 
@@ -314,7 +314,8 @@ static int oscbnkset(CSOUND *csound, OSCBNK *p)
 
     if (p->ilfomode & 0x0F) {
       ftp = csound->FTFind(csound, p->args[21]);    /* LFO 2 */
-      if (UNLIKELY((ftp == NULL) || ((p->l2t = ftp->ftable) == NULL))) return NOTOK;
+      if (UNLIKELY((ftp == NULL) || ((p->l2t = ftp->ftable) == NULL)))
+        return NOTOK;
       oscbnk_flen_setup(ftp->flen, &(p->l2t_mask), &(p->l2t_lobits),
                          &(p->l2t_pfrac));
     }
@@ -325,15 +326,18 @@ static int oscbnkset(CSOUND *csound, OSCBNK *p)
 
     if (p->ieqmode >= 0) {
       ftp = csound->FTFind(csound, p->args[22]);    /* EQ frequency */
-      if (UNLIKELY((ftp == NULL) || ((p->eqft = ftp->ftable) == NULL))) return NOTOK;
+      if (UNLIKELY((ftp == NULL) || ((p->eqft = ftp->ftable) == NULL)))
+        return NOTOK;
       p->eqft_len = ftp->flen;
 
       ftp = csound->FTFind(csound, p->args[23]);    /* EQ level */
-      if (UNLIKELY((ftp == NULL) || ((p->eqlt = ftp->ftable) == NULL))) return NOTOK;
+      if (UNLIKELY((ftp == NULL) || ((p->eqlt = ftp->ftable) == NULL)))
+        return NOTOK;
       p->eqlt_len = ftp->flen;
 
       ftp = csound->FTFind(csound, p->args[24]);    /* EQ Q */
-      if (UNLIKELY((ftp == NULL) || ((p->eqqt = ftp->ftable) == NULL))) return NOTOK;
+      if (UNLIKELY((ftp == NULL) || ((p->eqqt = ftp->ftable) == NULL)))
+        return NOTOK;
       p->eqqt_len = ftp->flen;
     }
     else {
@@ -343,7 +347,8 @@ static int oscbnkset(CSOUND *csound, OSCBNK *p)
 
     if (*(p->args[25]) >= FL(1.0)) {        /* parameter table */
       ftp = csound->FTFind(csound, p->args[25]);
-      if (UNLIKELY((ftp == NULL) || ((p->tabl = ftp->ftable) == NULL))) return NOTOK;
+      if (UNLIKELY((ftp == NULL) || ((p->tabl = ftp->ftable) == NULL)))
+        return NOTOK;
       p->tabl_len = ftp->flen;
     }
     else {
@@ -353,7 +358,8 @@ static int oscbnkset(CSOUND *csound, OSCBNK *p)
 
     if (*(p->args[26]) >= FL(1.0)) {        /* output table */
       ftp = csound->FTFind(csound, p->args[26]);
-      if (UNLIKELY((ftp == NULL) || ((p->outft = ftp->ftable) == NULL))) return NOTOK;
+      if (UNLIKELY((ftp == NULL) || ((p->outft = ftp->ftable) == NULL)))
+        return NOTOK;
       p->outft_len = ftp->flen;
     }
     else {
@@ -661,7 +667,7 @@ static int grain2(CSOUND *csound, GRAIN2 *p)
     o        = p->osc;                  /* oscillator array             */
     w_interp = (p->mode & 8 ? 1 : 0);   /* interpolate window   */
     g_interp = (p->mode & 4 ? 0 : 1);   /* interpolate grain    */
-    f_nolock = (p->mode & 2 ? 1 : 0);   /* don't lock grain frq */
+    f_nolock = (p->mode & 2 ? 1 : 0);   /* do not lock grain frq */
     w_ft     = p->wft;                  /* window ftable                */
     w_mask   = p->wft_mask; w_lobits = p->wft_lobits; w_pfrac = p->wft_pfrac;
 
@@ -832,7 +838,7 @@ static int grain3(CSOUND *csound, GRAIN3 *p)
     aout0 = p->ar;                              /* audio output         */
     w_interp = (p->mode & 8 ? 1 : 0);   /* interpolate window   */
     g_interp = (p->mode & 4 ? 0 : 1);   /* interpolate grain    */
-    f_nolock = (p->mode & 2 ? 1 : 0);   /* don't lock grain frq */
+    f_nolock = (p->mode & 2 ? 1 : 0);   /* do not lock grain frq */
     w_ft = p->wft;                              /* window ftable        */
     w_mask = p->wft_mask; w_lobits = p->wft_lobits; w_pfrac = p->wft_pfrac;
     phs = p->phase;                             /* grain phase offset   */
@@ -1120,7 +1126,7 @@ static int kosclikt(CSOUND *csound, OSCKT *p)
 {
     FUNC    *ftp;
     uint32   n, phs;
-    MYFLT   v, *ft;
+    MYFLT   v;
 
     /* check if table number was changed */
     if (*(p->kfn) != p->oldfn || p->ft == NULL) {
@@ -1131,7 +1137,7 @@ static int kosclikt(CSOUND *csound, OSCKT *p)
     }
 
     /* copy object data to local variables */
-    ft = p->ft; phs = p->phs;
+    phs = p->phs;
     /* read from table with interpolation */
     n = phs >> p->lobits; v = (MYFLT) ((int32) (phs & p->mask)) * p->pfrac;
     *(p->sr) = (p->ft[n] + (p->ft[n + 1] - p->ft[n]) * v) * *(p->xamp);
@@ -2466,13 +2472,13 @@ static const OENTRY localops[] = {
             (SUBR) rnd31set, (SUBR) NULL, (SUBR) rnd31a                 },
     { "oscilikt",   0xFFFE,             TR,      NULL,   NULL,
             (SUBR) NULL, (SUBR) NULL, (SUBR) NULL                       },
-    { "oscilikt.kk", sizeof(OSCKT),     7,      "s",    "kkkoo",
+    { "oscilikt.kk", sizeof(OSCKT),     TR|7,      "s",    "kkkoo",
             (SUBR) oscktset, (SUBR) kosclikt, (SUBR)osckkikt            },
-    { "oscilikt.ka", sizeof(OSCKT),     5,      "a",    "kakoo",
+    { "oscilikt.ka", sizeof(OSCKT),     TR|5,      "a",    "kakoo",
             (SUBR) oscktset, (SUBR) NULL, (SUBR) osckaikt               },
-    { "oscilikt.ak", sizeof(OSCKT),     5,      "a",    "akkoo",
+    { "oscilikt.ak", sizeof(OSCKT),     TR|5,      "a",    "akkoo",
             (SUBR) oscktset, (SUBR) NULL, (SUBR) oscakikt               },
-    { "oscilikt.aa", sizeof(OSCKT),     5,      "a",    "aakoo",
+    { "oscilikt.aa", sizeof(OSCKT),     TR|5,      "a",    "aakoo",
             (SUBR) oscktset, (SUBR) NULL, (SUBR) oscaaikt               },
     { "osciliktp",  sizeof(OSCKTP),     TR|5,      "a",    "kkko",
             (SUBR) oscktpset, (SUBR) NULL, (SUBR) oscktp                },
