@@ -47,8 +47,8 @@ static int pvsgainset(CSOUND *csound, PVSGAIN *p){
     p->fout->sliding = 0;
     if (p->fa->sliding) {
       if (p->fout->frame.auxp == NULL ||
-          p->fout->frame.size < sizeof(MYFLT) * csound->ksmps * (N + 2))
-        csound->AuxAlloc(csound, (N + 2) * sizeof(MYFLT) * csound->ksmps,
+          p->fout->frame.size < sizeof(MYFLT) * CS_KSMPS * (N + 2))
+        csound->AuxAlloc(csound, (N + 2) * sizeof(MYFLT) * CS_KSMPS,
                          &p->fout->frame);
       p->fout->NB = p->fa->NB;
       p->fout->sliding = 1;
@@ -80,7 +80,7 @@ static int pvsgain(CSOUND *csound, PVSGAIN *p)
 
     if (p->fa->sliding) {
       CMPLX * fout, *fa;
-      int n, nsmps=csound->ksmps;
+      int n, nsmps=CS_KSMPS;
       int NB = p->fa->NB;
       for (n=0; n<nsmps; n++) {
         fout = (CMPLX*) p->fout->frame.auxp +NB*n;
@@ -105,7 +105,7 @@ static int pvsgain(CSOUND *csound, PVSGAIN *p)
         p->fout->framecount = p->fa->framecount;
         p->lastframe = p->fout->framecount;
     }
-    return OK;    
+    return OK;
 }
 
 
@@ -124,17 +124,17 @@ static int pvsinit(CSOUND *csound, PVSINI *p)
     p->fout->format = (int32) *p->format;
     p->fout->framecount = 1;
     p->fout->sliding = 0;
-    if (p->fout->overlap < csound->ksmps || p->fout->overlap <=10) {
+    if (p->fout->overlap < CS_KSMPS || p->fout->overlap <=10) {
       int NB = 1+N/2;
       MYFLT *bframe;
       p->fout->NB = NB;
       if (p->fout->frame.auxp == NULL ||
-          p->fout->frame.size * csound->ksmps < sizeof(float) * (N + 2))
-        csound->AuxAlloc(csound, (N + 2) * csound->ksmps * sizeof(float),
+          p->fout->frame.size * CS_KSMPS < sizeof(float) * (N + 2))
+        csound->AuxAlloc(csound, (N + 2) * CS_KSMPS * sizeof(float),
                          &p->fout->frame);
       p->fout->sliding = 1;
       bframe = (MYFLT *) p->fout->frame.auxp;
-      for (n=0; n<csound->ksmps; n++)
+      for (n=0; n<CS_KSMPS; n++)
         for (i = 0; i < N + 2; i += 2) {
           bframe[i+n*NB] = FL(0.0);
           bframe[i+n*NB + 1] = (i >>1) * N * csound->onedsr;
@@ -148,7 +148,7 @@ static int pvsinit(CSOUND *csound, PVSINI *p)
         }
         bframe = (float *) p->fout->frame.auxp;
         for (i = 0; i < N + 2; i += 2) {
-          bframe[i] = 0.0f;
+          //bframe[i] = 0.0f;
           bframe[i + 1] = (i >>1) * N * csound->onedsr;
         }
       }
@@ -299,7 +299,7 @@ static int pvsdiskinset(CSOUND *csound, pvsdiskin *p)
 
 static int pvsdiskinproc(CSOUND *csound, pvsdiskin *p)
 {
-    int overlap = p->fout->overlap, frames, i, posi;
+    int overlap = p->fout->overlap, i, posi;
     double pos = p->pos;
     int32 N = p->fout->N;
     MYFLT frac;
@@ -321,7 +321,7 @@ static int pvsdiskinproc(CSOUND *csound, pvsdiskin *p)
         while(pos >= p->flen) pos -= p->flen;
         while(pos < 0) pos += p->flen;
         csound->PVOC_fseek(csound,p->pvfile, pos);
-        frames = csound->PVOC_GetFrames(csound, p->pvfile, buffer, 2*p->chans);
+        (void)csound->PVOC_GetFrames(csound, p->pvfile, buffer, 2*p->chans);
         p->oldpos = posi = (int)pos;
 
       }
@@ -332,7 +332,7 @@ static int pvsdiskinproc(CSOUND *csound, pvsdiskin *p)
           fout[i] = amp*(frame1[i] + frac*(frame2[i] - frame1[i]));
           fout[i+1] =  frame1[i+1] + frac*(frame2[i+1] - frame1[i+1]);
         }
-      } else  /* don't */
+      } else  /* do not */
         for (i=0; i < N+2; i+=2) {
           fout[i] = amp*(frame1[i]);
           fout[i+1] =  frame1[i+1];
@@ -343,7 +343,7 @@ static int pvsdiskinproc(CSOUND *csound, pvsdiskin *p)
       p->scnt -= overlap;
       p->fout->framecount++;
     }
-    p->scnt += csound->ksmps;
+    p->scnt += CS_KSMPS;
 
     return OK;
 }
@@ -388,26 +388,29 @@ int pvstanalset(CSOUND *csound, PVST *p)
       if (p->fout[i]->frame.auxp == NULL ||
           p->fout[i]->frame.size < sizeof(float) * (N + 2))
         csound->AuxAlloc(csound, (N + 2) * sizeof(float), &p->fout[i]->frame);
+      else
+        memset(p->fout[i]->frame.auxp, 0, sizeof(float)*(N+2));
       if (p->bwin[i].auxp == NULL ||
           p->bwin[i].size < sizeof(MYFLT) * (N + 2))
         csound->AuxAlloc(csound, (N + 2) * sizeof(MYFLT), &p->bwin[i]);
+      else
+        memset(p->bwin[i].auxp, 0, p->bwin[i].size);
       if (p->fwin[i].auxp == NULL ||
           p->fwin[i].size < sizeof(MYFLT) * (N + 2))
         csound->AuxAlloc(csound, (N + 2) * sizeof(MYFLT), &p->fwin[i]);
+      else
+        memset(p->fwin[i].auxp, 0, sizeof(MYFLT)*(N+2));
       if (p->nwin[i].auxp == NULL ||
           p->nwin[i].size < sizeof(MYFLT) * (N + 2))
         csound->AuxAlloc(csound, (N + 2) * sizeof(MYFLT), &p->nwin[i]);
-      memset(p->fwin[i].auxp, 0, sizeof(MYFLT)*(N+2));
-      memset(p->bwin[i].auxp, 0, sizeof(MYFLT)*(N+2));
-      memset(p->nwin[i].auxp, 0, sizeof(MYFLT)*(N+2));
-      memset(p->fout[i]->frame.auxp, 0, sizeof(float)*(N+2));
-
+      else
+        memset(p->nwin[i].auxp, 0, sizeof(MYFLT)*(N+2));
     }
 
     if (p->win.auxp == NULL ||
         p->win.size < sizeof(MYFLT) * (N))
       csound->AuxAlloc(csound, (N) * sizeof(MYFLT), &p->win);
-    p->scale = 0.f;
+    p->scale = 0.0f;
     for (i=0; i < N; i++)
       p->scale += (((MYFLT *)p->win.auxp)[i] = 0.5 - 0.5*cos(i*2*PI/N));
     for (i=0; i < N; i++)
@@ -444,7 +447,8 @@ int pvstanal(CSOUND *csound, PVST *p)
       /* audio samples are stored in a function table */
       ft = csound->FTnp2Find(csound,p->knum);
       if (ft == NULL){
-        csound->PerfError(csound, "could not find table number %d\n", (int) *p->knum);
+        csound->PerfError(csound,
+                          "could not find table number %d\n", (int) *p->knum);
         return NOTOK;
 
       }
@@ -491,21 +495,21 @@ int pvstanal(CSOUND *csound, PVST *p)
           frac = pos  - post;
           post *= nchans;
           post += j;
-          if (post < 0 || post >= size ) in = 0.0;
+          if (post >= size ) in = 0.0;
           else in = tab[post] + frac*(tab[post+nchans] - tab[post]);
           fwin[i] = amp * in * win[i]; /* window it */
           /* back windo, bwin */
           post = (int) (pos - hsize*pitch);
           post *= nchans;
           post += j;
-          if (post < 0 ||post >= size ) in = 0.0;
+          if (post >= size ) in = 0.0;
           else in =  tab[post] + frac*(tab[post+nchans] - tab[post]);
           bwin[i] = in * win[i];  /* window it */
           if (*p->konset){
           post = (int) pos + hsize;
           post *= nchans;
           post += j;
-          if (post < 0 || post >= size ) in = 0.0;
+          if (post >= size ) in = 0.0;
           else in =  tab[post];
           nwin[i] = amp * in * win[i];
           }
@@ -562,7 +566,7 @@ int pvstanal(CSOUND *csound, PVST *p)
       p->scnt -= hsize;
       p->pos = spos;
     }
-    p->scnt += csound->ksmps;
+    p->scnt += CS_KSMPS;
     return OK;
 
 }
@@ -584,7 +588,7 @@ static int pvsfreezeset(CSOUND *csound, PVSFREEZE *p)
     p->fout->NB = (N/2)+1;
     p->fout->sliding = p->fin->sliding;
     if (p->fin->sliding) {
-      int nsmps = csound->ksmps;
+      int nsmps = CS_KSMPS;
       if (p->fout->frame.auxp == NULL ||
           p->fout->frame.size < sizeof(MYFLT) * (N + 2) * nsmps)
         csound->AuxAlloc(csound, (N + 2) * sizeof(MYFLT) * nsmps,
@@ -611,7 +615,7 @@ static int pvsfreezeset(CSOUND *csound, PVSFREEZE *p)
 
 static int pvssfreezeprocess(CSOUND *csound, PVSFREEZE *p)
 {
-    int i, n, k, nsmps = csound->ksmps;
+    int i, n, k, nsmps = CS_KSMPS;
     int NB = p->fin->NB;
     MYFLT freeza = *p->kfra, freezf = *p->kfrf;
 
@@ -673,20 +677,20 @@ static int pvsoscset(CSOUND *csound, PVSOSC *p)
     p->fout->format = (int32) *p->format;
     p->fout->framecount = 0;
     p->fout->sliding = 0;
-    if (p->fout->overlap<csound->ksmps || p->fout->overlap<=10) {
+    if (p->fout->overlap<CS_KSMPS || p->fout->overlap<=10) {
       CMPLX *bframe;
       int NB = 1+N/2, n;
       return csound->InitError(csound, Str("pvsosc does not work while sliding"));
       p->fout->NB = NB;
       p->fout->sliding = 1;
       if (p->fout->frame.auxp == NULL ||
-          p->fout->frame.size < csound->ksmps*sizeof(MYFLT) * (N + 2))
+          p->fout->frame.size < CS_KSMPS*sizeof(MYFLT) * (N + 2))
         csound->AuxAlloc(csound,
-                         (N + 2) * csound->ksmps* sizeof(MYFLT), &p->fout->frame);
+                         (N + 2) * CS_KSMPS* sizeof(MYFLT), &p->fout->frame);
       else memset(p->fout->frame.auxp,
-                  '\0', (N + 2) * csound->ksmps* sizeof(MYFLT));
+                  '\0', (N + 2) * CS_KSMPS* sizeof(MYFLT));
       bframe = (CMPLX *)p->fout->frame.auxp;
-      for (n=0; n<csound->ksmps; n++)
+      for (n=0; n<CS_KSMPS; n++)
         for (i = 0; i < NB; i++) {
           bframe[i+NB*n].re = FL(0.0);
           bframe[i+NB*n].im = i * N * csound->onedsr;
@@ -701,11 +705,11 @@ static int pvsoscset(CSOUND *csound, PVSOSC *p)
           csound->AuxAlloc(csound, (N + 2) * sizeof(float), &p->fout->frame);
         bframe = (float *) p->fout->frame.auxp;
         for (i = 0; i < N + 2; i += 2) {
-          bframe[i] = 0.0f;
+          //bframe[i] = 0.0f;
           bframe[i + 1] = (i / 2) * N * csound->onedsr;
         }
         p->lastframe = 1;
-        p->incr = (MYFLT)csound->ksmps/p->fout->overlap;
+        p->incr = (MYFLT)CS_KSMPS/p->fout->overlap;
       }
     return OK;
 }
@@ -729,7 +733,7 @@ static int pvsoscprocess(CSOUND *csound, PVSOSC *p)
 
     if (p->fout->sliding) {
       CMPLX *fout;
-      int m, nsmps = csound->ksmps;
+      int m, nsmps = CS_KSMPS;
       int NB = p->fout->NB;
       harm = (int)(csound->esr/(2*ffun));
       if (type==1) famp *= FL(1.456)/POWER((MYFLT)harm, FL(1.0)/FL(2.4));
@@ -798,7 +802,7 @@ static int pvsoscprocess(CSOUND *csound, PVSOSC *p)
     }
     p->incr += p->incr;
     if (p->incr > 1) {
-      p->incr = (MYFLT)csound->ksmps/p->fout->overlap;
+      p->incr = (MYFLT)CS_KSMPS/p->fout->overlap;
       p->lastframe++;
     }
     return OK;
@@ -848,7 +852,7 @@ static int pvsbinprocessa(CSOUND *csound, PVSBIN *p)
       int NB = p->fin->NB;
       pos = *p->kbin;
       if (pos >= 0 && pos < NB) {
-        for (k=0; k<csound->ksmps; k++) {
+        for (k=0; k<CS_KSMPS; k++) {
           p->kamp[k] = (MYFLT)fin[pos+NB*k].re;
           p->kfreq[k] = (MYFLT)fin[pos+NB*k].im;
         }
@@ -861,7 +865,7 @@ static int pvsbinprocessa(CSOUND *csound, PVSBIN *p)
         framesize = p->fin->N + 2;
         pos=*p->kbin*2;
         if (pos >= 0 && pos < framesize) {
-          for (k=0; k<csound->ksmps; k++) {
+          for (k=0; k<CS_KSMPS; k++) {
             p->kamp[k] = (MYFLT)fin[pos];
             p->kfreq[k] = (MYFLT)fin[pos+1];
           }
@@ -882,12 +886,12 @@ static int pvsmoothset(CSOUND *csound, PVSMOOTH *p)
     p->fout->sliding = p->fin->sliding;
     if (p->fin->sliding) {
       if (p->fout->frame.auxp == NULL ||
-          p->fout->frame.size < sizeof(MYFLT) * csound->ksmps * (N + 2))
-        csound->AuxAlloc(csound, (N + 2) * sizeof(MYFLT) * csound->ksmps,
+          p->fout->frame.size < sizeof(MYFLT) * CS_KSMPS * (N + 2))
+        csound->AuxAlloc(csound, (N + 2) * sizeof(MYFLT) * CS_KSMPS,
                          &p->fout->frame);
       if (p->del.auxp == NULL ||
-          p->del.size < sizeof(MYFLT) * csound->ksmps * (N + 2))
-        csound->AuxAlloc(csound, (N + 2) * sizeof(MYFLT) * csound->ksmps,
+          p->del.size < sizeof(MYFLT) * CS_KSMPS * (N + 2))
+        csound->AuxAlloc(csound, (N + 2) * sizeof(MYFLT) * CS_KSMPS,
                          &p->del);
     }
     else
@@ -927,7 +931,7 @@ static int pvsmoothprocess(CSOUND *csound, PVSMOOTH *p)
     if (p->fin->sliding) {
       CMPLX *fout, *fin, *del;
       double  costh1, costh2, coef1, coef2;
-      int n, nsmps=csound->ksmps;
+      int n, nsmps=CS_KSMPS;
       int NB = p->fin->NB;
       ffa = ffa < 0.0 ? 0.0 : (ffa > 1.0 ? 1.0 : ffa);
       ffr = ffr < 0.0 ? 0.0 : (ffr > 1.0 ? 1.0 : ffr);
@@ -998,8 +1002,8 @@ static int pvsmixset(CSOUND *csound, PVSMIX *p)
     p->fout->sliding = 0;
     if (p->fa->sliding) {
       if (p->fout->frame.auxp == NULL ||
-          p->fout->frame.size < sizeof(MYFLT) * csound->ksmps * (N + 2))
-        csound->AuxAlloc(csound, (N + 2) * sizeof(MYFLT) * csound->ksmps,
+          p->fout->frame.size < sizeof(MYFLT) * CS_KSMPS * (N + 2))
+        csound->AuxAlloc(csound, (N + 2) * sizeof(MYFLT) * CS_KSMPS,
                          &p->fout->frame);
       p->fout->NB = p->fa->NB;
       p->fout->sliding = 1;
@@ -1032,7 +1036,7 @@ static int pvsmix(CSOUND *csound, PVSMIX *p)
     if (UNLIKELY(!fsigs_equal(p->fa, p->fb))) goto err1;
     if (p->fa->sliding) {
       CMPLX * fout, *fa, *fb;
-      int n, nsmps=csound->ksmps;
+      int n, nsmps=CS_KSMPS;
       int NB = p->fa->NB;
       for (n=0; n<nsmps; n++) {
         fout = (CMPLX*) p->fout->frame.auxp +NB*n;
@@ -1085,8 +1089,8 @@ static int pvsfilterset(CSOUND *csound, PVSFILTER *p)
     p->fout->sliding = 0;
     if (p->fin->sliding) {
       if (p->fout->frame.auxp == NULL ||
-          p->fout->frame.size < sizeof(MYFLT) * csound->ksmps * (N + 2))
-        csound->AuxAlloc(csound, sizeof(MYFLT) * csound->ksmps * (N + 2),
+          p->fout->frame.size < sizeof(MYFLT) * CS_KSMPS * (N + 2))
+        csound->AuxAlloc(csound, sizeof(MYFLT) * CS_KSMPS * (N + 2),
                          &p->fout->frame);
       p->fout->NB = p->fin->NB;
       p->fout->sliding = 1;
@@ -1120,7 +1124,7 @@ static int pvsfilter(CSOUND *csound, PVSFILTER *p)
 
     if (p->fin->sliding) {
       int NB = p->fout->NB;
-      int n, nsmps = csound->ksmps;
+      int n, nsmps = CS_KSMPS;
       CMPLX *fin, *fout, *fil;
       MYFLT g = *p->gain;
       kdepth = kdepth >= FL(0.0) ? (kdepth <= FL(1.0) ? kdepth*g : g) : FL(0.0);
@@ -1182,8 +1186,8 @@ static int pvsscaleset(CSOUND *csound, PVSSCALE *p)
     p->fout->sliding = p->fin->sliding;
     if (p->fin->sliding) {
       if (p->fout->frame.auxp == NULL ||
-          p->fout->frame.size < csound->ksmps * sizeof(MYFLT) * (N + 2))
-        csound->AuxAlloc(csound, csound->ksmps * sizeof(MYFLT) * (N + 2),
+          p->fout->frame.size < CS_KSMPS * sizeof(MYFLT) * (N + 2))
+        csound->AuxAlloc(csound, CS_KSMPS * sizeof(MYFLT) * (N + 2),
                          &p->fout->frame);
     }
     else
@@ -1231,7 +1235,7 @@ static int pvsscale(CSOUND *csound, PVSSCALE *p)
     if (UNLIKELY(fout == NULL)) goto err1;
 
     if (p->fout->sliding) {
-      int n, nsmps = csound->ksmps;
+      int n, nsmps = CS_KSMPS;
       int NB    = p->fout->NB;
       MYFLT   g = *p->gain;
       for (n=0; n<nsmps; n++) {
@@ -1395,9 +1399,9 @@ static int pvsshiftset(CSOUND *csound, PVSSHIFT *p)
       csound->Warning(csound, Str("Unsafe to have same fsig as in and out"));
     if (p->fin->sliding) {
       if (p->fout->frame.auxp==NULL ||
-          csound->ksmps*(N+2)*sizeof(MYFLT) > (unsigned int)p->fout->frame.size)
-        csound->AuxAlloc(csound, csound->ksmps*(N+2)*sizeof(MYFLT),&p->fout->frame);
-      else memset(p->fout->frame.auxp, 0, csound->ksmps*(N+2)*sizeof(MYFLT));
+          CS_KSMPS*(N+2)*sizeof(MYFLT) > (unsigned int)p->fout->frame.size)
+        csound->AuxAlloc(csound, CS_KSMPS*(N+2)*sizeof(MYFLT),&p->fout->frame);
+      else memset(p->fout->frame.auxp, 0, CS_KSMPS*(N+2)*sizeof(MYFLT));
     }
     else
       {
@@ -1419,11 +1423,13 @@ static int pvsshiftset(CSOUND *csound, PVSSHIFT *p)
     if (p->ceps.auxp == NULL ||
         p->ceps.size < sizeof(MYFLT) * (N+2))
       csound->AuxAlloc(csound, sizeof(MYFLT) * (N + 2), &p->ceps);
-    memset(p->ceps.auxp, 0, sizeof(MYFLT)*(N+2));
+    else
+      memset(p->ceps.auxp, 0, sizeof(MYFLT)*(N+2));
     if (p->fenv.auxp == NULL ||
         p->fenv.size < sizeof(MYFLT) * (N+2))
       csound->AuxAlloc(csound, sizeof(MYFLT) * (N + 2), &p->fenv);
-    memset(p->fenv.auxp, 0, sizeof(MYFLT)*(N+2));
+    else
+      memset(p->fenv.auxp, 0, sizeof(MYFLT)*(N+2));
 
     return OK;
 }
@@ -1446,7 +1452,7 @@ static int pvsshift(CSOUND *csound, PVSSHIFT *p)
 
     if (UNLIKELY(fout == NULL)) goto err1;
     if (p->fin->sliding) {
-      int n, nsmps = csound->ksmps;
+      int n, nsmps = CS_KSMPS;
       int NB  = p->fout->NB;
       MYFLT g = *p->gain;
       lowest = lowest ? (lowest > NB ? NB : lowest) : 1;
@@ -1607,11 +1613,13 @@ static int pvswarpset(CSOUND *csound, PVSWARP *p)
     if (p->ceps.auxp == NULL ||
         p->ceps.size < sizeof(MYFLT) * (N+2))
       csound->AuxAlloc(csound, sizeof(MYFLT) * (N + 2), &p->ceps);
-    memset(p->ceps.auxp, 0, sizeof(MYFLT)*(N+2));
+    else
+      memset(p->ceps.auxp, 0, sizeof(MYFLT)*(N+2));
     if (p->fenv.auxp == NULL ||
         p->fenv.size < sizeof(MYFLT) * (N+2))
       csound->AuxAlloc(csound, sizeof(MYFLT) * (N + 2), &p->fenv);
-    memset(p->fenv.auxp, 0, sizeof(MYFLT)*(N+2));
+    else
+      memset(p->fenv.auxp, 0, sizeof(MYFLT)*(N+2));
 
     return OK;
 }
@@ -1758,14 +1766,14 @@ static int pvsblurset(CSOUND *csound, PVSBLUR *p)
       csound->InitError(csound, Str("pvsblur does not work sliding yet"));
       delayframes = (int) (FL(0.5) + *p->maxdel * csound->esr);
       if (p->fout->frame.auxp == NULL ||
-          p->fout->frame.size < sizeof(MYFLT) * csound->ksmps * (N + 2))
-        csound->AuxAlloc(csound, (N + 2) * sizeof(MYFLT) * csound->ksmps,
+          p->fout->frame.size < sizeof(MYFLT) * CS_KSMPS * (N + 2))
+        csound->AuxAlloc(csound, (N + 2) * sizeof(MYFLT) * CS_KSMPS,
                          &p->fout->frame);
 
       if (p->delframes.auxp == NULL ||
-          p->delframes.size <   (N + 2) * sizeof(MYFLT) * csound->ksmps * delayframes)
+          p->delframes.size < (N + 2) * sizeof(MYFLT) * CS_KSMPS * delayframes)
         csound->AuxAlloc(csound,
-                         (N + 2) * sizeof(MYFLT) * csound->ksmps * delayframes,
+                         (N + 2) * sizeof(MYFLT) * CS_KSMPS * delayframes,
                          &p->delframes);
     }
     else
@@ -1779,7 +1787,7 @@ static int pvsblurset(CSOUND *csound, PVSBLUR *p)
           csound->AuxAlloc(csound, (N + 2) * sizeof(float), &p->fout->frame);
 
         if (p->delframes.auxp == NULL ||
-          p->delframes.size <   (N + 2) * sizeof(float) * csound->ksmps * delayframes)
+          p->delframes.size < (N + 2) * sizeof(float) * CS_KSMPS * delayframes)
           csound->AuxAlloc(csound, (N + 2) * sizeof(float) * delayframes,
                            &p->delframes);
       }
@@ -1819,7 +1827,7 @@ static int pvsblur(CSOUND *csound, PVSBLUR *p)
     if (UNLIKELY(fout == NULL || delay == NULL)) goto err1;
 
     if (p->fin->sliding) {
-      int n, nsmps = csound->ksmps;
+      int n, nsmps = CS_KSMPS;
       int NB = p->fin->NB;
       kdel = kdel >= 0 ? (kdel < mdel ? kdel : mdel - framesize) : 0;
       for (n=0; n<nsmps; n++) {
@@ -1909,8 +1917,8 @@ static int pvstencilset(CSOUND *csound, PVSTENCIL *p)
     p->fout->NB = chans;
     if (p->fin->sliding) {
       if (p->fout->frame.auxp == NULL ||
-          p->fout->frame.size < sizeof(MYFLT) * (N + 2) * csound->ksmps)
-        csound->AuxAlloc(csound, (N + 2) * sizeof(MYFLT) * csound->ksmps,
+          p->fout->frame.size < sizeof(MYFLT) * (N + 2) * CS_KSMPS)
+        csound->AuxAlloc(csound, (N + 2) * sizeof(MYFLT) * CS_KSMPS,
                          &p->fout->frame);
       p->fout->sliding = 1;
     }
@@ -1925,7 +1933,7 @@ static int pvstencilset(CSOUND *csound, PVSTENCIL *p)
           return csound->InitError(csound, Str("pvstencil: signal format "
                                                "must be amp-phase or amp-freq."));
       }
-    p->func = csound->FTFind(csound, p->ifn);
+    p->func = csound->FTnp2Find(csound, p->ifn);
     if (p->func == NULL)
       return OK;
 
@@ -1953,7 +1961,7 @@ static int pvstencil(CSOUND *csound, PVSTENCIL *p)
       p->fout->format = p->fin->format;
       p->fout->wintype = p->fin->wintype;
       ftable = p->func->ftable;
-      for (n=0; n<csound->ksmps; n++) {
+      for (n=0; n<CS_KSMPS; n++) {
         CMPLX *fout = (CMPLX *) p->fout->frame.auxp + n*NB;
         CMPLX *fin  = (CMPLX *) p->fin->frame.auxp  + n*NB;
         for (i = 0; i < NB; i++) {
@@ -2037,11 +2045,13 @@ static int pvsenvwset(CSOUND *csound, PVSENVW *p)
     if (p->ceps.auxp == NULL ||
         p->ceps.size < sizeof(MYFLT) * (N+2))
       csound->AuxAlloc(csound, sizeof(MYFLT) * (N + 2), &p->ceps);
-    memset(p->ceps.auxp, 0, sizeof(MYFLT)*(N+2));
+    else
+      memset(p->ceps.auxp, 0, sizeof(MYFLT)*(N+2));
     if (p->fenv.auxp == NULL ||
         p->fenv.size < sizeof(MYFLT) * (N+2))
       csound->AuxAlloc(csound, sizeof(MYFLT) * (N + 2), &p->fenv);
-    memset(p->fenv.auxp, 0, sizeof(MYFLT)*(N+2));
+    else
+      memset(p->fenv.auxp, 0, sizeof(MYFLT)*(N+2));
 
     return OK;
 }
@@ -2057,14 +2067,14 @@ static int pvsenvw(CSOUND *csound, PVSENVW *p)
     MYFLT   *ceps = (MYFLT *) p->ceps.auxp;
     int coefs = (int) *p->coefs;
     FUNC  *ft = csound->FTnp2Find(csound, p->ftab);
-    int size = ft->flen;
-    MYFLT *ftab = ft->ftable;
+    int size;
+    MYFLT *ftab;
 
     if (ft == NULL) {
-      csound->PerfError(csound, "could not find table number %d\n", (int) *p->ftab);
+      csound->PerfError(csound,
+                        Str("could not find table number %d\n"), (int) *p->ftab);
       return NOTOK;
     }
-
     size = ft->flen;
     ftab = ft->ftable;
 
@@ -2135,7 +2145,7 @@ static int pvsenvw(CSOUND *csound, PVSENVW *p)
 
 }
 
-typedef struct pvs2tab_t { 
+typedef struct pvs2tab_t {
     OPDS h;
     MYFLT *framecount;
     TABDAT *ans;
@@ -2153,16 +2163,16 @@ int pvs2tab_init(CSOUND *csound, PVS2TAB_T *p)
 }
 
 int  pvs2tab(CSOUND *csound, PVS2TAB_T *p){
- 
+
   int size = p->ans->size, N = p->fsig->N, i;
   float *fsig = (float *) p->fsig->frame.auxp;
   for(i = 0; i < size && i < N+2; i++)
-      p->ans->data[i] = (MYFLT) fsig[i];   
+      p->ans->data[i] = (MYFLT) fsig[i];
   *p->framecount = (MYFLT) p->fsig->framecount;
-  return OK; 
+  return OK;
 }
 
-typedef struct tab2pvs_t { 
+typedef struct tab2pvs_t {
     OPDS h;
     PVSDAT *fout;
     TABDAT *in;
@@ -2185,8 +2195,8 @@ int tab2pvs_init(CSOUND *csound, TAB2PVS_T *p)
           p->fout->frame.size < sizeof(float) * (N + 2)) {
         csound->AuxAlloc(csound, (N + 2) * sizeof(float), &p->fout->frame);
       }
-
-      memset(p->fout->frame.auxp, 0, sizeof(float)*(N+2));
+      else
+        memset(p->fout->frame.auxp, 0, sizeof(float)*(N+2));
       return OK;
     }
     else return csound->InitError(csound, Str("t-variable not initialised"));
@@ -2196,11 +2206,11 @@ int  tab2pvs(CSOUND *csound, TAB2PVS_T *p)
 {
     int size = p->in->size, i;
     float *fout = (float *) p->fout->frame.auxp;
-  
+
     if (p->lastframe < p->fout->framecount){
       for (i = 0; i < size; i++){
-        fout[i] = (float) p->in->data[i]; 
-      } 
+        fout[i] = (float) p->in->data[i];
+      }
       p->lastframe = p->fout->framecount;
     }
     return OK;
@@ -2220,7 +2230,7 @@ static OENTRY localops[] = {
    (SUBR) pvsshift},
   {"pvsfilter", sizeof(PVSFILTER), 3, "f", "fffp", (SUBR) pvsfilterset,
    (SUBR) pvsfilter},
-  {"pvscale", sizeof(PVSSCALE), 3, "f", "fkOPO", 
+  {"pvscale", sizeof(PVSSCALE), 3, "f", "fkOPO",
               (SUBR) pvsscaleset, (SUBR) pvsscale},
   {"pvshift", sizeof(PVSSHIFT), 3, "f", "fkkOPO", (SUBR) pvsshiftset,
    (SUBR) pvsshift},
@@ -2244,11 +2254,16 @@ static OENTRY localops[] = {
    (SUBR) pvsdiskinproc, NULL},
   {"pvstanal", sizeof(PVST), 3, "FFFFFFFFFFFFFFFF", "kkkkPPoooP",(SUBR) pvstanalset,
    (SUBR) pvstanal, NULL},
-  {"pvswarp", sizeof(PVSWARP), 3, "f", "fkkOPPO", (SUBR) pvswarpset, (SUBR) pvswarp},
-  {"pvsenvftw", sizeof(PVSENVW), 3, "k", "fkPPO", (SUBR) pvsenvwset, (SUBR) pvsenvw},
-  {"pvsgain", sizeof(PVSGAIN), 3, "f", "fk", (SUBR) pvsgainset, (SUBR) pvsgain, NULL},
-  {"pvs2tab", sizeof(PVS2TAB_T), 3, "k", "tf", (SUBR) pvs2tab_init, (SUBR) pvs2tab, NULL},
-  {"tab2pvs", sizeof(TAB2PVS_T), 3, "f", "toop", (SUBR) tab2pvs_init, (SUBR) tab2pvs, NULL}
+  {"pvswarp", sizeof(PVSWARP), 3, "f", "fkkOPPO",
+                               (SUBR) pvswarpset, (SUBR) pvswarp},
+  {"pvsenvftw", sizeof(PVSENVW), 3, "k", "fkPPO",
+                               (SUBR) pvsenvwset, (SUBR) pvsenvw},
+  {"pvsgain", sizeof(PVSGAIN), 3, "f", "fk",
+                               (SUBR) pvsgainset, (SUBR) pvsgain, NULL},
+  {"pvs2tab", sizeof(PVS2TAB_T), 3, "k", "tf",
+                               (SUBR) pvs2tab_init, (SUBR) pvs2tab, NULL},
+  {"tab2pvs", sizeof(TAB2PVS_T), 3, "f", "toop",
+                               (SUBR) tab2pvs_init, (SUBR) tab2pvs, NULL}
 };
 
 int pvsbasic_init_(CSOUND *csound)
@@ -2256,4 +2271,3 @@ int pvsbasic_init_(CSOUND *csound)
   return csound->AppendOpcodes(csound, &(localops[0]),
                                (int) (sizeof(localops) / sizeof(OENTRY)));
 }
-
