@@ -60,7 +60,8 @@ kpitch - pitch control (transposition ratio)
 
 FLOOPER2
 
-asig flooper2 kamp, kpitch, kloopstart, kloopend, kcrossfade, ifn [, istart, imode, ifenv]
+asig flooper2 kamp, kpitch, kloopstart, kloopend, kcrossfade,
+              ifn [, istart, imode, ifenv]
 
 Function-table crossfading looper with variable loop parameters and
 different looping modes.
@@ -69,7 +70,8 @@ INIT
 
 ifn - sound source function table. Non-power-of-two and deferred allocation
 tables are allowed.
-istart - playback starting point in secs, only applicable to loop modes 0 & 2 [def:0]
+istart - playback starting point in secs, only applicable to loop modes 0 & 2
+         [def:0]
 imode - loop modes: 0 forward, 1 backward, 2 back-and-forth [def: 0]
 ifenv - if non-zero, crossfade envelope shape table number. 0, the default, sets
 the crossfade to linear.
@@ -388,7 +390,7 @@ static int flooper2_init(CSOUND *csound, flooper2 *p)
     if (UNLIKELY(p->sfunc==NULL)) {
       return csound->InitError(csound,Str("function table not found\n"));
     }
-    if (*p->ifn2 != 0) p->efunc = csound->FTFind(csound, p->ifn2);
+    if (*p->ifn2 != 0) p->efunc = csound->FTnp2Find(csound, p->ifn2);
     else p->efunc = NULL;
 
     if (*p->iskip == 0){
@@ -656,7 +658,7 @@ static int flooper2_process(CSOUND *csound, flooper2 *p)
 static int flooper3_init(CSOUND *csound, flooper3 *p)
 {
     int len,i,p2s,lomod;
-    p->sfunc = csound->FTnp2Find(csound, p->ifn);  
+    p->sfunc = csound->FTnp2Find(csound, p->ifn);
     if (UNLIKELY(p->sfunc==NULL)) {
       return csound->InitError(csound,Str("function table not found\n"));
     }
@@ -832,7 +834,7 @@ static int flooper3_process(CSOUND *csound, flooper3 *p)
       }
       else if (mode == 2){
         out[i] = 0;
-        
+
         tndx0 = ndx[0]>>lobits;
         frac0 = (ndx[0] & lomask)*lodiv;
         if (init && tndx0 < loop_start + crossfade) {
@@ -870,7 +872,7 @@ static int flooper3_process(CSOUND *csound, flooper3 *p)
           count  += ei;
         }
 
-        
+
         tndx1 = ndx[1]>>lobits;
         frac1 = (ndx[1] & lomask)*lodiv;
         if (tndx1 > loop_end - crossfade) {
@@ -905,11 +907,13 @@ static int flooper3_process(CSOUND *csound, flooper3 *p)
             loop_start = MYFLT2LRND(*p->loop_start*sr);
             loop_end =   MYFLT2LRND(*p->loop_end*sr);
             p->lstart = loop_start = (loop_start < 0 ? 0 : loop_start);
-            p->lend = loop_end =   (loop_end > len ? len :
-                                    (loop_end < loop_start ? loop_start : loop_end));
+            p->lend = loop_end =
+              (loop_end > len ? len :
+              (loop_end < loop_start ? loop_start : loop_end));
             loopsize = (loop_end - loop_start);
             crossfade =  MYFLT2LRND(*p->crossfade*sr);
-            p->cfade = crossfade = crossfade > loopsize/2 ? loopsize/2-1 : crossfade;
+            p->cfade = crossfade =
+              crossfade > loopsize/2 ? loopsize/2-1 : crossfade;
             cvt = (MYFLT)elen/p->cfade;
           }
         }
@@ -998,15 +1002,16 @@ static int pvsvoc_init(CSOUND *csound, pvsvoc *p)
    if (p->ceps.auxp == NULL ||
       p->ceps.size < sizeof(MYFLT) * (N+2))
     csound->AuxAlloc(csound, sizeof(MYFLT) * (N + 2), &p->ceps);
-  memset(p->ceps.auxp, 0, sizeof(MYFLT)*(N+2));
-  if (p->fenv.auxp == NULL ||
-      p->fenv.size < sizeof(MYFLT) * (N+2))
-    csound->AuxAlloc(csound, sizeof(MYFLT) * (N + 2), &p->fenv);
-  if (p->fexc.auxp == NULL ||
-      p->fexc.size < sizeof(MYFLT) * (N+2))
-    csound->AuxAlloc(csound, sizeof(MYFLT) * (N + 2), &p->fexc);
+   else
+     memset(p->ceps.auxp, 0, sizeof(MYFLT)*(N+2));
+   if (p->fenv.auxp == NULL ||
+       p->fenv.size < sizeof(MYFLT) * (N+2))
+     csound->AuxAlloc(csound, sizeof(MYFLT) * (N + 2), &p->fenv);
+   if (p->fexc.auxp == NULL ||
+       p->fexc.size < sizeof(MYFLT) * (N+2))
+     csound->AuxAlloc(csound, sizeof(MYFLT) * (N + 2), &p->fexc);
 
-    return OK;
+   return OK;
 }
 
 static int pvsvoc_process(CSOUND *csound, pvsvoc *p)
