@@ -211,7 +211,7 @@ static int posc_set(CSOUND *csound, POSC *p)
 {
     FUNC *ftp;
 
-    if (UNLIKELY((ftp = csound->FTnp2Find(csound, p->ift)) == NULL)) 
+    if (UNLIKELY((ftp = csound->FTnp2Find(csound, p->ift)) == NULL))
       return csound->InitError(csound, Str("table not found in poscil"));
     p->ftp        = ftp;
     p->tablen     = ftp->flen;
@@ -335,7 +335,7 @@ static int poscak(CSOUND *csound, POSC *p)
 static int kposc(CSOUND *csound, POSC *p)
 {
     double      phs = p->phs;
-    double      si = *p->freq * p->tablen * csound->onedkr;
+    double      si = *p->freq * p->tablen * CS_ONEDKR;
     MYFLT       *curr_samp = p->ftp->ftable + (int32)phs;
     MYFLT       fract = (MYFLT)(phs - (double)((int32)phs));
 
@@ -544,7 +544,7 @@ static int posc3aa(CSOUND *csound, POSC *p)
 static int kposc3(CSOUND *csound, POSC *p)
 {
     double      phs   = p->phs;
-    double      si    = *p->freq * p->tablen * csound->onedkr;
+    double      si    = *p->freq * p->tablen * CS_ONEDKR;
     MYFLT       *ftab = p->ftp->ftable;
     int         x0    = (int32)phs;
     MYFLT       fract = (MYFLT)(phs - (double)x0);
@@ -584,7 +584,8 @@ static int lposc_set(CSOUND *csound, LPOSC *p)
     FUNC   *ftp;
     MYFLT  loop, end, looplength;
 
-    if (UNLIKELY((ftp = csound->FTnp2Find(csound, p->ift)) == NULL)) return NOTOK;
+    if (UNLIKELY((ftp = csound->FTnp2Find(csound, p->ift)) == NULL))
+      return NOTOK;
     if (UNLIKELY(!(p->fsr=ftp->gen01args.sample_rate))) {
       csound->Warning(csound, Str("losc: no sample rate stored in function "
                                   "assuming=sr\n"));
@@ -714,7 +715,7 @@ static int rsnsety(CSOUND *csound, RESONY *p)
     if ((p->loop = (int) MYFLT2LONG(*p->ord)) < 1)
       p->loop = 4;  /* default value */
     if (!*p->istor && (p->aux.auxp == NULL ||
-                      (int32) (p->loop * 2 * sizeof(MYFLT)) > p->aux.size))
+                      (uint32_t) (p->loop * 2 * sizeof(MYFLT)) > p->aux.size))
       csound->AuxAlloc(csound, (size_t) (p->loop * 2 * sizeof(MYFLT)), &p->aux);
     p->yt1 = (MYFLT*)p->aux.auxp; p->yt2 = (MYFLT*)p->aux.auxp + p->loop;
     if (UNLIKELY(scale && scale != 1 && scale != 2)) {
@@ -794,6 +795,7 @@ static int fold_set(CSOUND *csound, FOLD *p)
 {
     p->sample_index = 0;
     p->index = 0.0;
+    p->value = FL(0.0);         /* This was not initialised -- JPff */
     return OK;
 }
 
@@ -826,6 +828,10 @@ static int fold(CSOUND *csound, FOLD *p)
 static int loopseg_set(CSOUND *csound, LOOPSEG *p)
 {
     p->nsegs   = p->INOCOUNT-3;
+    // Should check this is even
+    if (UNLIKELY((p->nsegs&1)!=0)) 
+      return csound->InitError(csound,
+                               Str("loop opcode: wrong argument count"));
     p->args[0] = FL(0.0);
     p->phs     = *p->iphase;
     return OK;
@@ -833,13 +839,13 @@ static int loopseg_set(CSOUND *csound, LOOPSEG *p)
 
 static int loopseg(CSOUND *csound, LOOPSEG *p)
 {
-    MYFLT *argp=p->args;
-    MYFLT beg_seg=FL(0.0), end_seg, durtot=FL(0.0);
-    double   phs, si=*p->freq*csound->onedkr;
+    MYFLT *argp = p->args;
+    MYFLT beg_seg = FL(0.0), end_seg, durtot = FL(0.0);
+    double   phs, si = *p->freq*CS_ONEDKR, dummy;
     int nsegs=p->nsegs+1;
     int j;
     if (*p->retrig)
-      phs=p->phs=*p->iphase;
+      phs=p->phs=modf((double)*p->iphase, &dummy);
     else
       phs=p->phs;
 
@@ -864,10 +870,10 @@ static int loopseg(CSOUND *csound, LOOPSEG *p)
       }
     }
     phs    += si;
-    while (phs >= 1.0)
-      phs -= 1.0;
-    while (phs < 0.0 )
-      phs += 1.0;
+    /* while (UNLIKELY(phs >= 1.0)) */
+    /*   phs -= 1.0; */
+    phs = modf(phs, &dummy);
+    if (UNLIKELY(phs < 0.0 )) phs += 1.0;
     p->phs = phs;
     return OK;
 }
@@ -877,11 +883,11 @@ static int loopxseg(CSOUND *csound, LOOPSEG *p)
     MYFLT exp1 = FL(1.0)/(FL(1.0)-EXP(FL(1.0)));
     MYFLT *argp=p->args;
     MYFLT beg_seg=FL(0.0), end_seg, durtot=FL(0.0);
-    double   phs, si=*p->freq*csound->onedkr;
+    double   phs, si=*p->freq*CS_ONEDKR, dummy;
     int nsegs=p->nsegs+1;
     int j;
     if (*p->retrig)
-      phs=p->phs=*p->iphase;
+      phs=p->phs=modf(*p->iphase, &dummy);
     else
       phs=p->phs;
 
@@ -906,10 +912,10 @@ static int loopxseg(CSOUND *csound, LOOPSEG *p)
       }
     }
     phs    += si;
-    while (phs >= 1.0)
-      phs -= 1.0;
-    while (phs < 0.0 )
-      phs += 1.0;
+    /* while (phs >= 1.0) */
+    /*   phs -= 1.0; */
+    phs = modf(phs, &dummy);
+    if (phs < 0.0 ) phs += 1.0;
     p->phs = phs;
     return OK;
 }
@@ -924,12 +930,12 @@ static int looptseg_set(CSOUND *csound, LOOPTSEG *p)
 static int looptseg(CSOUND *csound, LOOPTSEG *p)
 {
     MYFLT beg_seg=FL(0.0), end_seg=FL(0.0), durtot=FL(0.0);
-    double   phs, si=*p->freq*csound->onedkr;
+    double   phs, si=*p->freq*CS_ONEDKR, dummy;
     int nsegs=p->nsegs;
     int j;
 
     if (*p->retrig)
-      phs=p->phs=*p->iphase;
+      phs=p->phs=modf((double)*p->iphase, &dummy);
     else
       phs=p->phs;
 
@@ -953,10 +959,10 @@ static int looptseg(CSOUND *csound, LOOPTSEG *p)
       }
     }
     phs    += si;
-    while (UNLIKELY(phs >= 1.0))
-      phs -= 1.0;
-    while (UNLIKELY(phs < 0.0 ))
-      phs += 1.0;
+    /* while (UNLIKELY(phs >= 1.0)) */
+    /*   phs -= 1.0; */
+    phs = MODF(phs, &dummy);
+    if (UNLIKELY(phs < 0.0 )) phs += 1.0;
     p->phs = phs;
     return OK;
 }
@@ -964,13 +970,13 @@ static int looptseg(CSOUND *csound, LOOPTSEG *p)
 static int lpshold(CSOUND *csound, LOOPSEG *p)
 {
     MYFLT *argp=p->args;
-    MYFLT beg_seg=0, end_seg, durtot=FL(0.0);
-    double   phs, si=*p->freq*csound->onedkr;
+    MYFLT beg_seg=FL(0.0), end_seg, durtot=FL(0.0);
+    double   phs, si=*p->freq*CS_ONEDKR, dummy;
     int nsegs=p->nsegs+1;
     int j;
 
     if (*p->retrig)
-      phs=p->phs=*p->iphase;
+      phs=p->phs=modf((double)*p->iphase, &dummy);
     else
       phs=p->phs;
 
@@ -991,10 +997,10 @@ static int lpshold(CSOUND *csound, LOOPSEG *p)
       }
     }
     phs    += si;
-    while (phs >= 1.0)
-      phs -= 1.0;
-    while (phs < 0.0 )
-      phs += 1.0;
+    /* while (phs >= 1.0) */
+    /*   phs -= 1.0; */
+    phs = modf(phs, &dummy);
+    if (UNLIKELY(phs < 0.0 )) phs += 1.0;
     p->phs = phs;
     return OK;
 }
@@ -1009,17 +1015,17 @@ static int loopsegp_set(CSOUND *csound, LOOPSEGP *p)
 static int loopsegp(CSOUND *csound, LOOPSEGP *p)
 {
     MYFLT *argp = p->args;
-    MYFLT beg_seg=0, end_seg, durtot=FL(0.0);
+    MYFLT beg_seg=0, end_seg, durtot=FL(0.0), dummy;
     MYFLT phs;
     int nsegs=p->nsegs+1;
     int j;
 
     phs = *p->kphase;
 
-    while (phs >= FL(1.0))
-      phs -= FL(1.0);
-    while (phs < FL(0.0))
-      phs += FL(1.0);
+    /* while (phs >= FL(1.0)) */
+    /*   phs -= FL(1.0); */
+    phs = MODF(phs, &dummy);
+    if (phs < FL(0.0)) phs += FL(1.0);
 
     for (j=1; j<nsegs; j++)
       argp[j] = *p->argums[j-1];
@@ -1047,17 +1053,14 @@ static int loopsegp(CSOUND *csound, LOOPSEGP *p)
 static int lpsholdp(CSOUND *csound, LOOPSEGP *p)
 {
     MYFLT *argp=p->args;
-    MYFLT beg_seg=FL(0.0), end_seg, durtot=FL(0.0);
+    MYFLT beg_seg=FL(0.0), end_seg, durtot=FL(0.0), dummy;
     MYFLT phs;
     int nsegs=p->nsegs+1;
     int j;
 
-    phs = *p->kphase;
+    phs = MODF(*p->kphase, &dummy);
 
-    while (phs >= FL(1.0))
-      phs -= FL(1.0);
-    while (phs < FL(0.0))
-      phs += FL(1.0);
+    if (phs < FL(0.0)) phs += FL(1.0);
 
     for (j=1; j<nsegs; j++)
       argp[j] = *p->argums[j-1];
@@ -1142,7 +1145,7 @@ static int tlineto(CSOUND *csound, LINETO2 *p)
       p->current_val = *p->ksig;
     }
     else if (p->current_time < p->old_time) {
-      p->current_time += csound->onedkr;
+      p->current_time += CS_ONEDKR;
       p->val_incremented += p->incr;
     }
     *p->kr = p->val_incremented;
@@ -1156,7 +1159,7 @@ static int vibrato_set(CSOUND *csound, VIBRATO *p)
 {
     FUNC        *ftp;
 
-    if ((ftp = csound->FTFind(csound, p->ifn)) != NULL) {
+    if ((ftp = csound->FTnp2Find(csound, p->ifn)) != NULL) {
       p->ftp = ftp;
       if (*p->iphs >= 0)
         p->lphs = ((int32)(*p->iphs * FMAXLEN)) & PHMASK;
@@ -1167,7 +1170,7 @@ static int vibrato_set(CSOUND *csound, VIBRATO *p)
     p->xcpsFreqRate = randGab *(*p->ampMaxRate - *p->ampMinRate) +
       *p->ampMinRate;
     p->tablen = ftp->flen;
-    p->tablenUPkr = p->tablen * csound->onedkr;
+    p->tablenUPkr = p->tablen * CS_ONEDKR;
     return OK;
 }
 
@@ -1234,7 +1237,7 @@ static int vibr_set(CSOUND *csound, VIBR *p)
 #define cpsMaxRate      FL(2.28100)
 #define iphs            FL(0.0)
 
-    if (LIKELY((ftp = csound->FTFind(csound, p->ifn)) != NULL)) {
+    if (LIKELY((ftp = csound->FTnp2Find(csound, p->ifn)) != NULL)) {
       p->ftp = ftp;
       p->lphs = ((int32)(iphs * FMAXLEN)) & PHMASK;
     }
@@ -1242,7 +1245,7 @@ static int vibr_set(CSOUND *csound, VIBR *p)
     p->xcpsAmpRate = randGab  * (cpsMaxRate - cpsMinRate) + cpsMinRate;
     p->xcpsFreqRate = randGab  * (ampMaxRate - ampMinRate) + ampMinRate;
     p->tablen = ftp->flen;
-    p->tablenUPkr = p->tablen * csound->onedkr;
+    p->tablenUPkr = p->tablen * CS_ONEDKR;
     return OK;
 }
 
@@ -1408,7 +1411,7 @@ static int jitters(CSOUND *csound, JITTERS *p)
     if (p->phs >= 1.0) {
       MYFLT     slope, resd1, resd0, f2, f1;
     next:
-      p->si = (randGab * (*p->cpsMax-*p->cpsMin) + *p->cpsMin)*csound->onedkr;
+      p->si = (randGab * (*p->cpsMax-*p->cpsMin) + *p->cpsMin)*CS_ONEDKR;
       if (p->si == 0) p->si = 1; /* Is this necessary? */
       while (p->phs > 1.0)
         p->phs -= 1.0;
@@ -1473,7 +1476,8 @@ static int jittersa(CSOUND *csound, JITTERS *p)
 static int kDiscreteUserRand(CSOUND *csound, DURAND *p)
 { /* gab d5*/
     if (p->pfn != (int32)*p->tableNum) {
-      if (UNLIKELY( (p->ftp = csound->FTFindP(csound, p->tableNum) ) == NULL)) goto err1;
+      if (UNLIKELY( (p->ftp = csound->FTFindP(csound, p->tableNum) ) == NULL))
+        goto err1;
       p->pfn = (int32)*p->tableNum;
     }
     *p->out = p->ftp->ftable[(int32)(randGab * MYFLT2LONG(p->ftp->flen))];
@@ -1496,7 +1500,8 @@ static int aDiscreteUserRand(CSOUND *csound, DURAND *p)
     int n, nsmps = csound->ksmps, flen;
 
     if (p->pfn != (int32)*p->tableNum) {
-      if (UNLIKELY( (p->ftp = csound->FTFindP(csound, p->tableNum) ) == NULL)) goto err1;
+      if (UNLIKELY( (p->ftp = csound->FTFindP(csound, p->tableNum) ) == NULL))
+        goto err1;
       p->pfn = (int32)*p->tableNum;
     }
     table = p->ftp->ftable;
@@ -1515,7 +1520,8 @@ static int kContinuousUserRand(CSOUND *csound, CURAND *p)
     int32 indx;
     MYFLT findx, fract, v1, v2;
     if (p->pfn != (int32)*p->tableNum) {
-      if (UNLIKELY( (p->ftp = csound->FTFindP(csound, p->tableNum) ) == NULL)) goto err1;
+      if (UNLIKELY( (p->ftp = csound->FTFindP(csound, p->tableNum) ) == NULL))
+        goto err1;
       p->pfn = (int32)*p->tableNum;
     }
     findx = (MYFLT) (randGab * MYFLT2LONG(p->ftp->flen));
@@ -1551,7 +1557,8 @@ static int aContinuousUserRand(CSOUND *csound, CURAND *p)
     MYFLT findx, fract,v1,v2;
 
     if (p->pfn != (int32)*p->tableNum) {
-      if (UNLIKELY( (p->ftp = csound->FTFindP(csound, p->tableNum) ) == NULL)) goto err1;
+      if (UNLIKELY( (p->ftp = csound->FTFindP(csound, p->tableNum) ) == NULL))
+        goto err1;
       p->pfn = (int32)*p->tableNum;
     }
 
@@ -1604,7 +1611,8 @@ static int randomi_set(CSOUND *csound, RANDOMI *p)
         p->dfdmax = (p->num2 - p->num1) / FMAXLEN;
         break;
     case 2: /* immediate interpolation between ifirstval and 1st random number */
-        p->num1 = (*p->max - *p->min) ? (*p->fstval - *p->min) / (*p->max - *p->min) : FL(0.0);
+        p->num1 = (*p->max - *p->min) ?
+          (*p->fstval - *p->min) / (*p->max - *p->min) : FL(0.0);
         p->num2 = randGab;
         p->dfdmax = (p->num2 - p->num1) / FMAXLEN;
         break;
@@ -1670,7 +1678,8 @@ static int randomh_set(CSOUND *csound, RANDOMH *p)
     int mode = (int)(*p->mode);
     switch (mode) {
     case 2: /* the first output value is ifirstval */
-        p->num1 = (*p->max - *p->min) ? (*p->fstval - *p->min) / (*p->max - *p->min) : FL(0.0);
+        p->num1 = (*p->max - *p->min) ?
+          (*p->fstval - *p->min) / (*p->max - *p->min) : FL(0.0);
         break;
     case 3: /* the first output value is a random number within the defined range */
         p->num1 = randGab;
@@ -1743,9 +1752,10 @@ static int random3(CSOUND *csound, RANDOM3 *p)
     if (p->phs >= 1.0) {
       MYFLT     slope, resd1, resd0, f2, f1;
     next:
-      p->si = (randGab * (*p->cpsMax-*p->cpsMin) + *p->cpsMin)*csound->onedkr;
-      while (p->phs > 1.0)
-        p->phs -= 1.0;
+      p->si = (randGab * (*p->cpsMax-*p->cpsMin) + *p->cpsMin)*CS_ONEDKR;
+      /* while (p->phs > 1.0) */
+      /*   p->phs -= 1.0; */
+      p->phs = MODF(p->phs, &f0);
       f0     = p->num0 = p->num1;
       f1     = p->num1 = p->num2;
       f2     = p->num2 = randGab;
@@ -1784,8 +1794,9 @@ static int random3a(CSOUND *csound, RANDOM3 *p)
         MYFLT   slope, resd1, resd0, f2, f1;
       next:
         si =  (randGab  * (cpsMax - cpsMin) + cpsMin)*csound->onedsr;
-        while (phs > 1.0)
-          phs -= 1.0;
+        /* while (phs > 1.0) */
+        /*   phs -= 1.0; */
+        phs    = MODF(phs, &f0);
         f0     = p->num0 = p->num1;
         f1     = p->num1 = p->num2;
         f2     = p->num2 = BiRandGab;
@@ -1889,4 +1900,3 @@ int uggab_init_(CSOUND *csound)
     return csound->AppendOpcodes(csound, &(localops[0]),
                                  (int) (sizeof(localops) / sizeof(OENTRY)));
 }
-
