@@ -172,6 +172,10 @@ PUBLIC EVLIST * cscoreListCreate(CSOUND *csound, int nslots)
     int   needsiz = sizeof(EVLIST) + nslots * sizeof(EVENT *);
     int   minfreesiz = needsiz + sizeof(CSHDR);
 
+    if (minfreesiz > MAXALLOC) {
+      csound->Message(csound, Str("Not enough memory\n"));
+      exit(1);
+    }
     if (nxtfree != NULL && nxtfree->size >= minfreesiz)
       newblk = nxtfree;
     else newblk = getfree(csound, minfreesiz);
@@ -199,6 +203,10 @@ PUBLIC EVENT * cscoreCreateEvent(CSOUND *csound, int pcnt)
     int   needsiz = sizeof(EVENT) + pcnt * sizeof(MYFLT);
     int   minfreesiz = needsiz + sizeof(CSHDR);
 
+    if (minfreesiz > MAXALLOC) {
+      csound->Message(csound, Str("Not enough memory\n"));
+      exit(1);
+    }
     if (nxtfree != NULL && nxtfree->size >= minfreesiz)
       newblk = nxtfree;
     else newblk = getfree(csound, minfreesiz);
@@ -835,7 +843,7 @@ PUBLIC int csoundInitializeCscore(CSOUND *csound, FILE* insco, FILE* outsco)
     next = cscoreCreateEvent(csound, PMAX); /* creat EVENT blk receiving buf */
     next->op = '\0';
     savinfdata(csound, csound->scfp,
-               next, FL(0.0), 1, 0, 0);    /* curuntil 0, wasend, non-warp, not eof */
+               next, FL(0.0), 1, 0, 0); /* curuntil 0, wasend, non-warp, not eof */
     makecurrent(csound, csound->scfp);  /* make all this current         */
 
     return CSOUND_SUCCESS;
@@ -865,7 +873,7 @@ PUBLIC int csoundInitializeCscore(CSOUND *csound, FILE* insco, FILE* outsco)
     next->op = '\0';
 
     savinfdata(csound, csound->scfp,
-               next, FL(0.0), 1, 0, 0);    /* curuntil 0, wasend, non-warp, not eof */
+               next, FL(0.0), 1, 0, 0); /* curuntil 0, wasend, non-warp, not eof */
     makecurrent(csound, csound->scfp);  /* make all this current         */
 
     return CSOUND_SUCCESS;
@@ -941,7 +949,7 @@ PUBLIC void cscoreFileSetCurrent(CSOUND *csound, FILE *fp)
       corfile_rewind(inf);
       corfile_rm(&csound->scstr);
       csound->scstr = inf;
-      nxtevt->op = NULL;
+      nxtevt->op = '\0';
       atEOF = 0;
     }
     if (csound->scfp != NULL)
