@@ -81,7 +81,8 @@
 #if defined(__MACH__)
 #include <TargetConditionals.h>
 #if (TARGET_OS_IPHONE == 0) && (TARGET_IPHONE_SIMULATOR == 0)
-#if defined(MAC_OS_X_VERSION_10_6) && (MAC_OS_X_VERSION_MIN_REQUIRED>=MAC_OS_X_VERSION_10_6)
+#if defined(MAC_OS_X_VERSION_10_6) && \
+  (MAC_OS_X_VERSION_MIN_REQUIRED>=MAC_OS_X_VERSION_10_6)
 #define NEW_MACH_CODE
 #else
 #define OLD_MACH_CODE
@@ -89,7 +90,7 @@
 #endif
 #endif
 
-#if defined(LINUX) || defined(NEW_MACH_CODE)
+#if defined(LINUX) || defined(NEW_MACH_CODE) || defined(__HAIKU__)
 #include <dlfcn.h>
 #elif defined(WIN32)
 #include <windows.h>
@@ -133,7 +134,16 @@ static  const   char    *plugindir_envvar =   "OPCODEDIR";
 static  const   char    *plugindir64_envvar = "OPCODEDIR64";
 
 /* default directory to load plugins from if environment variable is not set */
-#if !(defined(_CSOUND_RELEASE_) && (defined(LINUX) || defined(__MACH__)))
+#if defined(__HAIKU__)
+#  define ENABLE_OPCODEDIR_WARNINGS 0
+#  ifndef CS_DEFAULT_PLUGINDIR
+#    ifndef USE_DOUBLE
+#      define CS_DEFAULT_PLUGINDIR  "/boot/common/lib/csound/plugins"
+#    else
+#      define CS_DEFAULT_PLUGINDIR  "/boot/common/lib/csound/plugins64"
+#    endif
+#  endif
+#elif !(defined(_CSOUND_RELEASE_) && (defined(LINUX) || defined(__MACH__)))
 #  define ENABLE_OPCODEDIR_WARNINGS 1
 #  ifdef CS_DEFAULT_PLUGINDIR
 #    undef CS_DEFAULT_PLUGINDIR
@@ -248,7 +258,7 @@ static CS_NOINLINE int csoundLoadExternal(CSOUND *csound,
     err = csound->OpenLibrary(&h, libraryPath);
     if (UNLIKELY(err)) {
       char ERRSTR[256];
- #if defined(LINUX)
+ #if defined(LINUX) || defined(__HAIKU__)
       sprintf(ERRSTR, Str("could not open library '%s' (%s)"),
                       libraryPath, dlerror());
  #else
@@ -542,7 +552,8 @@ static OSErr GetFragmentName(CSOUND* csound, FSSpecPtr libr, char* name)
 }
 
 /* Examine each file in theFolder and load it if it is a Csound plugin */
-static OSErr SearchFolderAndLoadPlugins(CSOUND *csound, FSSpecPtr theFolder, int* cserr)
+static OSErr SearchFolderAndLoadPlugins(CSOUND *csound,
+                                        FSSpecPtr theFolder, int* cserr)
 {
     OSErr      err, err2;
     int        result;
@@ -573,13 +584,15 @@ static OSErr SearchFolderAndLoadPlugins(CSOUND *csound, FSSpecPtr theFolder, int
                 catinfo.hFileInfo.ioFlFndrInfo.fdCreator == 'Csnd') {
                 /* this is a Csound plugin library */
                 err2 = FSMakeFSSpec(catinfo.hFileInfo.ioVRefNum,
-                      catinfo.hFileInfo.ioFlParID, catinfo.hFileInfo.ioNamePtr, &spec);
+                      catinfo.hFileInfo.ioFlParID, catinfo.hFileInfo.ioNamePtr,
+                                    &spec);
                 if (err2 != noErr) continue; /* this really should not happen */
                 err2 = GetFragmentName(csound, &spec, fragname);
                 result = CSOUND_SUCCESS;
                 if (err2 == noErr) result = csoundLoadExternal(csound, fragname);
                 /* record serious errors */
-                if (result != CSOUND_SUCCESS && result != CSOUND_ERROR) *cserr = result;
+                if (result != CSOUND_SUCCESS && result != CSOUND_ERROR)
+                  *cserr = result;
                 /* continue to search folder when one file fails to load */
             }
         }
@@ -651,7 +664,7 @@ int csoundLoadModules(CSOUND *csound)
     err = FindCsoundExtensionsFolder(&pluginDir);
     if  (err == noErr)
         SearchFolderAndLoadPlugins(csound, &pluginDir, &cserr);
-    /* ignore errors from search & we don't care if unable to locate */
+    /* ignore errors from search & we do not care if unable to locate */
 
     return cserr;
 }
@@ -951,7 +964,7 @@ PUBLIC void *csoundGetLibrarySymbol(void *library, const char *procedureName)
     return (void*) GetProcAddress((HMODULE) library, procedureName);
 }
 
-#elif defined(LINUX) || defined (NEW_MACH_CODE)
+#elif defined(LINUX) || defined (NEW_MACH_CODE) || defined(__HAIKU__)
 
 PUBLIC int csoundOpenLibrary(void **library, const char *libraryPath)
 {
@@ -1077,7 +1090,7 @@ int csoundOpenLibrary(void **library, const char *libraryPath)
     case NSObjectFileImageSuccess:
       /* It was okay, so use NSLinkModule to link in the image */
       *library = NSLinkModule(ofi, libraryPath, flags);
-      /* Don't forget to destroy the object file
+      /* do not forget to destroy the object file
          image, unless you like leaks */
       NSDestroyObjectFileImage(ofi);
       /* If the mode was global, then change the module, this avoids
@@ -1344,8 +1357,8 @@ const INITFN staticmodules[] = { hrtfopcodes_localops_init, babo_localops_init,
                                  crossfm_localops_init, pvlock_localops_init,
                                  fareyseq_localops_init, hrtfearly_localops_init,
                                  hrtfreverb_localops_init, minmax_localops_init,
-                                 vaops_localops_init, 
-#ifndef WIN32
+                                 vaops_localops_init,
+#if defined(__MACH__) || defined(LINUX) || defined(__HAIKU__)
                                  cpumeter_localops_init,
 #endif
                                  mp3in_localops_init, gendy_localops_init,
@@ -1362,15 +1375,15 @@ CS_NOINLINE int csoundInitStaticModules(CSOUND *csound)
     int     i;
     OENTRY  *opcodlst_n;
     long    length;
-
+    
     for (i=0; staticmodules[i]!=NULL; i++) {
       length = (staticmodules[i])(csound, &opcodlst_n);
 
       if (UNLIKELY(length <= 0L)) return CSOUND_ERROR;
       length /= (long) sizeof(OENTRY);
       if (length) {
-        if (UNLIKELY(csound->AppendOpcodes(csound, opcodlst_n,
-                                           (int) length) != 0))
+	 if (UNLIKELY(csound->AppendOpcodes(csound, opcodlst_n,
+	                                 (int) length) != 0))
           return CSOUND_ERROR;
       }
     }
