@@ -110,10 +110,17 @@ CS_NOINLINE char *csoundTmpFileName(CSOUND *csound, char *buf, const char *ext)
         //        if (UNLIKELY(mytmpnam(buf) == NULL))
         //          csound->Die(csound, Str(" *** cannot create temporary file"));
         int fd;
-        strcpy(buf, "/tmp/csoundXXXXXX");
+        char *tmpdir = getenv("TMPDIR");
+        if (tmpdir != NULL && tmpdir[0] != '\0')
+          snprintf(buf, nBytes, "%s/csound-XXXXXX", tmpdir);
+        else
+          strcpy(buf, "/tmp/csound-XXXXXX");
+        umask(0077); /* ensure exclusive access on buggy i
+                        mplementations of mkstemp */
         if (UNLIKELY((fd = mkstemp(buf)) < 0))
           csound->Die(csound, Str(" *** cannot create temporary file"));
         close(fd);
+        unlink(buf);
 #else
         {
           char  *s = (char*) csoundGetEnv(csound, "SFDIR");
@@ -280,9 +287,15 @@ int readOptions(CSOUND *csound, FILE *unf, int readingCsOptions)
               csoundDie(csound, Str("More than %d arguments in <CsOptions>"),
                         CSD_MAX_ARGS);
             argv[++argc] = ++p;
-            while (*p != '"' && *p != '\0') p++;
-
-            if (*p == '"') *p = '\0';
+            while (*p != '"' && *p != '\0') {
+              if (*p == '\\' && *(p+1) != '\0')
+                p++;
+              p++;
+            }
+            if (*p == '"') {
+              /* ETX char used to mark the limits of a string */
+              *p = (isspace(*(p+1)) ? '\0' : 3);
+            }
             break;
           }
 
@@ -313,6 +326,27 @@ int readOptions(CSOUND *csound, FILE *unf, int readingCsOptions)
           *p = '\0';
           break;
         }
+        else if (*p=='"') {
+          int is_escape = 0;
+          char *old = NULL;
+          *p=3; /* ETX char used to mark the limits of a string */
+          while ((*p != '"' || is_escape) && *p != '\0') {
+            if (is_escape)
+              *old = 0x18; /* CAN char used to mark a removable character */
+            is_escape = (*p == '\\' ? !is_escape : 0);
+            old = p;
+            p++;
+          }
+          if (*p == '"') {
+            if (isspace(*(p+1))) {
+              *p = '\0';
+              break;
+            }
+            else {
+              *p = 3;
+            }
+          }
+        }
         p++;
       }
 #ifdef _DEBUG
@@ -351,15 +385,15 @@ static int createOrchestra(CSOUND *csound, FILE *unf)
       while (*p == ' ' || *p == '\t') p++;
       if (strstr(p, "</CsInstruments>") == p) {
         //corfile_flush(incore);
-#ifdef ENABLE_NEW_PARSER
+        //#ifdef ENABLE_NEW_PARSER
         if (csound->oparms->newParser) corfile_puts("\n#exit\n", incore);
-#endif
+        //#endif
         corfile_putc('\0', incore);
         corfile_putc('\0', incore);
         csound->orchstr = incore;
         return TRUE;
       }
-      else 
+      else
         corfile_puts(buffer, incore);
     }
     csoundErrorMsg(csound, Str("Missing end tag </CsInstruments>"));
@@ -369,20 +403,18 @@ static int createOrchestra(CSOUND *csound, FILE *unf)
 static int createScore(CSOUND *csound, FILE *unf)
 {
     char   *p;
-    CORFIL *incore = corfile_create_w();
     char   buffer[CSD_MAX_LINE_LEN];
 
+    if (csound->scorestr == NULL)
+      csound->scorestr = corfile_create_w();
     csound->scoLineOffset = ST(csdlinecount);
     while (my_fgets(csound, buffer, CSD_MAX_LINE_LEN, unf)!= NULL) {
       p = buffer;
       while (*p == ' ' || *p == '\t') p++;
-      if (strstr(p, "</CsScore>") == p) {
-        corfile_flush(incore);
-        csound->scorestr = incore;
+      if (strstr(p, "</CsScore>") == p)
         return TRUE;
-      }
-      else 
-        corfile_puts(buffer, incore);
+      else
+        corfile_puts(buffer, csound->scorestr);
     }
     csoundErrorMsg(csound, Str("Missing end tag </CsScore>"));
     return FALSE;
@@ -430,10 +462,22 @@ static int createExScore(CSOUND *csound, char *p, FILE *unf)
         sprintf(sys, "%s %s %s", prog, extname, ST(sconame));
         if (UNLIKELY(system(sys) != 0)) {
           csoundErrorMsg(csound, Str("External generation failed"));
+          remove(extname);
+          remove(ST(sconame));
           return FALSE;
         }
         remove(extname);
-        add_tmpfile(csound, ST(sconame));           /* IV - Feb 03 2005 */
+        if (csound->scorestr == NULL)
+          csound->scorestr = corfile_create_w();
+        fd = csoundFileOpen(csound, &scof, CSFILE_STD, ST(sconame), "r", NULL);
+        if (UNLIKELY(fd == NULL)) {
+          remove(ST(sconame));
+          return FALSE;
+        }
+        while (my_fgets(csound, buffer, CSD_MAX_LINE_LEN, scof)!= NULL)
+          corfile_puts(buffer, csound->scorestr);
+        csoundFileClose(csound, fd);
+        remove(ST(sconame));
         return TRUE;
       }
       else fputs(buffer, scof);
@@ -584,12 +628,7 @@ static int createFile(CSOUND *csound, char *buffer, FILE *unf)
     else
       q = strchr(p, '>');
     if (q) *q='\0';
-    //  printf("p=>>%s<<\n", p);
     strcpy(filename, p);
-//sscanf(buffer, "<CsFileB filename=\"%s\">", filename);
-//    if (filename[0] != '\0' &&
-//       filename[strlen(filename) - 1] == '>' && filename[strlen(filename) - 2] == '"')
-//    filename[strlen(filename) - 2] = '\0';
     if (UNLIKELY((smpf = fopen(filename, "rb")) != NULL)) {
       fclose(smpf);
       csoundDie(csound, Str("File %s already exists"), filename);
@@ -726,11 +765,13 @@ int read_unified_file(CSOUND *csound, char **pname, char **score)
       while (*p == ' ' || *p == '\t') p++;
       if (strstr(p, "<CsoundSynthesizer>") == p ||
           strstr(p, "<CsoundSynthesiser>") == p) {
-        csoundMessage(csound, Str("STARTING FILE\n"));
+        csoundDebugMsg(csound, Str("STARTING FILE\n"));
         started = TRUE;
       }
       else if (strstr(p, "</CsoundSynthesizer>") == p ||
                strstr(p, "</CsoundSynthesiser>") == p) {
+        if (csound->scorestr != NULL)
+          corfile_flush(csound->scorestr);
         *pname = ST(orcname);
         *score = ST(sconame);
         if (ST(midiSet)) {
@@ -800,7 +841,7 @@ int read_unified_file(CSOUND *csound, char **pname, char **score)
         result = r && result;
       }
       else if (blank_buffer(csound, buffer)) continue;
-      else if (started && strchr(p, '<') == buffer){ 
+      else if (started && strchr(p, '<') == buffer){
         csoundMessage(csound, Str("unknown CSD tag: %s\n"), buffer);
       }
     }
@@ -818,4 +859,3 @@ int read_unified_file(CSOUND *csound, char **pname, char **score)
     csoundFileClose(csound, fd);
     return result;
 }
-
