@@ -18,7 +18,6 @@
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  */
 #include "CppSound.hpp"
-#include "Midifile.hpp"
 #include "Score.hpp"
 #include "System.hpp"
 #include "Conversions.hpp"
@@ -32,6 +31,8 @@
 #include <fstream>
 #include <sstream>
 
+#include <allegro.h>
+
 #if defined(HAVE_MUSICXML2)
 #if defined(EXP)
 #undef EXP
@@ -50,7 +51,7 @@ using namespace MusicXML2;
 namespace csound
 {
 
-void printChord(std::ostream &stream, std::string label, const std::vector<double> &chord)
+void SILENCE_PUBLIC printChord(std::ostream &stream, std::string label, const std::vector<double> &chord)
 {
     if (!( (System::getMessageLevel() & System::INFORMATION_LEVEL) == System::INFORMATION_LEVEL) ) {
         return;
@@ -65,7 +66,7 @@ void printChord(std::ostream &stream, std::string label, const std::vector<doubl
     stream << "]" << std::endl;
 }
 
-void printChord(std::string label, const std::vector<double> &chord)
+void SILENCE_PUBLIC printChord(std::string label, const std::vector<double> &chord)
 {
     if (!( (System::getMessageLevel() & System::INFORMATION_LEVEL) == System::INFORMATION_LEVEL) ) {
         return;
@@ -172,9 +173,25 @@ void Score::load(std::string filename)
 
 void Score::load(std::istream &stream)
 {
-    MidiFile midiFile;
-    midiFile.read(stream);
-    load(midiFile);
+    Alg_seq seq(stream, true);
+    seq.convert_to_seconds();
+    Alg_iterator iterator(&seq, false);
+    iterator.begin();
+    for(;;) {
+        Alg_event *event = iterator.next();
+        if (!event) {
+            break;
+        }
+        append(event->get_start_time(),
+               event->get_duration(),
+               double(144),
+               double(event->chan),
+               event->get_pitch(),
+               event->get_loud());
+    }
+    // MidiFile midiFile;
+    // midiFile.read(stream);
+    // load(midiFile);
 }
 
 #if defined(HAVE_MUSICXML2)
@@ -299,7 +316,7 @@ void Score::save(std::string filename)
     System::inform("BEGAN Score::save(%s)...\n", filename.c_str());
     std::ofstream stream;
     //stream.open(filename.c_str(), std::ios_base::binary);
-    stream.open(filename.c_str(), std::ifstream::binary);
+    stream.open(filename.c_str(), std::ios::out | std::ios::binary);
     if (filename.find(".mid") != std::string::npos ||
             filename.find(".MID") != std::string::npos) {
         save(stream);
@@ -333,8 +350,31 @@ void Score::save(std::string filename)
 
 void Score::save(std::ostream &stream)
 {
-    save(midifile);
-    midifile.write(stream);
+    Alg_seq seq;
+    for (size_t i = 0, n = size(); i < n; ++i) {
+        const Event &event = at(i);
+        if (event.isNoteOn()) {
+            int channel = event.getChannel();
+            double time = event.getTime();
+            double duration = event.getDuration();
+            float pitch = event.getKey();
+            float loudness = event.getVelocity();
+            Alg_note *note = seq.create_note(time,
+                    channel,
+                    pitch,
+                    pitch,
+                    loudness,
+                    duration);
+            // Does nothing if the track already exists.
+            seq.add_track(channel);
+            seq.add_event(note, channel);
+        }
+    }
+    // Write with time in seconds.
+    seq.write(std::cout, true);
+    seq.smf_write(stream);
+    // save(midifile);
+    // midifile.write(stream);
 }
 
 static double max(double a, double b)
@@ -471,91 +511,6 @@ void Score::rescale(Event &event)
     }
 }
 
-void Score::load(MidiFile &midiFile)
-{
-    std::vector<Event>::clear();
-    for(std::vector<MidiTrack>::iterator trackI = midiFile.midiTracks.begin(); trackI != midiFile.midiTracks.end(); ++trackI) {
-        ///std::set<const MidiEvent *> usedNoteOffEvents;
-        for(std::vector<MidiEvent>::iterator onEventI = trackI->begin(); onEventI != trackI->end(); ++onEventI) {
-            const MidiEvent &noteOnEvent = *onEventI;
-            std::cerr << "At:       " << std::hex << &noteOnEvent << " " << noteOnEvent.toString();
-            if(noteOnEvent.isNoteOn()) {
-                for(std::vector<MidiEvent>::iterator offEventI = onEventI; offEventI != trackI->end(); ++offEventI) {
-                    const MidiEvent &noteOffEvent = *offEventI;
-                    ///if (usedNoteOffEvents.find(&noteOffEvent) == usedNoteOffEvents.end()) {
-                    if(noteOnEvent.matchesNoteOffEvent(noteOffEvent)) {
-                        std::cerr << " matches: " << std::hex << &noteOffEvent << " " << noteOffEvent.toString();
-                        double status = noteOnEvent.getStatusNybble();
-                        double instrument = noteOnEvent.getChannelNybble();
-                        double time_ = noteOnEvent.time;
-                        double duration = noteOffEvent.time - noteOnEvent.time;
-                        double key = noteOnEvent.getKey();
-                        double velocity = noteOnEvent.getVelocity();
-                        append(time_, duration, status, instrument, key, velocity);
-                        std::cerr << "  producing: " << back().toString().c_str() << std::endl;
-                        ///usedNoteOffEvents.insert(&noteOffEvent);
-                        break;
-                    }
-                    ///}
-                }
-            }
-        }
-    }
-    findScale();
-    sort();
-}
-
-void Score::save(MidiFile &midiFile)
-{
-    findScale();
-    sort();
-    // Make this a Format 1 file.
-    midiFile.clear();
-    midiFile.midiHeader.type = 1;
-    // Each track contains all events for one instrument
-    // (not the same as MIDI channel).
-    std::map<int, Score> eventsForInstruments;
-    for (Score::iterator it = begin(); it != end(); ++it) {
-        const Event &event = *it;
-        //event.dump(std::cout);
-        if(event.isNoteOn()) {
-            Event onEvent = *it;
-            int instrument = event.getInstrument();
-            eventsForInstruments[instrument].push_back(onEvent);
-            Event offEvent = onEvent;
-            onEvent.createNoteOffEvent(offEvent);
-            eventsForInstruments[instrument].push_back(offEvent);
-        }
-    }
-    for (std::map<int, Score>::iterator it = eventsForInstruments.begin();
-            it != eventsForInstruments.end();
-            ++it) {
-        Score &eventsForInstrument = it->second;
-        eventsForInstrument.sort();
-        MidiTrack midiTrack;
-        for (size_t i = 0, n = eventsForInstrument.size(); i < n; i++) {
-            const Event &event = eventsForInstrument[i];
-            MidiEvent midiEvent;
-            midiEvent.time = event.getTime();
-            midiEvent.ticks = int(Conversions::round(midiEvent.time / midiFile.currentSecondsPerTick));
-            midiEvent.push_back(event.getMidiStatus());
-            midiEvent.push_back(event.getKeyNumber());
-            midiEvent.push_back(event.getVelocity());
-            midiTrack.push_back(midiEvent);
-        }
-        MidiEvent trackEnd;
-        trackEnd.ticks = midiTrack.back().ticks;
-        trackEnd.time = midiTrack.back().time;
-        trackEnd.push_back(MidiFile::META_EVENT);
-        trackEnd.push_back(MidiFile::META_END_OF_TRACK);
-        trackEnd.push_back(0);
-        midiTrack.push_back(trackEnd);
-        midiFile.midiTracks.push_back(midiTrack);
-        System::inform("Saved MIDI track for instrument %3d (MIDI channel %3d) with %7d events.\n", it->first, it->first % 16, it->second.size());
-    }
-    midiFile.midiHeader.trackCount = midiFile.midiTracks.size();
-}
-
 void Score::dump(std::ostream &stream)
 {
     stream << "silence::Score = " << int(size()) << " events:" << std::endl;
@@ -633,16 +588,23 @@ void Score::sort()
 
 double Score::getDuration()
 {
-    findScale();
-    double duration = 0.0;
-    double duration_ = 0.0;
-    for(Score::iterator it = begin(); it != end(); ++it) {
-        duration_ = it->getTime() + it->getDuration();
-        if(duration_ > duration) {
-            duration = duration_;
+    double start = 0.0;
+    double end = 0.0;
+    for (int i = 0, n = size(); i < n; ++i) {
+        const Event &event = at(i);
+        if (i == 0) {
+            start = event.getTime();
+            end = event.getOffTime();            
+        } else {
+            if (event.getTime() < start) {
+                start = event.getTime();
+            }
+            if (event.getOffTime() > end) {
+                end = event.getOffTime();
+            }
         }
     }
-    return (duration - scaleActualMinima.getTime());
+    return end - start;
 }
 
 void Score::rescale(int dimension, bool rescaleMinimum, double minimum, bool rescaleRange, double range)
@@ -1279,4 +1241,44 @@ void Score::remove(size_t index)
 {
     erase(begin() + index);
 }
+void Score::tieOverlappingNotes(bool considerInstrumentNumber)
+{
+    sort();
+    for (int laterI = size() - 1; laterI > 1; --laterI) {
+        Event &laterEvent = (*this)[laterI];
+        if (!laterEvent.isNote()) {
+            continue;
+        }
+        for (int earlierI = laterI - 1; earlierI > 0; --earlierI) {
+            Event &earlierEvent = (*this)[earlierI];
+            if (!earlierEvent.isNote()) {
+                continue;
+            }
+            if (earlierEvent.getKeyNumber() != laterEvent.getKeyNumber()) {
+                continue;
+            }
+            if (earlierEvent.getVelocity() <= 0.0 || laterEvent.getVelocity() <= 0.0) {
+                continue;
+            }
+            if (earlierEvent.getOffTime() < laterEvent.getTime()) {
+                continue;
+            }
+            if (considerInstrumentNumber && (earlierEvent.getChannel() != laterEvent.getChannel())) {
+                continue;
+            }
+            // Ok, must be tied.
+            earlierEvent.setOffTime(laterEvent.getOffTime());
+            erase(begin() + laterI);
+            break;
+        }
+    }
 }
+
+void Score::temper(double tonesPerOctave)
+{
+    for (size_t i = 0, n = size(); i < n; ++i) {
+        (*this)[i].temper(tonesPerOctave);
+    }
+}
+}
+
